/* topbar.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from topbar.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <gtk/gtk.h>
#include <clutter-gtk/clutter-gtk.h>
#include <glib/gi18n-lib.h>
#include <gio/gio.h>
#include <stdlib.h>
#include <string.h>


#define BOXES_TYPE_TOPBAR_PAGE (boxes_topbar_page_get_type ())

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;
typedef struct _BoxesTopbarPrivate BoxesTopbarPrivate;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
typedef struct _BoxesCollectionPrivate BoxesCollectionPrivate;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))

typedef enum  {
	BOXES_TOPBAR_PAGE_COLLECTION,
	BOXES_TOPBAR_PAGE_SELECTION,
	BOXES_TOPBAR_PAGE_WIZARD,
	BOXES_TOPBAR_PAGE_PROPERTIES
} BoxesTopbarPage;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesTopbar {
	BoxesUI parent_instance;
	BoxesTopbarPrivate * priv;
	GtkLabel* label;
	GtkNotebook* notebook;
};

struct _BoxesTopbarClass {
	BoxesUIClass parent_class;
};

struct _BoxesTopbarPrivate {
	GtkClutterActor* gtk_actor;
	GtkSpinner* spinner;
	GtkToolButton* select_btn;
	GtkToolButton* cancel_btn;
	GtkToolButton* spinner_btn;
	GtkToolButton* back_btn;
	GtkButton* new_btn;
	GtkLabel* selection_label;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesCollection {
	GObject parent_instance;
	BoxesCollectionPrivate * priv;
	GPtrArray* items;
};

struct _BoxesCollectionClass {
	GObjectClass parent_class;
};


static gpointer boxes_topbar_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_topbar_page_get_type (void) G_GNUC_CONST;
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
#define BOXES_TOPBAR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_TOPBAR, BoxesTopbarPrivate))
enum  {
	BOXES_TOPBAR_DUMMY_PROPERTY,
	BOXES_TOPBAR_ACTOR
};
#define BOXES_TOPBAR_height ((guint) 50)
BoxesTopbar* boxes_topbar_new (void);
BoxesTopbar* boxes_topbar_construct (GType object_type);
BoxesUI* boxes_ui_construct (GType object_type);
static void boxes_topbar_setup_topbar (BoxesTopbar* self);
GType boxes_app_get_type (void) G_GNUC_CONST;
static void __lambda95_ (BoxesTopbar* self);
static void boxes_topbar_update_selection_label (BoxesTopbar* self);
static void ___lambda95__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void __lambda2_ (BoxesTopbar* self, GtkToolButton* button);
void boxes_ui_set_ui_state (BoxesUI* self, BoxesUIState value);
static void ___lambda2__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
static void __lambda3_ (BoxesTopbar* self, GtkButton* button);
static void ___lambda3__gtk_button_clicked (GtkButton* _sender, gpointer self);
static void __lambda4_ (BoxesTopbar* self);
void boxes_app_set_selection_mode (BoxesApp* self, gboolean value);
static void ___lambda4__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
static void __lambda5_ (BoxesTopbar* self);
gboolean boxes_app_get_selection_mode (BoxesApp* self);
static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self);
static void boxes_topbar_update_select_btn_sensitivity (BoxesTopbar* self);
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static void _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self);
static void __lambda94_ (BoxesTopbar* self);
static void ___lambda94__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self);
GList* boxes_app_get_selected_items (BoxesApp* self);
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void boxes_topbar_real_ui_state_changed (BoxesUI* base);
BoxesUIState boxes_ui_get_ui_state (BoxesUI* self);
static void boxes_topbar_finalize (GObject* obj);
ClutterActor* boxes_ui_get_actor (BoxesUI* self);
static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);


GType boxes_topbar_page_get_type (void) {
	static volatile gsize boxes_topbar_page_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_page_type_id__volatile)) {
		static const GEnumValue values[] = {{BOXES_TOPBAR_PAGE_COLLECTION, "BOXES_TOPBAR_PAGE_COLLECTION", "collection"}, {BOXES_TOPBAR_PAGE_SELECTION, "BOXES_TOPBAR_PAGE_SELECTION", "selection"}, {BOXES_TOPBAR_PAGE_WIZARD, "BOXES_TOPBAR_PAGE_WIZARD", "wizard"}, {BOXES_TOPBAR_PAGE_PROPERTIES, "BOXES_TOPBAR_PAGE_PROPERTIES", "properties"}, {0, NULL, NULL}};
		GType boxes_topbar_page_type_id;
		boxes_topbar_page_type_id = g_enum_register_static ("BoxesTopbarPage", values);
		g_once_init_leave (&boxes_topbar_page_type_id__volatile, boxes_topbar_page_type_id);
	}
	return boxes_topbar_page_type_id__volatile;
}


static void __lambda95_ (BoxesTopbar* self) {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 314 "topbar.c"
}


static void ___lambda95__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda95_ (self);
#line 321 "topbar.c"
}


BoxesTopbar* boxes_topbar_construct (GType object_type) {
	BoxesTopbar * self = NULL;
	BoxesApp* _tmp0_;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) boxes_ui_construct (object_type);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_setup_topbar (self);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp0_, "notify::selected-items", (GCallback) ___lambda95__g_object_notify, self, 0);
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	return self;
#line 338 "topbar.c"
}


BoxesTopbar* boxes_topbar_new (void) {
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	return boxes_topbar_construct (BOXES_TYPE_TOPBAR);
#line 345 "topbar.c"
}


static void __lambda2_ (BoxesTopbar* self, GtkToolButton* button) {
	BoxesApp* _tmp0_;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (button != NULL);
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_COLLECTION);
#line 357 "topbar.c"
}


static void ___lambda2__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda2_ (self, _sender);
#line 364 "topbar.c"
}


static void __lambda3_ (BoxesTopbar* self, GtkButton* button) {
	BoxesApp* _tmp0_;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (button != NULL);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_ui_set_ui_state ((BoxesUI*) _tmp0_, BOXES_UI_STATE_WIZARD);
#line 376 "topbar.c"
}


static void ___lambda3__gtk_button_clicked (GtkButton* _sender, gpointer self) {
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda3_ (self, _sender);
#line 383 "topbar.c"
}


static void __lambda4_ (BoxesTopbar* self) {
	BoxesApp* _tmp0_;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 94 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, TRUE);
#line 393 "topbar.c"
}


static void ___lambda4__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda4_ (self);
#line 400 "topbar.c"
}


static void __lambda5_ (BoxesTopbar* self) {
	gint _tmp0_ = 0;
	BoxesApp* _tmp1_;
	gboolean _tmp2_;
	gboolean _tmp3_;
	GtkNotebook* _tmp5_;
	gint _tmp6_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = boxes_app_get_selection_mode (_tmp1_);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	if (_tmp3_) {
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp0_ = (gint) BOXES_TOPBAR_PAGE_SELECTION;
#line 421 "topbar.c"
	} else {
		GtkNotebook* _tmp4_;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp4_ = self->notebook;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		g_object_set (_tmp4_, "page", (gint) BOXES_TOPBAR_PAGE_COLLECTION, NULL);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp0_ = (gint) BOXES_TOPBAR_PAGE_COLLECTION;
#line 430 "topbar.c"
	}
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = self->notebook;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp6_ = _tmp0_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_set (_tmp5_, "page", _tmp6_, NULL);
#line 438 "topbar.c"
}


static void ___lambda5__g_object_notify (GObject* _sender, GParamSpec* pspec, gpointer self) {
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda5_ (self);
#line 445 "topbar.c"
}


static void _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_added (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn_sensitivity (self);
#line 452 "topbar.c"
}


static void _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_removed (BoxesCollection* _sender, BoxesCollectionItem* item, gpointer self) {
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn_sensitivity (self);
#line 459 "topbar.c"
}


static void __lambda94_ (BoxesTopbar* self) {
	BoxesApp* _tmp0_;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 134 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_app_set_selection_mode (_tmp0_, FALSE);
#line 469 "topbar.c"
}


static void ___lambda94__gtk_tool_button_clicked (GtkToolButton* _sender, gpointer self) {
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__lambda94_ (self);
#line 476 "topbar.c"
}


static void boxes_topbar_setup_topbar (BoxesTopbar* self) {
	GtkNotebook* _tmp0_;
	GtkNotebook* _tmp1_;
	GtkNotebook* _tmp2_;
	GtkClutterActor* _tmp3_;
	GtkClutterActor* _tmp4_;
	GtkHBox* _tmp5_;
	GtkHBox* hbox;
	GtkNotebook* _tmp6_;
	GtkHBox* _tmp7_;
	GtkHBox* _tmp8_;
	GtkStyleContext* _tmp9_ = NULL;
	GtkToolbar* _tmp10_;
	GtkToolbar* toolbar_start;
	GtkStyleContext* _tmp11_ = NULL;
	GtkHBox* _tmp12_;
	GtkToolButton* _tmp13_;
	GtkToolButton* _tmp14_;
	GtkToolButton* _tmp15_;
	GtkToolButton* _tmp16_;
	GtkStyleContext* _tmp17_ = NULL;
	GtkToolButton* _tmp18_;
	GtkToolButton* _tmp19_;
	const gchar* _tmp20_ = NULL;
	GtkButton* _tmp21_;
	GtkButton* _tmp22_;
	GtkButton* _tmp23_;
	GtkStyleContext* _tmp24_ = NULL;
	GtkToolItem* _tmp25_;
	GtkToolItem* tool_item;
	GtkToolItem* _tmp26_;
	GtkButton* _tmp27_;
	GtkToolItem* _tmp28_;
	GtkButton* _tmp29_;
	GtkToolItem* _tmp30_;
	GtkLabel* _tmp31_;
	GtkLabel* _tmp32_;
	GtkLabel* _tmp33_;
	GtkToolItem* _tmp34_;
	GtkToolItem* _tmp35_;
	GtkToolItem* _tmp36_;
	GtkLabel* _tmp37_;
	GtkToolItem* _tmp38_;
	GtkToolbar* _tmp39_;
	GtkToolbar* toolbar_end;
	GtkStyleContext* _tmp40_ = NULL;
	GtkSpinner* _tmp41_;
	GtkSpinner* _tmp42_;
	GtkSpinner* _tmp43_;
	GtkToolButton* _tmp44_;
	GtkToolButton* _tmp45_;
	GtkToolButton* _tmp46_;
	GtkStyleContext* _tmp47_ = NULL;
	GtkToolButton* _tmp48_;
	GtkToolButton* _tmp49_;
	GtkToolButton* _tmp50_;
	GtkToolButton* _tmp51_;
	GtkStyleContext* _tmp52_ = NULL;
	GtkToolButton* _tmp53_;
	GtkToolButton* _tmp54_;
	BoxesApp* _tmp55_;
	BoxesApp* _tmp56_;
	BoxesCollection* _tmp57_;
	BoxesApp* _tmp58_;
	BoxesCollection* _tmp59_;
	GtkToolButton* _tmp60_;
	GtkHBox* _tmp61_;
	GtkHBox* _tmp62_;
	GtkNotebook* _tmp63_;
	GtkHBox* _tmp64_;
	GtkHBox* _tmp65_;
	GtkStyleContext* _tmp66_ = NULL;
	GtkToolbar* _tmp67_;
	GtkToolbar* toolbar_selection;
	GtkStyleContext* _tmp68_ = NULL;
	GtkHBox* _tmp69_;
	GtkLabel* _tmp70_;
	GtkLabel* _tmp71_;
	GtkToolItem* _tmp72_;
	GtkToolItem* _tmp73_;
	GtkToolItem* _tmp74_;
	GtkLabel* _tmp75_;
	GtkToolItem* _tmp76_;
	GtkToolButton* _tmp77_;
	GtkToolButton* _tmp78_;
	GtkStyleContext* _tmp79_ = NULL;
	GtkToolButton* _tmp80_;
	GtkToolButton* _tmp81_;
	GtkToolButton* _tmp82_;
	GtkHBox* _tmp83_;
	GtkHBox* _tmp84_;
	GtkNotebook* _tmp85_;
	GtkHBox* _tmp86_;
	GtkHBox* _tmp87_;
	GtkStyleContext* _tmp88_ = NULL;
	GtkHBox* _tmp89_;
	GtkNotebook* _tmp90_;
	GtkHBox* _tmp91_;
	GtkHBox* _tmp92_;
	GtkStyleContext* _tmp93_ = NULL;
	GtkNotebook* _tmp94_;
	GtkNotebook* _tmp95_;
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = (GtkNotebook*) gtk_notebook_new ();
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp0_);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->notebook);
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->notebook = _tmp0_;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = self->notebook;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp1_, 50, (gint) BOXES_TOPBAR_height);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = self->notebook;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = (GtkClutterActor*) gtk_clutter_actor_new_with_contents ((GtkWidget*) _tmp2_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp3_);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->gtk_actor = _tmp3_;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp4_ = self->priv->gtk_actor;
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	clutter_actor_set_name ((ClutterActor*) _tmp4_, "topbar");
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp5_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	hbox = _tmp5_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp6_ = self->notebook;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp7_ = hbox;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp6_, (GtkWidget*) _tmp7_, NULL);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp8_ = hbox;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp9_ = gtk_widget_get_style_context ((GtkWidget*) _tmp8_);
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp9_, GTK_STYLE_CLASS_SIDEBAR);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp10_ = (GtkToolbar*) gtk_toolbar_new ();
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp10_);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	toolbar_start = _tmp10_;
#line 49 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_icon_size (toolbar_start, (gint) GTK_ICON_SIZE_MENU);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp11_ = gtk_widget_get_style_context ((GtkWidget*) toolbar_start);
#line 50 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp11_, GTK_STYLE_CLASS_MENUBAR);
#line 51 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_show_arrow (toolbar_start, FALSE);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp12_ = hbox;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start ((GtkBox*) _tmp12_, (GtkWidget*) toolbar_start, TRUE, TRUE, (guint) 0);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp13_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp13_);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->back_btn = _tmp13_;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp14_ = self->priv->back_btn;
#line 55 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp14_, GTK_ALIGN_CENTER);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp15_ = self->priv->back_btn;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_tool_button_set_icon_name (_tmp15_, "go-previous-symbolic");
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp16_ = self->priv->back_btn;
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp17_ = gtk_widget_get_style_context ((GtkWidget*) _tmp16_);
#line 57 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp17_, "raised");
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp18_ = self->priv->back_btn;
#line 58 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp18_, "clicked", (GCallback) ___lambda2__gtk_tool_button_clicked, self, 0);
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp19_ = self->priv->back_btn;
#line 59 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_start, (GtkToolItem*) _tmp19_, 0);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp20_ = _ ("New");
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp21_ = (GtkButton*) gtk_button_new_with_label (_tmp20_);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp21_);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 61 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->new_btn = _tmp21_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp22_ = self->priv->new_btn;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_size_request ((GtkWidget*) _tmp22_, 70, -1);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp23_ = self->priv->new_btn;
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp24_ = gtk_widget_get_style_context ((GtkWidget*) _tmp23_);
#line 63 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp24_, "raised");
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp25_ = gtk_tool_item_new ();
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp25_);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	tool_item = _tmp25_;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp26_ = tool_item;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp27_ = self->priv->new_btn;
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_set ((GtkContainer*) _tmp26_, "child", (GtkWidget*) _tmp27_, NULL);
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp28_ = tool_item;
#line 66 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp28_, GTK_ALIGN_CENTER);
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp29_ = self->priv->new_btn;
#line 67 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp29_, "clicked", (GCallback) ___lambda3__gtk_button_clicked, self, 0);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp30_ = tool_item;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_start, _tmp30_, 1);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp31_ = (GtkLabel*) gtk_label_new ("");
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp31_);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->label);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->label = _tmp31_;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp32_ = self->label;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_name ((GtkWidget*) _tmp32_, "TopbarLabel");
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp33_ = self->label;
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_halign ((GtkWidget*) _tmp33_, GTK_ALIGN_START);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp34_ = gtk_tool_item_new ();
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp34_);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (tool_item);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	tool_item = _tmp34_;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp35_ = tool_item;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_tool_item_set_expand (_tmp35_, TRUE);
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp36_ = tool_item;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp37_ = self->label;
#line 75 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_set ((GtkContainer*) _tmp36_, "child", (GtkWidget*) _tmp37_, NULL);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp38_ = tool_item;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_start, _tmp38_, 2);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp39_ = (GtkToolbar*) gtk_toolbar_new ();
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp39_);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	toolbar_end = _tmp39_;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_icon_size (toolbar_end, (gint) GTK_ICON_SIZE_MENU);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp40_ = gtk_widget_get_style_context ((GtkWidget*) toolbar_end);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp40_, GTK_STYLE_CLASS_MENUBAR);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp41_ = (GtkSpinner*) gtk_spinner_new ();
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp41_);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->spinner = _tmp41_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp42_ = self->priv->spinner;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_spinner_start (_tmp42_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp43_ = self->priv->spinner;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp44_ = (GtkToolButton*) gtk_tool_button_new ((GtkWidget*) _tmp43_, NULL);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp44_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner_btn);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->spinner_btn = _tmp44_;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp45_ = self->priv->spinner_btn;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp45_, GTK_ALIGN_CENTER);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp46_ = self->priv->spinner_btn;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp47_ = gtk_widget_get_style_context ((GtkWidget*) _tmp46_);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp47_, "raised");
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp48_ = self->priv->spinner_btn;
#line 87 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_end, (GtkToolItem*) _tmp48_, 0);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp49_ = (GtkToolButton*) gtk_tool_button_new (NULL, NULL);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp49_);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->select_btn = _tmp49_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp50_ = self->priv->select_btn;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_tool_button_set_icon_name (_tmp50_, "emblem-default-symbolic");
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp51_ = self->priv->select_btn;
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp52_ = gtk_widget_get_style_context ((GtkWidget*) _tmp51_);
#line 91 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp52_, "raised");
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp53_ = self->priv->select_btn;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp53_, GTK_ALIGN_CENTER);
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp54_ = self->priv->select_btn;
#line 93 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp54_, "clicked", (GCallback) ___lambda4__gtk_tool_button_clicked, self, 0);
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp55_ = boxes_app_app;
#line 96 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object ((GObject*) _tmp55_, "notify::selection-mode", (GCallback) ___lambda5__g_object_notify, self, 0);
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_select_btn_sensitivity (self);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp56_ = boxes_app_app;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp57_ = _tmp56_->collection;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp57_, "item-added", (GCallback) _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_added, self, 0);
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp58_ = boxes_app_app;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp59_ = _tmp58_->collection;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp59_, "item-removed", (GCallback) _boxes_topbar_update_select_btn_sensitivity_boxes_collection_item_removed, self, 0);
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp60_ = self->priv->select_btn;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_end, (GtkToolItem*) _tmp60_, 1);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_show_arrow (toolbar_end, FALSE);
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp61_ = hbox;
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start ((GtkBox*) _tmp61_, (GtkWidget*) toolbar_end, FALSE, FALSE, (guint) 0);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp62_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp62_);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	hbox = _tmp62_;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp63_ = self->notebook;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp64_ = hbox;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp63_, (GtkWidget*) _tmp64_, NULL);
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp65_ = hbox;
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp66_ = gtk_widget_get_style_context ((GtkWidget*) _tmp65_);
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp66_, GTK_STYLE_CLASS_SIDEBAR);
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp67_ = (GtkToolbar*) gtk_toolbar_new ();
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp67_);
#line 114 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	toolbar_selection = _tmp67_;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_style (toolbar_selection, GTK_TOOLBAR_TEXT);
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp68_ = gtk_widget_get_style_context ((GtkWidget*) toolbar_selection);
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp68_, GTK_STYLE_CLASS_MENUBAR);
#line 117 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_icon_size (toolbar_selection, (gint) GTK_ICON_SIZE_MENU);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_set_show_arrow (toolbar_selection, FALSE);
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp69_ = hbox;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_box_pack_start ((GtkBox*) _tmp69_, (GtkWidget*) toolbar_selection, TRUE, TRUE, (guint) 0);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp70_ = (GtkLabel*) gtk_label_new ("");
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp70_);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_label);
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->selection_label = _tmp70_;
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_update_selection_label (self);
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp71_ = self->priv->selection_label;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_label_set_use_markup (_tmp71_, TRUE);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp72_ = gtk_tool_item_new ();
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp72_);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (tool_item);
#line 124 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	tool_item = _tmp72_;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp73_ = tool_item;
#line 125 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_tool_item_set_expand (_tmp73_, TRUE);
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp74_ = tool_item;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp75_ = self->priv->selection_label;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_set ((GtkContainer*) _tmp74_, "child", (GtkWidget*) _tmp75_, NULL);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp76_ = tool_item;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_selection, _tmp76_, 0);
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp77_ = (GtkToolButton*) gtk_tool_button_new_from_stock ("gtk-cancel");
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp77_);
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->cancel_btn);
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv->cancel_btn = _tmp77_;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp78_ = self->priv->cancel_btn;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp79_ = gtk_widget_get_style_context ((GtkWidget*) _tmp78_);
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp79_, "raised");
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp80_ = self->priv->cancel_btn;
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_valign ((GtkWidget*) _tmp80_, GTK_ALIGN_CENTER);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp81_ = self->priv->cancel_btn;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_toolbar_insert (toolbar_selection, (GtkToolItem*) _tmp81_, 1);
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp82_ = self->priv->cancel_btn;
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_signal_connect_object (_tmp82_, "clicked", (GCallback) ___lambda94__gtk_tool_button_clicked, self, 0);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp83_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp83_);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 138 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	hbox = _tmp83_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp84_ = hbox;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_set ((GtkWidget*) _tmp84_, "margin", 5, NULL);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp85_ = self->notebook;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp86_ = hbox;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp85_, (GtkWidget*) _tmp86_, NULL);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp87_ = hbox;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp88_ = gtk_widget_get_style_context ((GtkWidget*) _tmp87_);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp88_, GTK_STYLE_CLASS_SIDEBAR);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp89_ = (GtkHBox*) gtk_hbox_new (FALSE, 0);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_ref_sink (_tmp89_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	hbox = _tmp89_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp90_ = self->notebook;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp91_ = hbox;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_notebook_append_page (_tmp90_, (GtkWidget*) _tmp91_, NULL);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp92_ = hbox;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp93_ = gtk_widget_get_style_context ((GtkWidget*) _tmp92_);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_style_context_add_class (_tmp93_, GTK_STYLE_CLASS_SIDEBAR);
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp94_ = self->notebook;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_notebook_set_show_tabs (_tmp94_, FALSE);
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp95_ = self->notebook;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_show_all ((GtkWidget*) _tmp95_);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar_selection);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar_end);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (tool_item);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (toolbar_start);
#line 37 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (hbox);
#line 1024 "topbar.c"
}


static gint g_ptr_array_get_length (GPtrArray* self) {
	gint result;
	guint _tmp0_;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, 0);
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	_tmp0_ = self->len;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	result = (gint) _tmp0_;
#line 4092 "../vapi/upstream/glib-2.0.vapi"
	return result;
#line 1039 "topbar.c"
}


static void g_ptr_array_set_length (GPtrArray* self, gint value) {
	gint _tmp0_;
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	g_return_if_fail (self != NULL);
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	_tmp0_ = value;
#line 4093 "../vapi/upstream/glib-2.0.vapi"
	g_ptr_array_set_size (self, _tmp0_);
#line 1051 "topbar.c"
}


static void boxes_topbar_update_select_btn_sensitivity (BoxesTopbar* self) {
	GtkToolButton* _tmp0_;
	BoxesApp* _tmp1_;
	BoxesCollection* _tmp2_;
	GPtrArray* _tmp3_;
	gint _tmp4_;
	gint _tmp5_;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->select_btn;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_app;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_->collection;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_->items;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_ptr_array_get_length (_tmp3_);
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	gtk_widget_set_sensitive ((GtkWidget*) _tmp0_, _tmp5_ != 0);
#line 1078 "topbar.c"
}


static void _g_object_unref0_ (gpointer var) {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 1085 "topbar.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_list_free (self);
#line 1094 "topbar.c"
}


static void boxes_topbar_update_selection_label (BoxesTopbar* self) {
	BoxesApp* _tmp0_;
	GList* _tmp1_;
	GList* _tmp2_;
	GList* _tmp3_;
	guint _tmp4_ = 0U;
	guint _tmp5_;
	guint items;
	guint _tmp6_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_return_if_fail (self != NULL);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_app_app;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = boxes_app_get_selected_items (_tmp0_);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp2_ = _tmp1_;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp3_ = _tmp2_;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp4_ = g_list_length (_tmp3_);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp5_ = _tmp4_;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	__g_list_free__g_object_unref0_0 (_tmp3_);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	items = _tmp5_;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp6_ = items;
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	if (_tmp6_ > ((guint) 0)) {
#line 1129 "topbar.c"
		GtkLabel* _tmp7_;
		guint _tmp8_;
		const gchar* _tmp9_ = NULL;
		guint _tmp10_;
		gchar* _tmp11_ = NULL;
		gchar* _tmp12_;
		gchar* _tmp13_;
		gchar* _tmp14_;
		gchar* _tmp15_;
		gchar* _tmp16_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp7_ = self->priv->selection_label;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp8_ = items;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp9_ = ngettext ("%d selected", "%d selected", (gulong) _tmp8_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp10_ = items;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp11_ = g_strdup_printf (_tmp9_, _tmp10_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp12_ = _tmp11_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp13_ = g_strconcat ("<b>", _tmp12_, NULL);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp14_ = _tmp13_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp15_ = g_strconcat (_tmp14_, "</b>", NULL);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp16_ = _tmp15_;
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		gtk_label_set_markup (_tmp7_, _tmp16_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp16_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp14_);
#line 159 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp12_);
#line 1168 "topbar.c"
	} else {
		GtkLabel* _tmp17_;
		const gchar* _tmp18_ = NULL;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_;
		gchar* _tmp22_;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp17_ = self->priv->selection_label;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp18_ = _ ("Click on items to select them");
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp19_ = g_strconcat ("<i>", _tmp18_, NULL);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp20_ = _tmp19_;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp21_ = g_strconcat (_tmp20_, "</i>", NULL);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_tmp22_ = _tmp21_;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		gtk_label_set_markup (_tmp17_, _tmp22_);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp22_);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		_g_free0 (_tmp20_);
#line 1194 "topbar.c"
	}
}


static void boxes_topbar_real_ui_state_changed (BoxesUI* base) {
	BoxesTopbar * self;
	BoxesUIState _tmp0_;
	BoxesUIState _tmp1_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = boxes_ui_get_ui_state ((BoxesUI*) self);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp1_ = _tmp0_;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	switch (_tmp1_) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_COLLECTION:
#line 1213 "topbar.c"
		{
			GtkNotebook* _tmp2_;
			GtkToolButton* _tmp3_;
			GtkToolButton* _tmp4_;
			GtkToolButton* _tmp5_;
			GtkButton* _tmp6_;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp2_ = self->notebook;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp2_, "page", (gint) BOXES_TOPBAR_PAGE_COLLECTION, NULL);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp3_ = self->priv->back_btn;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp3_);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp4_ = self->priv->spinner_btn;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp4_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp5_ = self->priv->select_btn;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp5_);
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp6_ = self->priv->new_btn;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp6_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1242 "topbar.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_CREDS:
#line 1246 "topbar.c"
		{
			GtkButton* _tmp7_;
			GtkToolButton* _tmp8_;
			GtkToolButton* _tmp9_;
			GtkToolButton* _tmp10_;
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp7_ = self->priv->new_btn;
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp7_);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp8_ = self->priv->back_btn;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp8_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp9_ = self->priv->spinner_btn;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_show ((GtkWidget*) _tmp9_);
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp10_ = self->priv->select_btn;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			gtk_widget_hide ((GtkWidget*) _tmp10_);
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1270 "topbar.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_DISPLAY:
#line 1274 "topbar.c"
		{
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1278 "topbar.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_PROPERTIES:
#line 1282 "topbar.c"
		{
			GtkNotebook* _tmp11_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp11_ = self->notebook;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp11_, "page", (gint) BOXES_TOPBAR_PAGE_PROPERTIES, NULL);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1291 "topbar.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_UI_STATE_WIZARD:
#line 1295 "topbar.c"
		{
			GtkNotebook* _tmp12_;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			_tmp12_ = self->notebook;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			g_object_set (_tmp12_, "page", (gint) BOXES_TOPBAR_PAGE_WIZARD, NULL);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1304 "topbar.c"
		}
		default:
		{
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
			break;
#line 1310 "topbar.c"
		}
	}
}


static ClutterActor* boxes_topbar_real_get_actor (BoxesUI* base) {
	ClutterActor* result;
	BoxesTopbar* self;
	GtkClutterActor* _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self = (BoxesTopbar*) base;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_tmp0_ = self->priv->gtk_actor;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	result = (ClutterActor*) _tmp0_;
#line 13 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	return result;
#line 1328 "topbar.c"
}


static void boxes_topbar_class_init (BoxesTopbarClass * klass) {
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	boxes_topbar_parent_class = g_type_class_peek_parent (klass);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_type_class_add_private (klass, sizeof (BoxesTopbarPrivate));
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	BOXES_UI_CLASS (klass)->ui_state_changed = boxes_topbar_real_ui_state_changed;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	BOXES_UI_CLASS (klass)->get_actor = boxes_topbar_real_get_actor;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_topbar_get_property;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_topbar_finalize;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_TOPBAR_ACTOR, g_param_spec_object ("actor", "actor", "actor", clutter_actor_get_type (), G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
#line 1347 "topbar.c"
}


static void boxes_topbar_instance_init (BoxesTopbar * self) {
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self->priv = BOXES_TOPBAR_GET_PRIVATE (self);
#line 1354 "topbar.c"
}


static void boxes_topbar_finalize (GObject* obj) {
	BoxesTopbar * self;
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->label);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->gtk_actor);
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->notebook);
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->select_btn);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->cancel_btn);
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->spinner_btn);
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->back_btn);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->new_btn);
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	_g_object_unref0 (self->priv->selection_label);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	G_OBJECT_CLASS (boxes_topbar_parent_class)->finalize (obj);
#line 1384 "topbar.c"
}


GType boxes_topbar_get_type (void) {
	static volatile gsize boxes_topbar_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_topbar_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesTopbarClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_topbar_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesTopbar), 0, (GInstanceInitFunc) boxes_topbar_instance_init, NULL };
		GType boxes_topbar_type_id;
		boxes_topbar_type_id = g_type_register_static (BOXES_TYPE_UI, "BoxesTopbar", &g_define_type_info, 0);
		g_once_init_leave (&boxes_topbar_type_id__volatile, boxes_topbar_type_id);
	}
	return boxes_topbar_type_id__volatile;
}


static void _vala_boxes_topbar_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesTopbar * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_TOPBAR, BoxesTopbar);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
	switch (property_id) {
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		case BOXES_TOPBAR_ACTOR:
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		g_value_set_object (value, boxes_ui_get_actor ((BoxesUI*) self));
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		break;
#line 1411 "topbar.c"
		default:
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 12 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/topbar.vala"
		break;
#line 1417 "topbar.c"
	}
}



