/* util.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from util.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <config.h>
#include <glib/gstdio.h>
#include <gio/gio.h>
#include <gdk/gdk.h>
#include <clutter/clutter.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <libxml/parser.h>
#include <libxml/tree.h>
#include <libxml/xpath.h>
#include <clutter-gtk/clutter-gtk.h>
#include <osinfo/osinfo.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <cairo.h>
#include <gobject/gvaluecollector.h>

#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define _gtk_widget_path_unref0(var) ((var == NULL) ? NULL : (var = (gtk_widget_path_unref (var), NULL)))
typedef struct _Block27Data Block27Data;
#define _gtk_tree_path_free0(var) ((var == NULL) ? NULL : (var = (gtk_tree_path_free (var), NULL)))
typedef struct _Block28Data Block28Data;
typedef struct _BoxesOutputStreamWriteData BoxesOutputStreamWriteData;
#define _xmlFreeParserCtxt0(var) ((var == NULL) ? NULL : (var = (xmlFreeParserCtxt (var), NULL)))
#define _xmlXPathFreeContext0(var) ((var == NULL) ? NULL : (var = (xmlXPathFreeContext (var), NULL)))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
typedef struct _Block29Data Block29Data;

#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
#define _g_type_class_unref0(var) ((var == NULL) ? NULL : (var = (g_type_class_unref (var), NULL)))

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;
typedef struct _BoxesPairPrivate BoxesPairPrivate;
#define _t1_destroy_func0(var) (((var == NULL) || (t1_destroy_func == NULL)) ? NULL : (var = (t1_destroy_func (var), NULL)))
#define _t2_destroy_func0(var) (((var == NULL) || (t2_destroy_func == NULL)) ? NULL : (var = (t2_destroy_func (var), NULL)))
typedef struct _BoxesParamSpecPair BoxesParamSpecPair;

#define BOXES_TYPE_QUERY (boxes_query_get_type ())
#define BOXES_QUERY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_QUERY, BoxesQuery))
#define BOXES_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_QUERY, BoxesQueryClass))
#define BOXES_IS_QUERY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_QUERY))
#define BOXES_IS_QUERY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_QUERY))
#define BOXES_QUERY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_QUERY, BoxesQueryClass))

typedef struct _BoxesQuery BoxesQuery;
typedef struct _BoxesQueryClass BoxesQueryClass;
typedef struct _BoxesQueryPrivate BoxesQueryPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))

#define BOXES_FDO_TYPE_ACCOUNTS (boxes_fdo_accounts_get_type ())
#define BOXES_FDO_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_FDO_TYPE_ACCOUNTS, BoxesFdoAccounts))
#define BOXES_FDO_IS_ACCOUNTS(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_FDO_TYPE_ACCOUNTS))
#define BOXES_FDO_ACCOUNTS_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_FDO_TYPE_ACCOUNTS, BoxesFdoAccountsIface))

typedef struct _BoxesFdoAccounts BoxesFdoAccounts;
typedef struct _BoxesFdoAccountsIface BoxesFdoAccountsIface;

#define BOXES_FDO_TYPE_ACCOUNTS_PROXY (boxes_fdo_accounts_proxy_get_type ())
typedef GDBusProxy BoxesFdoAccountsProxy;
typedef GDBusProxyClass BoxesFdoAccountsProxyClass;

#define BOXES_FDO_TYPE_ACCOUNTS_USER (boxes_fdo_accounts_user_get_type ())
#define BOXES_FDO_ACCOUNTS_USER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_FDO_TYPE_ACCOUNTS_USER, BoxesFdoAccountsUser))
#define BOXES_FDO_IS_ACCOUNTS_USER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_FDO_TYPE_ACCOUNTS_USER))
#define BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_FDO_TYPE_ACCOUNTS_USER, BoxesFdoAccountsUserIface))

typedef struct _BoxesFdoAccountsUser BoxesFdoAccountsUser;
typedef struct _BoxesFdoAccountsUserIface BoxesFdoAccountsUserIface;

#define BOXES_FDO_TYPE_ACCOUNTS_USER_PROXY (boxes_fdo_accounts_user_proxy_get_type ())
typedef GDBusProxy BoxesFdoAccountsUserProxy;
typedef GDBusProxyClass BoxesFdoAccountsUserProxyClass;
typedef struct _BoxesCheckCpuVtCapabilityData BoxesCheckCpuVtCapabilityData;
typedef struct _BoxesCheckModuleKvmLoadedData BoxesCheckModuleKvmLoadedData;
typedef struct _Block30Data Block30Data;
typedef struct _BoxesRunInThreadData BoxesRunInThreadData;
typedef struct _Block31Data Block31Data;
typedef struct _BoxesExecData BoxesExecData;
typedef struct _Block32Data Block32Data;

typedef enum  {
	BOXES_ERROR_INVALID,
	BOXES_ERROR_COMMAND_FAILED
} BoxesError;
#define BOXES_ERROR boxes_error_quark ()
struct _Block27Data {
	int _ref_count_;
	GtkTreeView* tree_view;
};

struct _Block28Data {
	int _ref_count_;
	GtkIconView* icon_view;
};

struct _BoxesOutputStreamWriteData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GOutputStream* stream;
	guint8* buffer;
	gint buffer_length1;
	guint8* _tmp0_;
	gint _tmp0__length1;
	gint length;
	gssize i;
	gssize _tmp1_;
	gint _tmp2_;
	GOutputStream* _tmp3_;
	guint8* _tmp4_;
	gint _tmp4__length1;
	gssize _tmp5_;
	gint _tmp6_;
	gssize _tmp7_;
	gssize _tmp8_;
	gssize _tmp9_;
	GError * _inner_error_;
};

struct _Block29Data {
	int _ref_count_;
	ClutterActor* actor;
};

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

struct _BoxesPair {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesPairPrivate * priv;
	gpointer first;
	gpointer second;
};

struct _BoxesPairClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesPair *self);
};

struct _BoxesPairPrivate {
	GType t1_type;
	GBoxedCopyFunc t1_dup_func;
	GDestroyNotify t1_destroy_func;
	GType t2_type;
	GBoxedCopyFunc t2_dup_func;
	GDestroyNotify t2_destroy_func;
};

struct _BoxesParamSpecPair {
	GParamSpec parent_instance;
};

struct _BoxesQuery {
	GObject parent_instance;
	BoxesQueryPrivate * priv;
};

struct _BoxesQueryClass {
	GObjectClass parent_class;
};

struct _BoxesQueryPrivate {
	gchar* query;
	GHashTable* params;
};

struct _BoxesFdoAccountsIface {
	GTypeInterface parent_iface;
	void (*FindUserByName) (BoxesFdoAccounts* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_);
	gchar* (*FindUserByName_finish) (BoxesFdoAccounts* self, GAsyncResult* _res_, GError** error);
};

struct _BoxesFdoAccountsUserIface {
	GTypeInterface parent_iface;
	gboolean (*get_AutomaticLogin) (BoxesFdoAccountsUser* self);
	gboolean (*get_Locked) (BoxesFdoAccountsUser* self);
	gboolean (*get_SystemAccount) (BoxesFdoAccountsUser* self);
	gint32 (*get_AccountType) (BoxesFdoAccountsUser* self);
	gint32 (*get_PasswordMode) (BoxesFdoAccountsUser* self);
	gchar* (*get_Email) (BoxesFdoAccountsUser* self);
	gchar* (*get_HomeDirectory) (BoxesFdoAccountsUser* self);
	gchar* (*get_IconFile) (BoxesFdoAccountsUser* self);
	gchar* (*get_Language) (BoxesFdoAccountsUser* self);
	gchar* (*get_Location) (BoxesFdoAccountsUser* self);
	gchar* (*get_RealName) (BoxesFdoAccountsUser* self);
	gchar* (*get_Shell) (BoxesFdoAccountsUser* self);
	gchar* (*get_UserName) (BoxesFdoAccountsUser* self);
	gchar* (*get_XSession) (BoxesFdoAccountsUser* self);
};

struct _BoxesCheckCpuVtCapabilityData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* _tmp0_;
	GFile* file;
	GFile* _tmp1_;
	GFileInputStream* _tmp2_;
	GFileInputStream* _tmp3_;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	GDataInputStream* stream;
	gchar* line;
	GDataInputStream* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

struct _BoxesCheckModuleKvmLoadedData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gboolean result;
	gboolean _result_;
	GFile* _tmp0_;
	GFile* file;
	GFile* _tmp1_;
	GFileInputStream* _tmp2_;
	GFileInputStream* _tmp3_;
	GFileInputStream* _tmp4_;
	GDataInputStream* _tmp5_;
	GDataInputStream* _tmp6_;
	GDataInputStream* stream;
	gchar* line;
	GDataInputStream* _tmp7_;
	gchar* _tmp8_;
	gchar* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gboolean _tmp12_;
	gboolean _tmp13_;
	GError* _error_;
	const gchar* _tmp14_;
	gboolean _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar* _tmp19_;
	GError * _inner_error_;
};

typedef void (*BoxesRunInThreadFunc) (void* user_data, GError** error);
struct _Block30Data {
	int _ref_count_;
	GError* e;
	BoxesRunInThreadFunc func;
	gpointer func_target;
	gpointer _async_data_;
};

struct _BoxesRunInThreadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesRunInThreadFunc func;
	gpointer func_target;
	GCancellable* cancellable;
	Block30Data* _data30_;
	BoxesRunInThreadFunc _tmp0_;
	void* _tmp0__target;
	GCancellable* _tmp1_;
	GError* _tmp2_;
	GError* _tmp3_;
	GError* _tmp4_;
	GError * _inner_error_;
};

struct _Block31Data {
	int _ref_count_;
	gchar** argv;
	gint argv_length1;
	gpointer _async_data_;
};

struct _BoxesExecData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar** argv;
	gint argv_length1;
	GCancellable* cancellable;
	Block31Data* _data31_;
	gchar** _tmp0_;
	gint _tmp0__length1;
	GError * _inner_error_;
};

struct _Block32Data {
	int _ref_count_;
	GtkWidget* widget;
};


extern BoxesApp* boxes_app_app;
static gpointer boxes_pair_parent_class = NULL;
static gpointer boxes_query_parent_class = NULL;

GQuark boxes_error_quark (void);
gchar* boxes_get_pkgdata (const gchar* file_name);
gchar* boxes_get_style (const gchar* file_name);
gchar* boxes_get_pixmap (const gchar* file_name);
gchar* boxes_get_unattended (const gchar* file_name);
gchar* boxes_get_pkgdata_source (const gchar* file_name);
gchar* boxes_get_user_unattended (const gchar* file_name);
gchar* boxes_get_user_pkgconfig (const gchar* file_name);
void boxes_ensure_directory (const gchar* dir);
gchar* boxes_get_user_pkgcache (const gchar* file_name);
gchar* boxes_get_user_pkgdata (const gchar* file_name);
gboolean boxes_has_user_pkgconfig_sources (void);
gchar* boxes_get_user_pkgconfig_source (const gchar* file_name);
void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result);
void boxes_get_boxes_bg_color (GdkRGBA* result);
void boxes_get_color (const gchar* desc, GdkColor* result);
void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate);
static Block27Data* block27_data_ref (Block27Data* _data27_);
static void block27_data_unref (void * _userdata_);
static gboolean ____lambda43_ (Block27Data* _data27_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda43__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate);
static Block28Data* block28_data_ref (Block28Data* _data28_);
static void block28_data_unref (void * _userdata_);
static gboolean ____lambda8_ (Block28Data* _data28_, GtkWidget* w, GdkEventButton* event);
static gboolean _____lambda8__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self);
static void boxes_output_stream_write_data_free (gpointer _data);
void boxes_output_stream_write (GOutputStream* stream, guint8* buffer, int buffer_length1, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_output_stream_write_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_output_stream_write_co (BoxesOutputStreamWriteData* _data_);
static void boxes_output_stream_write_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
gboolean boxes_keyfile_save (GKeyFile* key_file, const gchar* file_name, gboolean overwrite);
gchar* boxes_replace_regex (const gchar* str, const gchar* old, const gchar* replacement);
gchar* boxes_make_filename (const gchar* name);
void boxes_fade_actor (ClutterActor* actor, guint opacity);
static Block29Data* block29_data_ref (Block29Data* _data29_);
static void block29_data_unref (void * _userdata_);
GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_app_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static void __lambda82_ (Block29Data* _data29_);
static void ___lambda82__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self);
void boxes_actor_add (ClutterActor* actor, ClutterActor* container);
void boxes_actor_remove (ClutterActor* actor);
OsinfoDevice* boxes_get_os_device_by_prop (OsinfoOs* os, const gchar* prop_name, const gchar* prop_value);
GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size);
void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size);
gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1);
gint boxes_get_enum_value (const gchar* value_nick, GType enum_type);
static GEnumValue* _g_enum_value_dup (GEnumValue* self);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain, GVirStoragePool** pool);
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
#define BOXES_PAIR_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_PAIR, BoxesPairPrivate))
enum  {
	BOXES_PAIR_DUMMY_PROPERTY
};
BoxesPair* boxes_pair_new (GType t1_type, GBoxedCopyFunc t1_dup_func, GDestroyNotify t1_destroy_func, GType t2_type, GBoxedCopyFunc t2_dup_func, GDestroyNotify t2_destroy_func, gconstpointer first, gconstpointer second);
BoxesPair* boxes_pair_construct (GType object_type, GType t1_type, GBoxedCopyFunc t1_dup_func, GDestroyNotify t1_destroy_func, GType t2_type, GBoxedCopyFunc t2_dup_func, GDestroyNotify t2_destroy_func, gconstpointer first, gconstpointer second);
static void boxes_pair_finalize (BoxesPair* obj);
GType boxes_query_get_type (void) G_GNUC_CONST;
#define BOXES_QUERY_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_QUERY, BoxesQueryPrivate))
enum  {
	BOXES_QUERY_DUMMY_PROPERTY
};
BoxesQuery* boxes_query_new (const gchar* query);
BoxesQuery* boxes_query_construct (GType object_type, const gchar* query);
void boxes_query_parse (BoxesQuery* self);
gchar* boxes_query_get (BoxesQuery* self, const gchar* key);
static GObject * boxes_query_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static void _g_free0_ (gpointer var);
static void boxes_query_finalize (GObject* obj);
GType boxes_fdo_accounts_proxy_get_type (void) G_GNUC_CONST;
guint boxes_fdo_accounts_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
GType boxes_fdo_accounts_get_type (void) G_GNUC_CONST;
void boxes_fdo_accounts_FindUserByName (BoxesFdoAccounts* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar* boxes_fdo_accounts_FindUserByName_finish (BoxesFdoAccounts* self, GAsyncResult* _res_, GError** error);
static void boxes_fdo_accounts_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static void _vala_g_async_ready_callback (GObject *source_object, GAsyncResult *res, void *user_data);
static void boxes_fdo_accounts_proxy_FindUserByName_async (BoxesFdoAccounts* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gchar* boxes_fdo_accounts_proxy_FindUserByName_finish (BoxesFdoAccounts* self, GAsyncResult* _res_, GError** error);
static void boxes_fdo_accounts_proxy_boxes_fdo_accounts_interface_init (BoxesFdoAccountsIface* iface);
static void _dbus_boxes_fdo_accounts_FindUserByName (BoxesFdoAccounts* self, GVariant* parameters, GDBusMethodInvocation* invocation);
static void _dbus_boxes_fdo_accounts_FindUserByName_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_);
static void boxes_fdo_accounts_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_fdo_accounts_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static gboolean boxes_fdo_accounts_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _boxes_fdo_accounts_unregister_object (gpointer user_data);
GType boxes_fdo_accounts_user_get_type (void) G_GNUC_CONST;
GType boxes_fdo_accounts_user_proxy_get_type (void) G_GNUC_CONST;
guint boxes_fdo_accounts_user_register_object (void* object, GDBusConnection* connection, const gchar* path, GError** error);
gboolean boxes_fdo_accounts_user_get_AutomaticLogin (BoxesFdoAccountsUser* self);
gboolean boxes_fdo_accounts_user_get_Locked (BoxesFdoAccountsUser* self);
gboolean boxes_fdo_accounts_user_get_SystemAccount (BoxesFdoAccountsUser* self);
gint32 boxes_fdo_accounts_user_get_AccountType (BoxesFdoAccountsUser* self);
gint32 boxes_fdo_accounts_user_get_PasswordMode (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_Email (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_HomeDirectory (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_IconFile (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_Language (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_Location (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_RealName (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_Shell (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_UserName (BoxesFdoAccountsUser* self);
gchar* boxes_fdo_accounts_user_get_XSession (BoxesFdoAccountsUser* self);
static void boxes_fdo_accounts_user_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters);
static gboolean boxes_fdo_accounts_user_dbus_proxy_get_AutomaticLogin (BoxesFdoAccountsUser* self);
static gboolean boxes_fdo_accounts_user_dbus_proxy_get_Locked (BoxesFdoAccountsUser* self);
static gboolean boxes_fdo_accounts_user_dbus_proxy_get_SystemAccount (BoxesFdoAccountsUser* self);
static gint32 boxes_fdo_accounts_user_dbus_proxy_get_AccountType (BoxesFdoAccountsUser* self);
static gint32 boxes_fdo_accounts_user_dbus_proxy_get_PasswordMode (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Email (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_HomeDirectory (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_IconFile (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Language (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Location (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_RealName (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Shell (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_UserName (BoxesFdoAccountsUser* self);
static gchar* boxes_fdo_accounts_user_dbus_proxy_get_XSession (BoxesFdoAccountsUser* self);
static void boxes_fdo_accounts_user_proxy_boxes_fdo_accounts_user_interface_init (BoxesFdoAccountsUserIface* iface);
static void boxes_fdo_accounts_user_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data);
static GVariant* boxes_fdo_accounts_user_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data);
static GVariant* _dbus_boxes_fdo_accounts_user_get_AutomaticLogin (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_Locked (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_SystemAccount (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_AccountType (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_PasswordMode (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_Email (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_HomeDirectory (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_IconFile (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_Language (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_Location (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_RealName (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_Shell (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_UserName (BoxesFdoAccountsUser* self);
static GVariant* _dbus_boxes_fdo_accounts_user_get_XSession (BoxesFdoAccountsUser* self);
static gboolean boxes_fdo_accounts_user_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data);
static void _boxes_fdo_accounts_user_unregister_object (gpointer user_data);
gchar* boxes_yes_no (gboolean value);
static void boxes_check_cpu_vt_capability_data_free (gpointer _data);
void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_);
static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_);
static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_check_module_kvm_loaded_data_free (gpointer _data);
void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_);
gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_);
static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_);
static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_run_in_thread_data_free (gpointer _data);
void boxes_run_in_thread (BoxesRunInThreadFunc func, void* func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_run_in_thread_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_run_in_thread_co (BoxesRunInThreadData* _data_);
static Block30Data* block30_data_ref (Block30Data* _data30_);
static void block30_data_unref (void * _userdata_);
static gboolean __lambda45_ (Block30Data* _data30_, GIOSchedulerJob* job, GCancellable* cancellable);
static gboolean __lambda46_ (Block30Data* _data30_);
static gboolean ___lambda46__gsource_func (gpointer self);
static gboolean ___lambda45__gio_scheduler_job_func (GIOSchedulerJob* job, GCancellable* cancellable, gpointer self);
static void boxes_exec_data_free (gpointer _data);
void boxes_exec (gchar** argv, int argv_length1, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_exec_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_exec_co (BoxesExecData* _data_);
static Block31Data* block31_data_ref (Block31Data* _data31_);
static void block31_data_unref (void * _userdata_);
static void __lambda47_ (Block31Data* _data31_, GError** error);
void boxes_exec_sync (gchar** argv, int argv_length1, GError** error);
static void ___lambda47__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_exec_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf);
static guint8* _vala_array_dup5 (guint8* self, int length);
void boxes_draw_as_css_box (GtkWidget* widget);
static Block32Data* block32_data_ref (Block32Data* _data32_);
static void block32_data_unref (void * _userdata_);
static gboolean __lambda96_ (Block32Data* _data32_, cairo_t* cr);
static gboolean ___lambda96__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self);
void boxes_delete_file (GFile* file, GError** error);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);
static gint _vala_array_length (gpointer array);

static const GDBusArgInfo _boxes_fdo_accounts_dbus_arg_info_FindUserByName_name = {-1, "name", "s"};
static const GDBusArgInfo _boxes_fdo_accounts_dbus_arg_info_FindUserByName_result = {-1, "result", "s"};
static const GDBusArgInfo * const _boxes_fdo_accounts_dbus_arg_info_FindUserByName_in[] = {&_boxes_fdo_accounts_dbus_arg_info_FindUserByName_name, NULL};
static const GDBusArgInfo * const _boxes_fdo_accounts_dbus_arg_info_FindUserByName_out[] = {&_boxes_fdo_accounts_dbus_arg_info_FindUserByName_result, NULL};
static const GDBusMethodInfo _boxes_fdo_accounts_dbus_method_info_FindUserByName = {-1, "FindUserByName", (GDBusArgInfo **) (&_boxes_fdo_accounts_dbus_arg_info_FindUserByName_in), (GDBusArgInfo **) (&_boxes_fdo_accounts_dbus_arg_info_FindUserByName_out)};
static const GDBusMethodInfo * const _boxes_fdo_accounts_dbus_method_info[] = {&_boxes_fdo_accounts_dbus_method_info_FindUserByName, NULL};
static const GDBusSignalInfo * const _boxes_fdo_accounts_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo * const _boxes_fdo_accounts_dbus_property_info[] = {NULL};
static const GDBusInterfaceInfo _boxes_fdo_accounts_dbus_interface_info = {-1, "org.freedesktop.Accounts", (GDBusMethodInfo **) (&_boxes_fdo_accounts_dbus_method_info), (GDBusSignalInfo **) (&_boxes_fdo_accounts_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_fdo_accounts_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_fdo_accounts_dbus_interface_vtable = {boxes_fdo_accounts_dbus_interface_method_call, boxes_fdo_accounts_dbus_interface_get_property, boxes_fdo_accounts_dbus_interface_set_property};
static const GDBusMethodInfo * const _boxes_fdo_accounts_user_dbus_method_info[] = {NULL};
static const GDBusSignalInfo * const _boxes_fdo_accounts_user_dbus_signal_info[] = {NULL};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_AutomaticLogin = {-1, "AutomaticLogin", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_Locked = {-1, "Locked", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_SystemAccount = {-1, "SystemAccount", "b", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_AccountType = {-1, "AccountType", "i", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_PasswordMode = {-1, "PasswordMode", "i", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_Email = {-1, "Email", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_HomeDirectory = {-1, "HomeDirectory", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_IconFile = {-1, "IconFile", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_Language = {-1, "Language", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_Location = {-1, "Location", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_RealName = {-1, "RealName", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_Shell = {-1, "Shell", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_UserName = {-1, "UserName", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo _boxes_fdo_accounts_user_dbus_property_info_XSession = {-1, "XSession", "s", G_DBUS_PROPERTY_INFO_FLAGS_READABLE};
static const GDBusPropertyInfo * const _boxes_fdo_accounts_user_dbus_property_info[] = {&_boxes_fdo_accounts_user_dbus_property_info_AutomaticLogin, &_boxes_fdo_accounts_user_dbus_property_info_Locked, &_boxes_fdo_accounts_user_dbus_property_info_SystemAccount, &_boxes_fdo_accounts_user_dbus_property_info_AccountType, &_boxes_fdo_accounts_user_dbus_property_info_PasswordMode, &_boxes_fdo_accounts_user_dbus_property_info_Email, &_boxes_fdo_accounts_user_dbus_property_info_HomeDirectory, &_boxes_fdo_accounts_user_dbus_property_info_IconFile, &_boxes_fdo_accounts_user_dbus_property_info_Language, &_boxes_fdo_accounts_user_dbus_property_info_Location, &_boxes_fdo_accounts_user_dbus_property_info_RealName, &_boxes_fdo_accounts_user_dbus_property_info_Shell, &_boxes_fdo_accounts_user_dbus_property_info_UserName, &_boxes_fdo_accounts_user_dbus_property_info_XSession, NULL};
static const GDBusInterfaceInfo _boxes_fdo_accounts_user_dbus_interface_info = {-1, "org.freedesktop.Accounts.User", (GDBusMethodInfo **) (&_boxes_fdo_accounts_user_dbus_method_info), (GDBusSignalInfo **) (&_boxes_fdo_accounts_user_dbus_signal_info), (GDBusPropertyInfo **) (&_boxes_fdo_accounts_user_dbus_property_info)};
static const GDBusInterfaceVTable _boxes_fdo_accounts_user_dbus_interface_vtable = {boxes_fdo_accounts_user_dbus_interface_method_call, boxes_fdo_accounts_user_dbus_interface_get_property, boxes_fdo_accounts_user_dbus_interface_set_property};
static GRegex* _tmp_regex_0 = NULL;
static GRegex* _tmp_regex_1 = NULL;

GQuark boxes_error_quark (void) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return g_quark_from_static_string ("boxes_error-quark");
#line 746 "util.c"
}


gchar* boxes_get_pkgdata (const gchar* file_name) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_ = NULL;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = file_name;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_build_filename (DATADIR, PACKAGE_TARNAME, _tmp0_, NULL);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp1_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 762 "util.c"
}


gchar* boxes_get_style (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_pkgdata (NULL);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (_tmp1_, "style", _tmp2_, NULL);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = _tmp3_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp4_;
#line 18 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 789 "util.c"
}


gchar* boxes_get_pixmap (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_pkgdata (NULL);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (_tmp1_, "pixmaps", _tmp2_, NULL);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = _tmp3_;
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp4_;
#line 22 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 816 "util.c"
}


gchar* boxes_get_unattended (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	gchar* dir;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_pkgdata (NULL);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_build_filename (_tmp1_, "unattended", NULL);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 26 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp3_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = file_name;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = g_build_filename (dir, _tmp4_, NULL);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp5_;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 851 "util.c"
}


gchar* boxes_get_pkgdata_source (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* _tmp4_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_pkgdata (NULL);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (_tmp1_, "sources", _tmp2_, NULL);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = _tmp3_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp4_;
#line 32 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 878 "util.c"
}


gchar* boxes_get_user_unattended (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	gchar* dir;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_user_pkgconfig (NULL);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_build_filename (_tmp1_, "unattended", NULL);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp3_;
#line 38 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_ensure_directory (dir);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = file_name;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = g_build_filename (dir, _tmp4_, NULL);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp5_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 915 "util.c"
}


gchar* boxes_get_user_pkgcache (const gchar* file_name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* dir;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = g_get_user_cache_dir ();
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_build_filename (_tmp0_, PACKAGE_TARNAME, NULL);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp1_;
#line 46 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_ensure_directory (dir);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (dir, _tmp2_, NULL);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp3_;
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 48 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 944 "util.c"
}


gchar* boxes_get_user_pkgconfig (const gchar* file_name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* dir;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = g_get_user_config_dir ();
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_build_filename (_tmp0_, PACKAGE_TARNAME, NULL);
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp1_;
#line 54 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_ensure_directory (dir);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (dir, _tmp2_, NULL);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp3_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 973 "util.c"
}


gchar* boxes_get_user_pkgdata (const gchar* file_name) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	gchar* dir;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = g_get_user_data_dir ();
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_build_filename (_tmp0_, PACKAGE_TARNAME, NULL);
#line 60 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp1_;
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_ensure_directory (dir);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = file_name;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_build_filename (dir, _tmp2_, NULL);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp3_;
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 64 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1002 "util.c"
}


gboolean boxes_has_user_pkgconfig_sources (void) {
	gboolean result = FALSE;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_user_pkgconfig (NULL);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_build_filename (_tmp1_, "sources", NULL);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = g_file_test (_tmp3_, G_FILE_TEST_IS_DIR);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = _tmp4_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp3_);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp5_;
#line 68 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1034 "util.c"
}


gchar* boxes_get_user_pkgconfig_source (const gchar* file_name) {
	gchar* result = NULL;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	gchar* dir;
	const gchar* _tmp4_;
	gchar* _tmp5_ = NULL;
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = boxes_get_user_pkgconfig (NULL);
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_;
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_build_filename (_tmp1_, "sources", NULL);
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp1_);
#line 72 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dir = _tmp3_;
#line 74 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_ensure_directory (dir);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = file_name;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = g_build_filename (dir, _tmp4_, NULL);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp5_;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (dir);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1071 "util.c"
}


void boxes_ensure_directory (const gchar* dir) {
	GError * _inner_error_ = NULL;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (dir != NULL);
#line 1079 "util.c"
	{
		const gchar* _tmp0_;
		GFile* _tmp1_ = NULL;
		GFile* file;
		GFile* _tmp2_;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = dir;
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp1_ = g_file_new_for_path (_tmp0_);
#line 81 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		file = _tmp1_;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = file;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_file_make_directory_with_parents (_tmp2_, NULL, &_inner_error_);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_object_unref0 (file);
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_EXISTS)) {
#line 1101 "util.c"
				goto __catch58_g_io_error_exists;
			}
			goto __catch58_g_error;
		}
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (file);
#line 1108 "util.c"
	}
	goto __finally58;
	__catch58_g_io_error_exists:
	{
		GError* _error_ = NULL;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_error_ = _inner_error_;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_error_);
#line 1120 "util.c"
	}
	goto __finally58;
	__catch58_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp3_;
		const gchar* _tmp4_;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_error_ = _inner_error_;
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = _error_;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = _tmp3_->message;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_warning ("util.vala:85: %s", _tmp4_);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_error_);
#line 1140 "util.c"
	}
	__finally58:
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_clear_error (&_inner_error_);
#line 80 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 1151 "util.c"
	}
}


void boxes_gdk_rgba_to_clutter_color (GdkRGBA* gdk_rgba, ClutterColor* result) {
	GdkRGBA _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_ = 0.0;
	GdkRGBA _tmp3_;
	gdouble _tmp4_;
	gdouble _tmp5_ = 0.0;
	GdkRGBA _tmp6_;
	gdouble _tmp7_;
	gdouble _tmp8_ = 0.0;
	GdkRGBA _tmp9_;
	gdouble _tmp10_;
	gdouble _tmp11_ = 0.0;
	ClutterColor _tmp12_ = {0};
	ClutterColor color;
#line 89 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (gdk_rgba != NULL);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = *gdk_rgba;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_.red;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = CLAMP (_tmp1_ * 255, (gdouble) 0, (gdouble) 255);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = *gdk_rgba;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = _tmp3_.green;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = CLAMP (_tmp4_ * 255, (gdouble) 0, (gdouble) 255);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = *gdk_rgba;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp6_.blue;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = CLAMP (_tmp7_ * 255, (gdouble) 0, (gdouble) 255);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = *gdk_rgba;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = _tmp9_.alpha;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = CLAMP (_tmp10_ * 255, (gdouble) 0, (gdouble) 255);
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_.red = (guint8) _tmp2_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_.green = (guint8) _tmp5_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_.blue = (guint8) _tmp8_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_.alpha = (guint8) _tmp11_;
#line 90 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	color = _tmp12_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	*result = color;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return;
#line 1211 "util.c"
}


void boxes_get_boxes_bg_color (GdkRGBA* result) {
	GtkStyleContext* _tmp0_;
	GtkStyleContext* style;
	GtkWidgetPath* _tmp1_;
	GtkWidgetPath* path;
	GdkRGBA _tmp2_ = {0};
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = gtk_style_context_new ();
#line 101 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	style = _tmp0_;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = gtk_widget_path_new ();
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	path = _tmp1_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_widget_path_append_type (path, GTK_TYPE_WINDOW);
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_style_context_set_path (style, path);
#line 105 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_style_context_add_class (style, "boxes-bg");
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_style_context_get_background_color (style, 0, &_tmp2_);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	*result = _tmp2_;
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_gtk_widget_path_unref0 (path);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (style);
#line 106 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return;
#line 1245 "util.c"
}


void boxes_get_color (const gchar* desc, GdkColor* result) {
	GdkColor color = {0};
	const gchar* _tmp0_;
	GdkColor _tmp1_ = {0};
#line 109 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (desc != NULL);
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = desc;
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gdk_color_parse (_tmp0_, &_tmp1_);
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	color = _tmp1_;
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	*result = color;
#line 112 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return;
#line 1265 "util.c"
}


static gpointer _g_object_ref0 (gpointer self) {
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self ? g_object_ref (self) : NULL;
#line 1272 "util.c"
}


static Block27Data* block27_data_ref (Block27Data* _data27_) {
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data27_->_ref_count_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data27_;
#line 1281 "util.c"
}


static void block27_data_unref (void * _userdata_) {
	Block27Data* _data27_;
	_data27_ = (Block27Data*) _userdata_;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data27_->_ref_count_)) {
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data27_->tree_view);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block27Data, _data27_);
#line 1294 "util.c"
	}
}


static gboolean ____lambda43_ (Block27Data* _data27_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GtkTreeViewColumn* column = NULL;
	gint x = 0;
	gint y = 0;
	gboolean _tmp0_ = FALSE;
	GdkEventButton _tmp1_;
	guint _tmp2_;
	gboolean _tmp5_;
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = *event;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _tmp1_.button;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp2_ == ((guint) 1)) {
#line 1319 "util.c"
		GdkEventButton _tmp3_;
		GdkEventType _tmp4_;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = *event;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = _tmp3_.type;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = _tmp4_ == GDK_BUTTON_PRESS;
#line 1328 "util.c"
	} else {
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = FALSE;
#line 1332 "util.c"
	}
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = _tmp0_;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp5_) {
#line 1338 "util.c"
		GtkTreeView* _tmp6_;
		GdkEventButton _tmp7_;
		gdouble _tmp8_;
		GdkEventButton _tmp9_;
		gdouble _tmp10_;
		GtkTreePath* _tmp11_ = NULL;
		GtkTreeViewColumn* _tmp12_ = NULL;
		gint _tmp13_ = 0;
		gint _tmp14_ = 0;
		GtkTreePath* _tmp15_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = _data27_->tree_view;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = *event;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _tmp7_.x;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = *event;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = _tmp9_.y;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		gtk_tree_view_get_path_at_pos (_tmp6_, (gint) _tmp8_, (gint) _tmp10_, &_tmp11_, &_tmp12_, &_tmp13_, &_tmp14_);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_gtk_tree_path_free0 (path);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		path = _tmp11_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		column = _tmp12_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		x = _tmp13_;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		y = _tmp14_;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp15_ = path;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp15_ != NULL) {
#line 1375 "util.c"
			GtkTreeView* _tmp16_;
			GtkTreePath* _tmp17_;
			GtkTreeViewColumn* _tmp18_;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp16_ = _data27_->tree_view;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp17_ = path;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp18_ = column;
#line 130 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			gtk_tree_view_row_activated (_tmp16_, _tmp17_, _tmp18_);
#line 1387 "util.c"
		}
	}
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = FALSE;
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_gtk_tree_path_free0 (path);
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1396 "util.c"
}


static gboolean _____lambda43__gtk_widget_button_press_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda43_ (self, _sender, event);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1405 "util.c"
}


void boxes_tree_view_activate_on_single_click (GtkTreeView* tree_view, gboolean should_activate) {
	Block27Data* _data27_;
	GtkTreeView* _tmp0_;
	GtkTreeView* _tmp1_;
	GtkTreeView* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	gulong id;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_;
	gboolean _tmp7_;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (tree_view != NULL);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data27_ = g_slice_new0 (Block27Data);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data27_->_ref_count_ = 1;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = tree_view;
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data27_->tree_view = _tmp1_;
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _data27_->tree_view;
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-tree-view-activate");
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	id = GPOINTER_TO_UINT (_tmp3_);
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = id;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 1441 "util.c"
		gboolean _tmp6_;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = should_activate;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 1447 "util.c"
	} else {
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = FALSE;
#line 1451 "util.c"
	}
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp4_;
#line 118 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp7_) {
#line 1457 "util.c"
		GtkTreeView* _tmp8_;
		gulong _tmp9_;
		GtkTreeView* _tmp10_;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _data27_->tree_view;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = id;
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = _data27_->tree_view;
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-tree-view-activate", GUINT_TO_POINTER ((gulong) 0), NULL);
#line 1471 "util.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_;
		gboolean _tmp14_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp12_ = id;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 1480 "util.c"
			gboolean _tmp13_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp13_ = should_activate;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp11_ = _tmp13_;
#line 1486 "util.c"
		} else {
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp11_ = FALSE;
#line 1490 "util.c"
		}
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = _tmp11_;
#line 121 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp14_) {
#line 1496 "util.c"
			GtkTreeView* _tmp15_;
			gulong _tmp16_ = 0UL;
			GtkTreeView* _tmp17_;
			gulong _tmp18_;
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp15_ = _data27_->tree_view;
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-press-event", (GCallback) _____lambda43__gtk_widget_button_press_event, block27_data_ref (_data27_), (GClosureNotify) block27_data_unref, 0);
#line 122 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			id = _tmp16_;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp17_ = _data27_->tree_view;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp18_ = id;
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-tree-view-activate", GUINT_TO_POINTER (_tmp18_), NULL);
#line 1513 "util.c"
		}
	}
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block27_data_unref (_data27_);
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data27_ = NULL;
#line 1520 "util.c"
}


static Block28Data* block28_data_ref (Block28Data* _data28_) {
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data28_->_ref_count_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data28_;
#line 1529 "util.c"
}


static void block28_data_unref (void * _userdata_) {
	Block28Data* _data28_;
	_data28_ = (Block28Data*) _userdata_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data28_->_ref_count_)) {
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data28_->icon_view);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block28Data, _data28_);
#line 1542 "util.c"
	}
}


static gpointer _gtk_tree_path_copy0 (gpointer self) {
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self ? gtk_tree_path_copy (self) : NULL;
#line 1550 "util.c"
}


static gboolean ____lambda8_ (Block28Data* _data28_, GtkWidget* w, GdkEventButton* event) {
	gboolean result = FALSE;
	GtkTreePath* path = NULL;
	GdkEventButton _tmp0_;
	guint _tmp1_;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (w != NULL, FALSE);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (event != NULL, FALSE);
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = *event;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _tmp0_.button;
#line 149 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp1_ == ((guint) 1)) {
#line 1569 "util.c"
		GtkIconView* _tmp2_;
		GdkEventButton _tmp3_;
		gdouble _tmp4_;
		GdkEventButton _tmp5_;
		gdouble _tmp6_;
		GtkTreePath* _tmp7_ = NULL;
		GtkTreePath* _tmp8_;
		GtkTreePath* _tmp9_;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = _data28_->icon_view;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = *event;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = _tmp3_.x;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = *event;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = _tmp5_.y;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = gtk_icon_view_get_path_at_pos (_tmp2_, (gint) _tmp4_, (gint) _tmp6_);
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _gtk_tree_path_copy0 (_tmp7_);
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_gtk_tree_path_free0 (path);
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		path = _tmp8_;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = path;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp9_ != NULL) {
#line 1600 "util.c"
			GtkIconView* _tmp10_;
			GtkTreePath* _tmp11_;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp10_ = _data28_->icon_view;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp11_ = path;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			gtk_icon_view_item_activated (_tmp10_, _tmp11_);
#line 1609 "util.c"
		}
	}
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = FALSE;
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_gtk_tree_path_free0 (path);
#line 155 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1618 "util.c"
}


static gboolean _____lambda8__gtk_widget_button_release_event (GtkWidget* _sender, GdkEventButton* event, gpointer self) {
	gboolean result;
	result = ____lambda8_ (self, _sender, event);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 1627 "util.c"
}


void boxes_icon_view_activate_on_single_click (GtkIconView* icon_view, gboolean should_activate) {
	Block28Data* _data28_;
	GtkIconView* _tmp0_;
	GtkIconView* _tmp1_;
	GtkIconView* _tmp2_;
	gconstpointer _tmp3_ = NULL;
	gulong id;
	gboolean _tmp4_ = FALSE;
	gulong _tmp5_;
	gboolean _tmp7_;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (icon_view != NULL);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data28_ = g_slice_new0 (Block28Data);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data28_->_ref_count_ = 1;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = icon_view;
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data28_->icon_view = _tmp1_;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _data28_->icon_view;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_object_get_data ((GObject*) _tmp2_, "boxes-icon-view-activate");
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	id = GPOINTER_TO_UINT (_tmp3_);
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = id;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp5_ != ((gulong) 0)) {
#line 1663 "util.c"
		gboolean _tmp6_;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = should_activate;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = _tmp6_ == FALSE;
#line 1669 "util.c"
	} else {
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = FALSE;
#line 1673 "util.c"
	}
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp4_;
#line 142 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp7_) {
#line 1679 "util.c"
		GtkIconView* _tmp8_;
		gulong _tmp9_;
		GtkIconView* _tmp10_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _data28_->icon_view;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = id;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_signal_handler_disconnect ((GObject*) _tmp8_, _tmp9_);
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = _data28_->icon_view;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_object_set_data_full ((GObject*) _tmp10_, "boxes-icon-view-activate", GUINT_TO_POINTER ((gulong) 0), NULL);
#line 1693 "util.c"
	} else {
		gboolean _tmp11_ = FALSE;
		gulong _tmp12_;
		gboolean _tmp14_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp12_ = id;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp12_ == ((gulong) 0)) {
#line 1702 "util.c"
			gboolean _tmp13_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp13_ = should_activate;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp11_ = _tmp13_;
#line 1708 "util.c"
		} else {
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp11_ = FALSE;
#line 1712 "util.c"
		}
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = _tmp11_;
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp14_) {
#line 1718 "util.c"
			GtkIconView* _tmp15_;
			gulong _tmp16_ = 0UL;
			GtkIconView* _tmp17_;
			gulong _tmp18_;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp15_ = _data28_->icon_view;
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp16_ = g_signal_connect_data ((GtkWidget*) _tmp15_, "button-release-event", (GCallback) _____lambda8__gtk_widget_button_release_event, block28_data_ref (_data28_), (GClosureNotify) block28_data_unref, 0);
#line 146 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			id = _tmp16_;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp17_ = _data28_->icon_view;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp18_ = id;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_object_set_data_full ((GObject*) _tmp17_, "boxes-icon-view-activate", GUINT_TO_POINTER (_tmp18_), NULL);
#line 1735 "util.c"
		}
	}
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block28_data_unref (_data28_);
#line 139 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data28_ = NULL;
#line 1742 "util.c"
}


static void boxes_output_stream_write_data_free (gpointer _data) {
	BoxesOutputStreamWriteData* _data_;
	_data_ = _data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->stream);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesOutputStreamWriteData, _data_);
#line 1753 "util.c"
}


void boxes_output_stream_write (GOutputStream* stream, guint8* buffer, int buffer_length1, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesOutputStreamWriteData* _data_;
	GOutputStream* _tmp0_;
	GOutputStream* _tmp1_;
	guint8* _tmp2_;
	gint _tmp2__length1;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesOutputStreamWriteData);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_output_stream_write);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_output_stream_write_data_free);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = stream;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->stream = _tmp1_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = buffer;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2__length1 = buffer_length1;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = _tmp2_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = _tmp2__length1;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_output_stream_write_co (_data_);
#line 1785 "util.c"
}


void boxes_output_stream_write_finish (GAsyncResult* _res_, GError** error) {
	BoxesOutputStreamWriteData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1795 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1799 "util.c"
}


static void boxes_output_stream_write_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesOutputStreamWriteData* _data_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_ = _user_data_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_source_object_ = source_object;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_res_ = _res_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_output_stream_write_co (_data_);
#line 1813 "util.c"
}


static gboolean boxes_output_stream_write_co (BoxesOutputStreamWriteData* _data_) {
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	switch (_data_->_state_) {
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 0:
#line 1822 "util.c"
		goto _state_0;
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 1:
#line 1826 "util.c"
		goto _state_1;
		default:
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_assert_not_reached ();
#line 1831 "util.c"
	}
	_state_0:
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = _data_->buffer;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0__length1 = _data_->buffer_length1;
#line 162 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->length = _data_->_tmp0__length1;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->i = (gssize) 0;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	while (TRUE) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp1_ = _data_->i;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp2_ = _data_->length;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (!(_data_->_tmp1_ < ((gssize) _data_->_tmp2_))) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			break;
#line 1852 "util.c"
		}
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp3_ = _data_->stream;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp4_ = _data_->buffer;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp4__length1 = _data_->buffer_length1;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp5_ = _data_->i;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp6_ = _data_->length;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_state_ = 1;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_output_stream_write_async (_data_->_tmp3_, _data_->_tmp4_ + _data_->_tmp5_, (gsize) (_data_->_tmp6_ - _data_->_tmp5_), G_PRIORITY_DEFAULT, NULL, boxes_output_stream_write_ready, _data_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 1870 "util.c"
		_state_1:
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp7_ = 0L;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp7_ = g_output_stream_write_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp8_ = _data_->_tmp7_;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_data_->_inner_error_ != NULL) {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_data_->_inner_error_->domain == G_IO_ERROR) {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_error_free (_data_->_inner_error_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (_data_->_state_ == 0) {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1890 "util.c"
				} else {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 1894 "util.c"
				}
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_object_unref (_data_->_async_result);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				return FALSE;
#line 1900 "util.c"
			} else {
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_clear_error (&_data_->_inner_error_);
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				return FALSE;
#line 1908 "util.c"
			}
		}
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp9_ = _data_->i;
#line 166 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->i = _data_->_tmp9_ + _data_->_tmp8_;
#line 1915 "util.c"
	}
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1921 "util.c"
	} else {
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1925 "util.c"
	}
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 161 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 1931 "util.c"
}


gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error) {
	gchar* result = NULL;
	xmlParserCtxt* _tmp0_;
	xmlParserCtxt* parser;
	xmlParserCtxt* _tmp1_;
	const gchar* _tmp2_;
	xmlDoc* _tmp3_ = NULL;
	xmlDoc* doc;
	xmlDoc* _tmp4_;
	xmlDoc* _tmp6_;
	xmlXPathContext* _tmp7_;
	xmlXPathContext* ctxt;
	xmlXPathContext* _tmp8_;
	const gchar* _tmp9_;
	xmlXPathObject* _tmp10_ = NULL;
	xmlXPathObject* obj;
	gboolean _tmp11_ = FALSE;
	xmlXPathObject* _tmp12_;
	gboolean _tmp15_;
	xmlXPathObject* _tmp22_;
	xmlXPathObjectType _tmp23_;
	xmlXPathObject* _tmp29_;
	const gchar* _tmp30_;
	gchar* _tmp31_;
	GError * _inner_error_ = NULL;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (xmldoc != NULL, NULL);
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (xpath != NULL, NULL);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = xmlNewParserCtxt ();
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	parser = _tmp0_;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = parser;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = xmldoc;
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = xmlCtxtReadDoc (_tmp1_, _tmp2_, "doc.xml", NULL, 0);
#line 171 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	doc = _tmp3_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = doc;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp4_ == NULL) {
#line 1980 "util.c"
		GError* _tmp5_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, "Can't parse XML doc");
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = _tmp5_;
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_propagate_error (error, _inner_error_);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlFreeParserCtxt0 (parser);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 1994 "util.c"
		} else {
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlFreeParserCtxt0 (parser);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_clear_error (&_inner_error_);
#line 174 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 2004 "util.c"
		}
	}
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = doc;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = xmlXPathNewContext (_tmp6_);
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	ctxt = _tmp7_;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = ctxt;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = xpath;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = xmlXPathEval (_tmp9_, _tmp8_);
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	obj = _tmp10_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_ = obj;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp12_ == NULL) {
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp11_ = TRUE;
#line 2027 "util.c"
	} else {
		xmlXPathObject* _tmp13_;
		const gchar* _tmp14_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp13_ = obj;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = _tmp13_->stringval;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp11_ = _tmp14_ == NULL;
#line 2037 "util.c"
	}
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp15_ = _tmp11_;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp15_) {
#line 2043 "util.c"
		gboolean _tmp16_;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp16_ = required;
#line 179 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp16_) {
#line 2049 "util.c"
			const gchar* _tmp17_;
			gchar* _tmp18_;
			gchar* _tmp19_;
			GError* _tmp20_;
			GError* _tmp21_;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp17_ = xpath;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp18_ = g_strconcat ("Failed to extract xpath ", _tmp17_, NULL);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp19_ = _tmp18_;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp20_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp19_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp21_ = _tmp20_;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_free0 (_tmp19_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_inner_error_ = _tmp21_;
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_inner_error_->domain == BOXES_ERROR) {
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_propagate_error (error, _inner_error_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_xmlFreeParserCtxt0 (parser);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				return NULL;
#line 2079 "util.c"
			} else {
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_xmlXPathFreeContext0 (ctxt);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_xmlFreeParserCtxt0 (parser);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_clear_error (&_inner_error_);
#line 180 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				return NULL;
#line 2091 "util.c"
			}
		} else {
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			result = NULL;
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlFreeParserCtxt0 (parser);
#line 182 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return result;
#line 2102 "util.c"
		}
	}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp22_ = obj;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp23_ = _tmp22_->type;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp23_ != XPATH_STRING) {
#line 2111 "util.c"
		const gchar* _tmp24_;
		gchar* _tmp25_;
		gchar* _tmp26_;
		GError* _tmp27_;
		GError* _tmp28_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp24_ = xpath;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp25_ = g_strconcat ("Failed to extract xpath ", _tmp24_, NULL);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp26_ = _tmp25_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp27_ = g_error_new_literal (BOXES_ERROR, BOXES_ERROR_INVALID, _tmp26_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp28_ = _tmp27_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp26_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = _tmp28_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_->domain == BOXES_ERROR) {
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_propagate_error (error, _inner_error_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlFreeParserCtxt0 (parser);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 2141 "util.c"
		} else {
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlXPathFreeContext0 (ctxt);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_xmlFreeParserCtxt0 (parser);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_clear_error (&_inner_error_);
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 2153 "util.c"
		}
	}
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp29_ = obj;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp30_ = _tmp29_->stringval;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp31_ = g_strdup (_tmp30_);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp31_;
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_xmlXPathFreeContext0 (ctxt);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_xmlFreeParserCtxt0 (parser);
#line 188 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 2170 "util.c"
}


gboolean boxes_keyfile_save (GKeyFile* key_file, const gchar* file_name, gboolean overwrite) {
	gboolean result = FALSE;
	GError * _inner_error_ = NULL;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (key_file != NULL, FALSE);
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (file_name != NULL, FALSE);
#line 2181 "util.c"
	{
		const gchar* _tmp0_;
		GFile* _tmp1_ = NULL;
		GFile* file;
		GFile* _tmp2_;
		gboolean _tmp3_ = FALSE;
		GFile* _tmp6_;
		GFileOutputStream* _tmp7_ = NULL;
		GFileOutputStream* _tmp8_;
		GFileOutputStream* _tmp9_;
		GDataOutputStream* _tmp10_;
		GDataOutputStream* _tmp11_;
		GDataOutputStream* stream;
		GDataOutputStream* _tmp12_;
		GKeyFile* _tmp13_;
		gchar* _tmp14_ = NULL;
		gchar* _tmp15_;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = file_name;
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp1_ = g_file_new_for_path (_tmp0_);
#line 193 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		file = _tmp1_;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = file;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = g_file_query_exists (_tmp2_, NULL);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_tmp3_) {
#line 2211 "util.c"
			gboolean _tmp4_;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp4_ = overwrite;
#line 196 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (!_tmp4_) {
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				result = FALSE;
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_object_unref0 (file);
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				return result;
#line 2223 "util.c"
			} else {
				GFile* _tmp5_;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp5_ = file;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_file_delete (_tmp5_, NULL, &_inner_error_);
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (_inner_error_ != NULL) {
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					_g_object_unref0 (file);
#line 2234 "util.c"
					goto __catch59_g_error;
				}
			}
		}
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = file;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = g_file_create (_tmp6_, G_FILE_CREATE_REPLACE_DESTINATION, NULL, &_inner_error_);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _tmp7_;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_object_unref0 (file);
#line 2249 "util.c"
			goto __catch59_g_error;
		}
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = _tmp8_;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = g_data_output_stream_new ((GOutputStream*) _tmp9_);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp11_ = _tmp10_;
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_tmp9_);
#line 201 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		stream = _tmp11_;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp12_ = stream;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp13_ = key_file;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = g_key_file_to_data (_tmp13_, NULL, NULL);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp15_ = _tmp14_;
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_data_output_stream_put_string (_tmp12_, _tmp15_, NULL, &_inner_error_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp15_);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_object_unref0 (stream);
#line 202 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_object_unref0 (file);
#line 2280 "util.c"
			goto __catch59_g_error;
		}
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = TRUE;
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (stream);
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (file);
#line 204 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 2291 "util.c"
	}
	goto __finally59;
	__catch59_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp16_;
		const gchar* _tmp17_;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_error_ = _inner_error_;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp16_ = _error_;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp17_ = _tmp16_->message;
#line 206 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_warning ("util.vala:206: %s", _tmp17_);
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = FALSE;
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_error_);
#line 207 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 2315 "util.c"
	}
	__finally59:
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_clear_error (&_inner_error_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 2324 "util.c"
}


gchar* boxes_replace_regex (const gchar* str, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (str != NULL, NULL);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (old != NULL, NULL);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (replacement != NULL, NULL);
#line 2337 "util.c"
	{
		const gchar* _tmp0_;
		GRegex* _tmp1_;
		GRegex* regex;
		GRegex* _tmp2_;
		const gchar* _tmp3_;
		const gchar* _tmp4_;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = old;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp1_ = g_regex_new (_tmp0_, 0, 0, &_inner_error_);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		regex = _tmp1_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2357 "util.c"
				goto __catch60_g_regex_error;
			}
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_clear_error (&_inner_error_);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 2366 "util.c"
		}
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = regex;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = str;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = replacement;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = g_regex_replace_literal (_tmp2_, _tmp3_, (gssize) (-1), 0, _tmp4_, 0, &_inner_error_);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = _tmp5_;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_regex_unref0 (regex);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_inner_error_->domain == G_REGEX_ERROR) {
#line 2384 "util.c"
				goto __catch60_g_regex_error;
			}
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_regex_unref0 (regex);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_clear_error (&_inner_error_);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return NULL;
#line 2395 "util.c"
		}
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = _tmp6_;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_regex_unref0 (regex);
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 2403 "util.c"
	}
	goto __finally60;
	__catch60_g_regex_error:
	{
		GError* _error_ = NULL;
		GError* _tmp7_;
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_error_ = _inner_error_;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = _error_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = _tmp7_->message;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("util.vala:216: %s", _tmp8_);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = str;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = g_strdup (_tmp9_);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = _tmp10_;
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_error_);
#line 217 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 2433 "util.c"
	}
	__finally60:
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_clear_error (&_inner_error_);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return NULL;
#line 2442 "util.c"
}


gchar* boxes_make_filename (const gchar* name) {
	gchar* result = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_ = NULL;
	gchar* filename;
	const gchar* _tmp2_;
	gchar* _tmp3_;
	gchar* tryname;
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (name != NULL, NULL);
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = name;
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = boxes_replace_regex (_tmp0_, "[\\\\/:()<>|?*]", "_");
#line 222 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	filename = _tmp1_;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = filename;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	tryname = _tmp3_;
#line 2468 "util.c"
	{
		gint i;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		i = 0;
#line 2473 "util.c"
		{
			gboolean _tmp4_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp4_ = TRUE;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			while (TRUE) {
#line 2480 "util.c"
				gboolean _tmp5_;
				const gchar* _tmp7_;
				gboolean _tmp8_ = FALSE;
				const gchar* _tmp9_;
				gint _tmp10_;
				gchar* _tmp11_ = NULL;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp5_ = _tmp4_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (!_tmp5_) {
#line 2491 "util.c"
					gint _tmp6_;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					_tmp6_ = i;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					i = _tmp6_ + 1;
#line 2497 "util.c"
				}
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp4_ = FALSE;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp7_ = tryname;
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp8_ = g_file_test (_tmp7_, G_FILE_TEST_EXISTS);
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (!_tmp8_) {
#line 225 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					break;
#line 2509 "util.c"
				}
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp9_ = filename;
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp10_ = i;
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp11_ = g_strdup_printf ("%s-%d", _tmp9_, _tmp10_);
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_free0 (tryname);
#line 226 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				tryname = _tmp11_;
#line 2521 "util.c"
			}
		}
	}
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = tryname;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (filename);
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 2531 "util.c"
}


static Block29Data* block29_data_ref (Block29Data* _data29_) {
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data29_->_ref_count_);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data29_;
#line 2540 "util.c"
}


static void block29_data_unref (void * _userdata_) {
	Block29Data* _data29_;
	_data29_ = (Block29Data*) _userdata_;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data29_->_ref_count_)) {
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data29_->actor);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block29Data, _data29_);
#line 2553 "util.c"
	}
}


static void __lambda82_ (Block29Data* _data29_) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_;
	guint _tmp2_;
	guint _tmp3_;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = _data29_->actor;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _data29_->actor;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = clutter_actor_get_opacity (_tmp1_);
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 243 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_set (_tmp0_, "visible", _tmp3_ != ((guint) 0), NULL);
#line 2573 "util.c"
}


static void ___lambda82__clutter_timeline_completed (ClutterTimeline* _sender, gpointer self) {
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	__lambda82_ (self);
#line 2580 "util.c"
}


void boxes_fade_actor (ClutterActor* actor, guint opacity) {
	Block29Data* _data29_;
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_;
	guint _tmp2_;
	ClutterActor* _tmp4_;
	guint _tmp5_;
	ClutterActor* _tmp6_;
	ClutterActor* _tmp7_;
	ClutterActor* _tmp8_;
	BoxesApp* _tmp9_;
	guint _tmp10_;
	ClutterActor* _tmp11_;
	guint _tmp12_;
	ClutterActor* _tmp13_;
	ClutterTransition* _tmp14_ = NULL;
	ClutterTransition* _tmp15_;
	ClutterTransition* t;
	ClutterActor* _tmp16_;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (actor != NULL);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data29_ = g_slice_new0 (Block29Data);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data29_->_ref_count_ = 1;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = actor;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data29_->actor = _tmp1_;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = opacity;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp2_ != ((guint) 0)) {
#line 2619 "util.c"
		ClutterActor* _tmp3_;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = _data29_->actor;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		clutter_actor_show (_tmp3_);
#line 2625 "util.c"
	}
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = _data29_->actor;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = opacity;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_set_reactive (_tmp4_, _tmp5_ == ((guint) 255));
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = _data29_->actor;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_save_easing_state (_tmp6_);
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _data29_->actor;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_set_easing_mode (_tmp7_, CLUTTER_EASE_OUT_QUAD);
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = _data29_->actor;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = boxes_app_app;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = _tmp9_->duration;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_set_easing_duration (_tmp8_, _tmp10_);
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = _data29_->actor;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_ = opacity;
#line 240 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_set_opacity (_tmp11_, _tmp12_);
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp13_ = _data29_->actor;
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp14_ = clutter_actor_get_transition (_tmp13_, "opacity");
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp15_ = _g_object_ref0 (_tmp14_);
#line 241 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	t = _tmp15_;
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_signal_connect_data ((ClutterTimeline*) t, "completed", (GCallback) ___lambda82__clutter_timeline_completed, block29_data_ref (_data29_), (GClosureNotify) block29_data_unref, 0);
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp16_ = _data29_->actor;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_restore_easing_state (_tmp16_);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (t);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block29_data_unref (_data29_);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data29_ = NULL;
#line 2675 "util.c"
}


void boxes_actor_add (ClutterActor* actor, ClutterActor* container) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_;
	ClutterActor* _tmp3_;
	ClutterActor* _tmp4_;
	ClutterActor* _tmp5_;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (actor != NULL);
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (container != NULL);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = actor;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = container;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp1_ == _tmp2_) {
#line 250 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 2700 "util.c"
	}
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = actor;
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_actor_remove (_tmp3_);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = container;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = actor;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_add_child (_tmp4_, _tmp5_);
#line 2712 "util.c"
}


void boxes_actor_remove (ClutterActor* actor) {
	ClutterActor* _tmp0_;
	ClutterActor* _tmp1_ = NULL;
	ClutterActor* _tmp2_;
	ClutterActor* container;
	ClutterActor* _tmp3_;
	ClutterActor* _tmp4_;
	ClutterActor* _tmp5_;
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (actor != NULL);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = actor;
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = clutter_actor_get_parent (_tmp0_);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	container = _tmp2_;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = container;
#line 259 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp3_ == NULL) {
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (container);
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 2742 "util.c"
	}
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = container;
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = actor;
#line 262 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	clutter_actor_remove_child (_tmp4_, _tmp5_);
#line 256 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (container);
#line 2752 "util.c"
}


OsinfoDevice* boxes_get_os_device_by_prop (OsinfoOs* os, const gchar* prop_name, const gchar* prop_value) {
	OsinfoDevice* result = NULL;
	OsinfoOs* _tmp0_;
	OsinfoOs* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	OsinfoDeviceList* _tmp4_ = NULL;
	OsinfoDeviceList* devices;
	OsinfoDevice* _tmp5_ = NULL;
	OsinfoDeviceList* _tmp6_;
	gint _tmp7_ = 0;
	OsinfoDevice* _tmp10_;
	OsinfoDevice* _tmp11_;
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (prop_name != NULL, NULL);
#line 265 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (prop_value != NULL, NULL);
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = os;
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp0_ == NULL) {
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = NULL;
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 2781 "util.c"
	}
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = os;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = prop_name;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = prop_value;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = osinfo_os_get_devices_by_property (_tmp1_, _tmp2_, _tmp3_, TRUE);
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	devices = _tmp4_;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = devices;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = osinfo_list_get_length ((OsinfoList*) _tmp6_);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp7_ > 0) {
#line 2799 "util.c"
		OsinfoDeviceList* _tmp8_;
		OsinfoEntity* _tmp9_ = NULL;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = devices;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = osinfo_list_get_nth ((OsinfoList*) _tmp8_, 0);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp9_, osinfo_device_get_type ()) ? ((OsinfoDevice*) _tmp9_) : NULL;
#line 2808 "util.c"
	} else {
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = NULL;
#line 2812 "util.c"
	}
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = _tmp5_;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = _g_object_ref0 (_tmp10_);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp11_;
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (devices);
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 2824 "util.c"
}


GtkImage* boxes_get_os_logo (OsinfoOs* os, gint size) {
	GtkImage* result = NULL;
	GtkImage* _tmp0_;
	GtkImage* image;
	GtkImage* _tmp1_;
	gint _tmp2_;
	OsinfoOs* _tmp3_;
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = (GtkImage*) gtk_image_new_from_icon_name ("media-optical", 0);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_ref_sink (_tmp0_);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	image = _tmp0_;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = image;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = size;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_image_set_pixel_size (_tmp1_, _tmp2_);
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = os;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp3_ != NULL) {
#line 2851 "util.c"
		GtkImage* _tmp4_;
		OsinfoOs* _tmp5_;
		gint _tmp6_;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = image;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = os;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = size;
#line 279 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		boxes_fetch_os_logo (_tmp4_, _tmp5_, _tmp6_);
#line 2863 "util.c"
	}
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = image;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 2869 "util.c"
}


void boxes_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size) {
	OsinfoOs* _tmp0_;
	gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gchar** _tmp4_ = NULL;
	gchar** _tmp5_;
	gint _tmp5__length1;
	gchar* _tmp6_ = NULL;
	gchar* _tmp7_;
	gchar* path;
	const gchar* _tmp8_;
	GError * _inner_error_ = NULL;
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (image != NULL);
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (os != NULL);
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = os;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_strdup (".svg");
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_strdup (".png");
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_strdup (".jpg");
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = g_new0 (gchar*, 3 + 1);
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_[0] = _tmp1_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_[1] = _tmp2_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_[2] = _tmp3_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = _tmp4_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5__length1 = 3;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = boxes_get_logo_path (_tmp0_, _tmp5_, 3);
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp6_;
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = (_vala_array_free (_tmp5_, _tmp5__length1, (GDestroyNotify) g_free), NULL);
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	path = _tmp7_;
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = path;
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp8_ == NULL) {
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (path);
#line 288 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 2926 "util.c"
	}
	{
		const gchar* _tmp9_;
		gint _tmp10_;
		GdkPixbuf* _tmp11_;
		GdkPixbuf* pixbuf;
		GtkImage* _tmp12_;
		GdkPixbuf* _tmp13_;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = path;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp10_ = size;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp11_ = gdk_pixbuf_new_from_file_at_size (_tmp9_, _tmp10_, -1, &_inner_error_);
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		pixbuf = _tmp11_;
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 2945 "util.c"
			goto __catch61_g_error;
		}
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp12_ = image;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp13_ = pixbuf;
#line 292 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		gtk_image_set_from_pixbuf (_tmp12_, _tmp13_);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (pixbuf);
#line 2956 "util.c"
	}
	goto __finally61;
	__catch61_g_error:
	{
		GError* _error_ = NULL;
		const gchar* _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_error_ = _inner_error_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = path;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp15_ = _error_;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp16_ = _tmp15_->message;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_warning ("util.vala:294: Error loading logo file '%s': %s", _tmp14_, _tmp16_);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_error_);
#line 2979 "util.c"
	}
	__finally61:
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (path);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_clear_error (&_inner_error_);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 2992 "util.c"
	}
#line 284 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (path);
#line 2996 "util.c"
}


static GEnumValue* _g_enum_value_dup (GEnumValue* self) {
	GEnumValue* dup;
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	dup = g_new0 (GEnumValue, 1);
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	memcpy (dup, self, sizeof (GEnumValue));
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return dup;
#line 3008 "util.c"
}


static gpointer __g_enum_value_dup0 (gpointer self) {
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self ? _g_enum_value_dup (self) : NULL;
#line 3015 "util.c"
}


gint boxes_get_enum_value (const gchar* value_nick, GType enum_type) {
	gint result = 0;
	GType _tmp0_;
	GTypeClass* _tmp1_ = NULL;
	GEnumClass* enum_class;
	const gchar* _tmp2_;
	GEnumValue* _tmp3_ = NULL;
	GEnumValue* _tmp4_;
	GEnumValue* val;
	gint _tmp5_;
#line 298 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (value_nick != NULL, 0);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = enum_type;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_type_class_ref (_tmp0_);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	enum_class = (GEnumClass*) _tmp1_;
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = value_nick;
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_enum_get_value_by_nick (enum_class, _tmp2_);
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = __g_enum_value_dup0 (_tmp3_);
#line 300 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	val = _tmp4_;
#line 301 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (val != NULL, -1);
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = (*val).value;
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp5_;
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (val);
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_type_class_unref0 (enum_class);
#line 303 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 3057 "util.c"
}


GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain, GVirStoragePool** pool) {
	GVirStoragePool* _vala_pool = NULL;
	GVirStorageVol* result = NULL;
	GVirConnection* _tmp0_;
	GVirStoragePool* _tmp1_ = NULL;
	GVirStoragePool* _tmp2_;
	GVirStoragePool* _tmp3_;
	GVirDomain* _tmp4_;
	const gchar* _tmp5_ = NULL;
	GVirStorageVol* _tmp6_ = NULL;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = connection;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = gvir_connection_find_storage_pool_by_name (_tmp0_, PACKAGE_TARNAME);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (_vala_pool);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_vala_pool = _tmp1_;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _vala_pool;
#line 310 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp2_ == NULL) {
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = NULL;
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (pool) {
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			*pool = _vala_pool;
#line 3093 "util.c"
		} else {
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_object_unref0 (_vala_pool);
#line 3097 "util.c"
		}
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 3101 "util.c"
	}
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _vala_pool;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = domain;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = gvir_domain_get_name (_tmp4_);
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = gvir_storage_pool_get_volume (_tmp3_, _tmp5_);
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp6_;
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (pool) {
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		*pool = _vala_pool;
#line 3117 "util.c"
	} else {
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_vala_pool);
#line 3121 "util.c"
	}
#line 314 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 3125 "util.c"
}


BoxesPair* boxes_pair_construct (GType object_type, GType t1_type, GBoxedCopyFunc t1_dup_func, GDestroyNotify t1_destroy_func, GType t2_type, GBoxedCopyFunc t2_dup_func, GDestroyNotify t2_destroy_func, gconstpointer first, gconstpointer second) {
	BoxesPair* self = NULL;
	gconstpointer _tmp0_;
	gpointer _tmp1_;
	gconstpointer _tmp2_;
	gpointer _tmp3_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self = (BoxesPair*) g_type_create_instance (object_type);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t1_type = t1_type;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t1_dup_func = t1_dup_func;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t1_destroy_func = t1_destroy_func;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t2_type = t2_type;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t2_dup_func = t2_dup_func;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->t2_destroy_func = t2_destroy_func;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = first;
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = ((_tmp0_ != NULL) && (t1_dup_func != NULL)) ? t1_dup_func ((gpointer) _tmp0_) : ((gpointer) _tmp0_);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_t1_destroy_func0 (self->first);
#line 322 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->first = _tmp1_;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = second;
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = ((_tmp2_ != NULL) && (t2_dup_func != NULL)) ? t2_dup_func ((gpointer) _tmp2_) : ((gpointer) _tmp2_);
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_t2_destroy_func0 (self->second);
#line 323 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->second = _tmp3_;
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self;
#line 3167 "util.c"
}


BoxesPair* boxes_pair_new (GType t1_type, GBoxedCopyFunc t1_dup_func, GDestroyNotify t1_destroy_func, GType t2_type, GBoxedCopyFunc t2_dup_func, GDestroyNotify t2_destroy_func, gconstpointer first, gconstpointer second) {
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return boxes_pair_construct (BOXES_TYPE_PAIR, t1_type, t1_dup_func, t1_destroy_func, t2_type, t2_dup_func, t2_destroy_func, first, second);
#line 3174 "util.c"
}


static void boxes_value_pair_init (GValue* value) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	value->data[0].v_pointer = NULL;
#line 3181 "util.c"
}


static void boxes_value_pair_free_value (GValue* value) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (value->data[0].v_pointer) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		boxes_pair_unref (value->data[0].v_pointer);
#line 3190 "util.c"
	}
}


static void boxes_value_pair_copy_value (const GValue* src_value, GValue* dest_value) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (src_value->data[0].v_pointer) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		dest_value->data[0].v_pointer = boxes_pair_ref (src_value->data[0].v_pointer);
#line 3200 "util.c"
	} else {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		dest_value->data[0].v_pointer = NULL;
#line 3204 "util.c"
	}
}


static gpointer boxes_value_pair_peek_pointer (const GValue* value) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return value->data[0].v_pointer;
#line 3212 "util.c"
}


static gchar* boxes_value_pair_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (collect_values[0].v_pointer) {
#line 3219 "util.c"
		BoxesPair* object;
		object = collect_values[0].v_pointer;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (object->parent_instance.g_class == NULL) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3226 "util.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 3230 "util.c"
		}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = boxes_pair_ref (object);
#line 3234 "util.c"
	} else {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = NULL;
#line 3238 "util.c"
	}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return NULL;
#line 3242 "util.c"
}


static gchar* boxes_value_pair_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesPair** object_p;
	object_p = collect_values[0].v_pointer;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (!object_p) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 3253 "util.c"
	}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (!value->data[0].v_pointer) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		*object_p = NULL;
#line 3259 "util.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		*object_p = value->data[0].v_pointer;
#line 3263 "util.c"
	} else {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		*object_p = boxes_pair_ref (value->data[0].v_pointer);
#line 3267 "util.c"
	}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return NULL;
#line 3271 "util.c"
}


GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecPair* spec;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_PAIR), NULL);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return G_PARAM_SPEC (spec);
#line 3285 "util.c"
}


gpointer boxes_value_get_pair (const GValue* value) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_PAIR), NULL);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return value->data[0].v_pointer;
#line 3294 "util.c"
}


void boxes_value_set_pair (GValue* value, gpointer v_object) {
	BoxesPair* old;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_PAIR));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	old = value->data[0].v_pointer;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (v_object) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_PAIR));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = v_object;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		boxes_pair_ref (value->data[0].v_pointer);
#line 3314 "util.c"
	} else {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = NULL;
#line 3318 "util.c"
	}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (old) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		boxes_pair_unref (old);
#line 3324 "util.c"
	}
}


void boxes_value_take_pair (GValue* value, gpointer v_object) {
	BoxesPair* old;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_PAIR));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	old = value->data[0].v_pointer;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (v_object) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_PAIR));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = v_object;
#line 3343 "util.c"
	} else {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		value->data[0].v_pointer = NULL;
#line 3347 "util.c"
	}
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (old) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		boxes_pair_unref (old);
#line 3353 "util.c"
	}
}


static void boxes_pair_class_init (BoxesPairClass * klass) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_pair_parent_class = g_type_class_peek_parent (klass);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	BOXES_PAIR_CLASS (klass)->finalize = boxes_pair_finalize;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_type_class_add_private (klass, sizeof (BoxesPairPrivate));
#line 3365 "util.c"
}


static void boxes_pair_instance_init (BoxesPair * self) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv = BOXES_PAIR_GET_PRIVATE (self);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->ref_count = 1;
#line 3374 "util.c"
}


static void boxes_pair_finalize (BoxesPair* obj) {
	BoxesPair * self;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_PAIR, BoxesPair);
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	((self->first == NULL) || (self->priv->t1_destroy_func == NULL)) ? NULL : (self->first = (self->priv->t1_destroy_func (self->first), NULL));
#line 319 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	((self->second == NULL) || (self->priv->t2_destroy_func == NULL)) ? NULL : (self->second = (self->priv->t2_destroy_func (self->second), NULL));
#line 3386 "util.c"
}


GType boxes_pair_get_type (void) {
	static volatile gsize boxes_pair_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_pair_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_pair_init, boxes_value_pair_free_value, boxes_value_pair_copy_value, boxes_value_pair_peek_pointer, "p", boxes_value_pair_collect_value, "p", boxes_value_pair_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesPairClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_pair_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesPair), 0, (GInstanceInitFunc) boxes_pair_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_pair_type_id;
		boxes_pair_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesPair", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_pair_type_id__volatile, boxes_pair_type_id);
	}
	return boxes_pair_type_id__volatile;
}


gpointer boxes_pair_ref (gpointer instance) {
	BoxesPair* self;
	self = instance;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&self->ref_count);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return instance;
#line 3411 "util.c"
}


void boxes_pair_unref (gpointer instance) {
	BoxesPair* self;
	self = instance;
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		BOXES_PAIR_GET_CLASS (self)->finalize (self);
#line 317 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 3424 "util.c"
	}
}


BoxesQuery* boxes_query_construct (GType object_type, const gchar* query) {
	BoxesQuery * self = NULL;
	const gchar* _tmp0_;
	gchar* _tmp1_;
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (query != NULL, NULL);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self = (BoxesQuery*) g_object_new (object_type, NULL);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = query;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (self->priv->query);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->query = _tmp1_;
#line 338 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_query_parse (self);
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self;
#line 3449 "util.c"
}


BoxesQuery* boxes_query_new (const gchar* query) {
#line 336 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return boxes_query_construct (BOXES_TYPE_QUERY, query);
#line 3456 "util.c"
}


void boxes_query_parse (BoxesQuery* self) {
	const gchar* _tmp0_;
	gchar** _tmp1_;
	gchar** _tmp2_ = NULL;
#line 341 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (self != NULL);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = self->priv->query;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _tmp1_ = g_strsplit (_tmp0_, "&", 0);
#line 3470 "util.c"
	{
		gchar** p_collection = NULL;
		gint p_collection_length1 = 0;
		gint _p_collection_size_ = 0;
		gint p_it = 0;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		p_collection = _tmp2_;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		p_collection_length1 = _vala_array_length (_tmp1_);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		for (p_it = 0; p_it < _vala_array_length (_tmp1_); p_it = p_it + 1) {
#line 3482 "util.c"
			gchar* _tmp3_;
			gchar* p = NULL;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp3_ = g_strdup (p_collection[p_it]);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			p = _tmp3_;
#line 3489 "util.c"
			{
				const gchar* _tmp4_;
				gchar** _tmp5_;
				gchar** _tmp6_ = NULL;
				gchar** pair;
				gint pair_length1;
				gint _pair_size_;
				gchar** _tmp7_;
				gint _tmp7__length1;
				GHashTable* _tmp8_;
				gchar** _tmp9_;
				gint _tmp9__length1;
				const gchar* _tmp10_;
				gchar* _tmp11_;
				gchar** _tmp12_;
				gint _tmp12__length1;
				const gchar* _tmp13_;
				gchar* _tmp14_;
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp4_ = p;
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp6_ = _tmp5_ = g_strsplit (_tmp4_, "=", 0);
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				pair = _tmp6_;
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				pair_length1 = _vala_array_length (_tmp5_);
#line 343 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_pair_size_ = pair_length1;
#line 344 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp7_ = pair;
#line 344 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp7__length1 = pair_length1;
#line 344 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (_tmp7__length1 != 2) {
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					pair = (_vala_array_free (pair, pair_length1, (GDestroyNotify) g_free), NULL);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					_g_free0 (p);
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					continue;
#line 3530 "util.c"
				}
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp8_ = self->priv->params;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp9_ = pair;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp9__length1 = pair_length1;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp10_ = _tmp9_[0];
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp11_ = g_strdup (_tmp10_);
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp12_ = pair;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp12__length1 = pair_length1;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp13_ = _tmp12_[1];
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp14_ = g_strdup (_tmp13_);
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				g_hash_table_insert (_tmp8_, _tmp11_, _tmp14_);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				pair = (_vala_array_free (pair, pair_length1, (GDestroyNotify) g_free), NULL);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_free0 (p);
#line 3556 "util.c"
			}
		}
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		p_collection = (_vala_array_free (p_collection, p_collection_length1, (GDestroyNotify) g_free), NULL);
#line 3561 "util.c"
	}
}


gchar* boxes_query_get (BoxesQuery* self, const gchar* key) {
	gchar* result = NULL;
	GHashTable* _tmp0_;
	const gchar* _tmp1_;
	gconstpointer _tmp2_ = NULL;
	gchar* _tmp3_;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (key != NULL, NULL);
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = self->priv->params;
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = key;
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_hash_table_lookup (_tmp0_, _tmp1_);
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_strdup ((const gchar*) _tmp2_);
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp3_;
#line 351 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 3588 "util.c"
}


static void _g_free0_ (gpointer var) {
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	var = (g_free (var), NULL);
#line 3595 "util.c"
}


static GObject * boxes_query_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesQuery * self;
	GHashFunc _tmp0_;
	GEqualFunc _tmp1_;
	GHashTable* _tmp2_;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	parent_class = G_OBJECT_CLASS (boxes_query_parent_class);
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_QUERY, BoxesQuery);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = g_str_hash;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = g_str_equal;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _g_free0_);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_hash_table_unref0 (self->priv->params);
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv->params = _tmp2_;
#line 332 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return obj;
#line 3624 "util.c"
}


static void boxes_query_class_init (BoxesQueryClass * klass) {
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_query_parent_class = g_type_class_peek_parent (klass);
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_type_class_add_private (klass, sizeof (BoxesQueryPrivate));
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_query_constructor;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_query_finalize;
#line 3637 "util.c"
}


static void boxes_query_instance_init (BoxesQuery * self) {
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self->priv = BOXES_QUERY_GET_PRIVATE (self);
#line 3644 "util.c"
}


static void boxes_query_finalize (GObject* obj) {
	BoxesQuery * self;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_QUERY, BoxesQuery);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (self->priv->query);
#line 330 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_hash_table_unref0 (self->priv->params);
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	G_OBJECT_CLASS (boxes_query_parent_class)->finalize (obj);
#line 3658 "util.c"
}


GType boxes_query_get_type (void) {
	static volatile gsize boxes_query_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_query_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesQueryClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_query_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesQuery), 0, (GInstanceInitFunc) boxes_query_instance_init, NULL };
		GType boxes_query_type_id;
		boxes_query_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesQuery", &g_define_type_info, 0);
		g_once_init_leave (&boxes_query_type_id__volatile, boxes_query_type_id);
	}
	return boxes_query_type_id__volatile;
}


gchar* boxes_get_logo_path (OsinfoOs* os, gchar** extensions, int extensions_length1) {
	gchar* result = NULL;
	gchar** _tmp0_;
	gint _tmp0__length1;
	OsinfoOs* _tmp1_;
	const gchar* _tmp2_;
	const gchar* _tmp3_;
	gchar** _tmp4_;
	gint _tmp4__length1;
	const gchar* _tmp5_;
	gchar* _tmp6_;
	gchar* _tmp7_;
	gchar* _tmp8_ = NULL;
	gchar* _tmp9_;
	gchar* path;
	const gchar* _tmp10_;
	GFile* _tmp11_ = NULL;
	GFile* file;
	GFile* _tmp12_;
	gboolean _tmp13_ = FALSE;
	GFile* _tmp24_;
	gboolean _tmp25_ = FALSE;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = extensions;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0__length1 = extensions_length1;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp0__length1 == 0) {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = NULL;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 3708 "util.c"
	}
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = os;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = osinfo_product_get_short_id ((OsinfoProduct*) _tmp1_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _tmp2_;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4_ = extensions;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp4__length1 = extensions_length1;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = _tmp4_[0];
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = g_strconcat (_tmp3_, _tmp5_, NULL);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp6_;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = boxes_get_pixmap (_tmp7_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = _tmp8_;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_tmp7_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	path = _tmp9_;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = path;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = g_file_new_for_path (_tmp10_);
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	file = _tmp11_;
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_ = file;
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp13_ = g_file_query_exists (_tmp12_, NULL);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (!_tmp13_) {
#line 3746 "util.c"
		OsinfoOs* _tmp14_;
		const gchar* _tmp15_;
		const gchar* _tmp16_;
		gchar** _tmp17_;
		gint _tmp17__length1;
		const gchar* _tmp18_;
		gchar* _tmp19_;
		gchar* _tmp20_;
		gchar* _tmp21_ = NULL;
		const gchar* _tmp22_;
		GFile* _tmp23_ = NULL;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp14_ = os;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp15_ = osinfo_os_get_distro (_tmp14_);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp16_ = _tmp15_;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp17_ = extensions;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp17__length1 = extensions_length1;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp18_ = _tmp17_[0];
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp19_ = g_strconcat (_tmp16_, _tmp18_, NULL);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp20_ = _tmp19_;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp21_ = boxes_get_pixmap (_tmp20_);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (path);
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		path = _tmp21_;
#line 362 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp20_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp22_ = path;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp23_ = g_file_new_for_path (_tmp22_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (file);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		file = _tmp23_;
#line 3790 "util.c"
	}
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp24_ = file;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp25_ = g_file_query_exists (_tmp24_, NULL);
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp25_) {
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = path;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (file);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 3804 "util.c"
	} else {
		OsinfoOs* _tmp26_;
		gchar** _tmp27_;
		gint _tmp27__length1;
		gchar** _tmp28_;
		gint _tmp28__length1;
		gchar* _tmp29_ = NULL;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp26_ = os;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp27_ = extensions;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp27__length1 = extensions_length1;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp28_ = extensions;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp28__length1 = extensions_length1;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp29_ = boxes_get_logo_path (_tmp26_, _tmp27_ + 1, _tmp28__length1 - 1);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		result = _tmp29_;
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (file);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (path);
#line 369 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return result;
#line 3832 "util.c"
	}
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (file);
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (path);
#line 3838 "util.c"
}


void boxes_fdo_accounts_FindUserByName (BoxesFdoAccounts* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	BOXES_FDO_ACCOUNTS_GET_INTERFACE (self)->FindUserByName (self, name, _callback_, _user_data_);
#line 3845 "util.c"
}


gchar* boxes_fdo_accounts_FindUserByName_finish (BoxesFdoAccounts* self, GAsyncResult* _res_, GError** error) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_GET_INTERFACE (self)->FindUserByName_finish (self, _res_, error);
#line 3852 "util.c"
}


static void boxes_fdo_accounts_base_init (BoxesFdoAccountsIface * iface) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	static gboolean initialized = FALSE;
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (!initialized) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		initialized = TRUE;
#line 3863 "util.c"
	}
}


GType boxes_fdo_accounts_get_type (void) {
	static volatile gsize boxes_fdo_accounts_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_fdo_accounts_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesFdoAccountsIface), (GBaseInitFunc) boxes_fdo_accounts_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_fdo_accounts_type_id;
		boxes_fdo_accounts_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesFdoAccounts", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_fdo_accounts_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (boxes_fdo_accounts_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) boxes_fdo_accounts_proxy_get_type);
		g_type_set_qdata (boxes_fdo_accounts_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.Accounts");
		g_type_set_qdata (boxes_fdo_accounts_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_fdo_accounts_register_object);
		g_once_init_leave (&boxes_fdo_accounts_type_id__volatile, boxes_fdo_accounts_type_id);
	}
	return boxes_fdo_accounts_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (BoxesFdoAccountsProxy, boxes_fdo_accounts_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BOXES_FDO_TYPE_ACCOUNTS, boxes_fdo_accounts_proxy_boxes_fdo_accounts_interface_init) )
static void boxes_fdo_accounts_proxy_class_init (BoxesFdoAccountsProxyClass* klass) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_DBUS_PROXY_CLASS (klass)->g_signal = boxes_fdo_accounts_proxy_g_signal;
#line 3888 "util.c"
}


static void boxes_fdo_accounts_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void boxes_fdo_accounts_proxy_init (BoxesFdoAccountsProxy* self) {
}


static void _vala_g_async_ready_callback (GObject *source_object, GAsyncResult *res, void *user_data) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (user_data, g_object_ref (res), g_object_unref);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_complete (user_data);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (user_data);
#line 3907 "util.c"
}


static void boxes_fdo_accounts_proxy_FindUserByName_async (BoxesFdoAccounts* self, const gchar* name, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	GDBusMessage *_message;
	GVariant *_arguments;
	GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_IO_ERROR;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_message = g_dbus_message_new_method_call (g_dbus_proxy_get_name ((GDBusProxy *) self), g_dbus_proxy_get_object_path ((GDBusProxy *) self), "org.freedesktop.Accounts", "FindUserByName");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_arguments_builder, g_variant_new_string (name));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_dbus_message_set_body (_message, _arguments);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_dbus_connection_send_message_with_reply (g_dbus_proxy_get_connection ((GDBusProxy *) self), _message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, g_dbus_proxy_get_default_timeout ((GDBusProxy *) self), NULL, NULL, _vala_g_async_ready_callback, g_simple_async_result_new ((GObject *) self, _callback_, _user_data_, NULL));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_message);
#line 3931 "util.c"
}


static gchar* boxes_fdo_accounts_proxy_FindUserByName_finish (BoxesFdoAccounts* self, GAsyncResult* _res_, GError** error) {
	GDBusMessage *_reply_message;
	GVariant *_reply;
	GVariantIter _reply_iter;
	gchar* _result;
	GVariant* _tmp0_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply_message = g_dbus_connection_send_message_with_reply_finish (g_dbus_proxy_get_connection ((GDBusProxy *) self), g_simple_async_result_get_op_res_gpointer ((GSimpleAsyncResult *) _res_), error);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_reply_message) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 3947 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_dbus_message_to_gerror (_reply_message, error)) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_reply_message);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 3955 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_dbus_message_get_body (_reply_message);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_iter_init (&_reply_iter, _reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = g_variant_iter_next_value (&_reply_iter);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_tmp0_, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_tmp0_);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_reply_message);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 3971 "util.c"
}


static void boxes_fdo_accounts_proxy_boxes_fdo_accounts_interface_init (BoxesFdoAccountsIface* iface) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->FindUserByName = boxes_fdo_accounts_proxy_FindUserByName_async;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->FindUserByName_finish = boxes_fdo_accounts_proxy_FindUserByName_finish;
#line 3980 "util.c"
}


static void _dbus_boxes_fdo_accounts_FindUserByName (BoxesFdoAccounts* self, GVariant* parameters, GDBusMethodInvocation* invocation) {
	GVariantIter _arguments_iter;
	gchar* name = NULL;
	GVariant* _tmp1_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_iter_init (&_arguments_iter, parameters);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_variant_iter_next_value (&_arguments_iter);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	name = g_variant_dup_string (_tmp1_, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_tmp1_);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_fdo_accounts_FindUserByName (self, name, (GAsyncReadyCallback) _dbus_boxes_fdo_accounts_FindUserByName_ready, invocation);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (name);
#line 4000 "util.c"
}


static void _dbus_boxes_fdo_accounts_FindUserByName_ready (GObject * source_object, GAsyncResult * _res_, gpointer _user_data_) {
	GDBusMethodInvocation * invocation;
	GError* error = NULL;
	GDBusMessage* _reply_message;
	GVariant* _reply;
	GVariantBuilder _reply_builder;
	gchar* result;
	invocation = _user_data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_FindUserByName_finish ((BoxesFdoAccounts*) source_object, _res_, &error);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (error) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_dbus_method_invocation_return_gerror (invocation, error);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4020 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply_message = g_dbus_message_new_method_reply (g_dbus_method_invocation_get_message (invocation));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_init (&_reply_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_builder_add_value (&_reply_builder, g_variant_new_string (result));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_builder_end (&_reply_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_dbus_message_set_body (_reply_message, _reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_dbus_connection_send_message (g_dbus_method_invocation_get_connection (invocation), _reply_message, G_DBUS_SEND_MESSAGE_FLAGS_NONE, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (invocation);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_reply_message);
#line 4040 "util.c"
}


static void boxes_fdo_accounts_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (method_name, "FindUserByName") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_dbus_boxes_fdo_accounts_FindUserByName (object, parameters, invocation);
#line 4053 "util.c"
	} else {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (invocation);
#line 4057 "util.c"
	}
}


static GVariant* boxes_fdo_accounts_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return NULL;
#line 4069 "util.c"
}


static gboolean boxes_fdo_accounts_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4080 "util.c"
}


guint boxes_fdo_accounts_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data = g_new (gpointer, 3);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[0] = g_object_ref (object);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[1] = g_object_ref (connection);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[2] = g_strdup (path);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_fdo_accounts_dbus_interface_info), &_boxes_fdo_accounts_dbus_interface_vtable, data, _boxes_fdo_accounts_unregister_object, error);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!result) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return 0;
#line 4101 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4105 "util.c"
}


static void _boxes_fdo_accounts_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[0]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[1]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (data[2]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (data);
#line 4120 "util.c"
}


gboolean boxes_fdo_accounts_user_get_AutomaticLogin (BoxesFdoAccountsUser* self) {
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_AutomaticLogin (self);
#line 4129 "util.c"
}


gboolean boxes_fdo_accounts_user_get_Locked (BoxesFdoAccountsUser* self) {
#line 380 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 380 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_Locked (self);
#line 4138 "util.c"
}


gboolean boxes_fdo_accounts_user_get_SystemAccount (BoxesFdoAccountsUser* self) {
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_SystemAccount (self);
#line 4147 "util.c"
}


gint32 boxes_fdo_accounts_user_get_AccountType (BoxesFdoAccountsUser* self) {
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 382 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_AccountType (self);
#line 4156 "util.c"
}


gint32 boxes_fdo_accounts_user_get_PasswordMode (BoxesFdoAccountsUser* self) {
#line 383 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, 0);
#line 383 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_PasswordMode (self);
#line 4165 "util.c"
}


gchar* boxes_fdo_accounts_user_get_Email (BoxesFdoAccountsUser* self) {
#line 384 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 384 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_Email (self);
#line 4174 "util.c"
}


gchar* boxes_fdo_accounts_user_get_HomeDirectory (BoxesFdoAccountsUser* self) {
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 385 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_HomeDirectory (self);
#line 4183 "util.c"
}


gchar* boxes_fdo_accounts_user_get_IconFile (BoxesFdoAccountsUser* self) {
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 386 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_IconFile (self);
#line 4192 "util.c"
}


gchar* boxes_fdo_accounts_user_get_Language (BoxesFdoAccountsUser* self) {
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 387 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_Language (self);
#line 4201 "util.c"
}


gchar* boxes_fdo_accounts_user_get_Location (BoxesFdoAccountsUser* self) {
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_Location (self);
#line 4210 "util.c"
}


gchar* boxes_fdo_accounts_user_get_RealName (BoxesFdoAccountsUser* self) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_RealName (self);
#line 4219 "util.c"
}


gchar* boxes_fdo_accounts_user_get_Shell (BoxesFdoAccountsUser* self) {
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 390 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_Shell (self);
#line 4228 "util.c"
}


gchar* boxes_fdo_accounts_user_get_UserName (BoxesFdoAccountsUser* self) {
#line 391 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 391 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_UserName (self);
#line 4237 "util.c"
}


gchar* boxes_fdo_accounts_user_get_XSession (BoxesFdoAccountsUser* self) {
#line 392 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 392 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return BOXES_FDO_ACCOUNTS_USER_GET_INTERFACE (self)->get_XSession (self);
#line 4246 "util.c"
}


static void boxes_fdo_accounts_user_base_init (BoxesFdoAccountsUserIface * iface) {
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	static gboolean initialized = FALSE;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (!initialized) {
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		initialized = TRUE;
#line 4257 "util.c"
	}
}


GType boxes_fdo_accounts_user_get_type (void) {
	static volatile gsize boxes_fdo_accounts_user_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_fdo_accounts_user_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesFdoAccountsUserIface), (GBaseInitFunc) boxes_fdo_accounts_user_base_init, (GBaseFinalizeFunc) NULL, (GClassInitFunc) NULL, (GClassFinalizeFunc) NULL, NULL, 0, 0, (GInstanceInitFunc) NULL, NULL };
		GType boxes_fdo_accounts_user_type_id;
		boxes_fdo_accounts_user_type_id = g_type_register_static (G_TYPE_INTERFACE, "BoxesFdoAccountsUser", &g_define_type_info, 0);
		g_type_interface_add_prerequisite (boxes_fdo_accounts_user_type_id, G_TYPE_OBJECT);
		g_type_set_qdata (boxes_fdo_accounts_user_type_id, g_quark_from_static_string ("vala-dbus-proxy-type"), (void*) boxes_fdo_accounts_user_proxy_get_type);
		g_type_set_qdata (boxes_fdo_accounts_user_type_id, g_quark_from_static_string ("vala-dbus-interface-name"), "org.freedesktop.Accounts.User");
		g_type_set_qdata (boxes_fdo_accounts_user_type_id, g_quark_from_static_string ("vala-dbus-register-object"), (void*) boxes_fdo_accounts_user_register_object);
		g_once_init_leave (&boxes_fdo_accounts_user_type_id__volatile, boxes_fdo_accounts_user_type_id);
	}
	return boxes_fdo_accounts_user_type_id__volatile;
}


G_DEFINE_TYPE_EXTENDED (BoxesFdoAccountsUserProxy, boxes_fdo_accounts_user_proxy, G_TYPE_DBUS_PROXY, 0, G_IMPLEMENT_INTERFACE (BOXES_FDO_TYPE_ACCOUNTS_USER, boxes_fdo_accounts_user_proxy_boxes_fdo_accounts_user_interface_init) )
static void boxes_fdo_accounts_user_proxy_class_init (BoxesFdoAccountsUserProxyClass* klass) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_DBUS_PROXY_CLASS (klass)->g_signal = boxes_fdo_accounts_user_proxy_g_signal;
#line 4282 "util.c"
}


static void boxes_fdo_accounts_user_proxy_g_signal (GDBusProxy* proxy, const gchar* sender_name, const gchar* signal_name, GVariant* parameters) {
}


static void boxes_fdo_accounts_user_proxy_init (BoxesFdoAccountsUserProxy* self) {
}


static gboolean boxes_fdo_accounts_user_dbus_proxy_get_AutomaticLogin (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gboolean _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "AutomaticLogin");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4301 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("AutomaticLogin"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4319 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4325 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_get_boolean (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4333 "util.c"
}


static gboolean boxes_fdo_accounts_user_dbus_proxy_get_Locked (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gboolean _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Locked");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4344 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Locked"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4362 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4368 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_get_boolean (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4376 "util.c"
}


static gboolean boxes_fdo_accounts_user_dbus_proxy_get_SystemAccount (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gboolean _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "SystemAccount");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4387 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("SystemAccount"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4405 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4411 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_get_boolean (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4419 "util.c"
}


static gint32 boxes_fdo_accounts_user_dbus_proxy_get_AccountType (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gint32 _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "AccountType");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4430 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("AccountType"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return 0;
#line 4448 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4454 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_get_int32 (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4462 "util.c"
}


static gint32 boxes_fdo_accounts_user_dbus_proxy_get_PasswordMode (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gint32 _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "PasswordMode");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4473 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("PasswordMode"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return 0;
#line 4491 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4497 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_get_int32 (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4505 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Email (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Email");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4516 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Email"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4534 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4540 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4548 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_HomeDirectory (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "HomeDirectory");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4559 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("HomeDirectory"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4577 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4583 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4591 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_IconFile (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "IconFile");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4602 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("IconFile"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4620 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4626 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4634 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Language (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Language");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4645 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Language"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4663 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4669 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4677 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Location (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Location");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4688 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Location"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4706 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4712 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4720 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_RealName (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "RealName");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4731 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("RealName"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4749 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4755 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4763 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_Shell (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "Shell");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4774 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("Shell"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4792 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4798 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4806 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_UserName (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "UserName");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4817 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("UserName"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4835 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4841 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4849 "util.c"
}


static gchar* boxes_fdo_accounts_user_dbus_proxy_get_XSession (BoxesFdoAccountsUser* self) {
	GVariant *_inner_reply;
	gchar* _result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_inner_reply = g_dbus_proxy_get_cached_property ((GDBusProxy *) self, "XSession");
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!_inner_reply) {
#line 4860 "util.c"
		GVariant *_arguments;
		GVariant *_reply;
		GVariantBuilder _arguments_builder;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_init (&_arguments_builder, G_VARIANT_TYPE_TUPLE);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("org.freedesktop.Accounts.User"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_builder_add_value (&_arguments_builder, g_variant_new_string ("XSession"));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_arguments = g_variant_builder_end (&_arguments_builder);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_reply = g_dbus_proxy_call_sync ((GDBusProxy *) self, "org.freedesktop.DBus.Properties.Get", _arguments, G_DBUS_CALL_FLAGS_NONE, -1, NULL, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (!_reply) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return NULL;
#line 4878 "util.c"
		}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_get (_reply, "(v)", &_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_variant_unref (_reply);
#line 4884 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_result = g_variant_dup_string (_inner_reply, NULL);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_variant_unref (_inner_reply);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _result;
#line 4892 "util.c"
}


static void boxes_fdo_accounts_user_proxy_boxes_fdo_accounts_user_interface_init (BoxesFdoAccountsUserIface* iface) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_AutomaticLogin = boxes_fdo_accounts_user_dbus_proxy_get_AutomaticLogin;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_Locked = boxes_fdo_accounts_user_dbus_proxy_get_Locked;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_SystemAccount = boxes_fdo_accounts_user_dbus_proxy_get_SystemAccount;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_AccountType = boxes_fdo_accounts_user_dbus_proxy_get_AccountType;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_PasswordMode = boxes_fdo_accounts_user_dbus_proxy_get_PasswordMode;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_Email = boxes_fdo_accounts_user_dbus_proxy_get_Email;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_HomeDirectory = boxes_fdo_accounts_user_dbus_proxy_get_HomeDirectory;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_IconFile = boxes_fdo_accounts_user_dbus_proxy_get_IconFile;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_Language = boxes_fdo_accounts_user_dbus_proxy_get_Language;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_Location = boxes_fdo_accounts_user_dbus_proxy_get_Location;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_RealName = boxes_fdo_accounts_user_dbus_proxy_get_RealName;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_Shell = boxes_fdo_accounts_user_dbus_proxy_get_Shell;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_UserName = boxes_fdo_accounts_user_dbus_proxy_get_UserName;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	iface->get_XSession = boxes_fdo_accounts_user_dbus_proxy_get_XSession;
#line 4925 "util.c"
}


static void boxes_fdo_accounts_user_dbus_interface_method_call (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* method_name, GVariant* parameters, GDBusMethodInvocation* invocation, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (invocation);
#line 4936 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_AutomaticLogin (BoxesFdoAccountsUser* self) {
	gboolean result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_AutomaticLogin (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_boolean (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 4949 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_Locked (BoxesFdoAccountsUser* self) {
	gboolean result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_Locked (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_boolean (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 4962 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_SystemAccount (BoxesFdoAccountsUser* self) {
	gboolean result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_SystemAccount (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_boolean (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 4975 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_AccountType (BoxesFdoAccountsUser* self) {
	gint32 result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_AccountType (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_int32 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 4988 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_PasswordMode (BoxesFdoAccountsUser* self) {
	gint32 result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_PasswordMode (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_int32 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5001 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_Email (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_Email (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5016 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_HomeDirectory (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_HomeDirectory (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5031 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_IconFile (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_IconFile (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5046 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_Language (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_Language (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5061 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_Location (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_Location (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5076 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_RealName (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_RealName (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5091 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_Shell (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_Shell (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5106 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_UserName (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_UserName (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5121 "util.c"
}


static GVariant* _dbus_boxes_fdo_accounts_user_get_XSession (BoxesFdoAccountsUser* self) {
	gchar* result;
	GVariant* _reply;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = boxes_fdo_accounts_user_get_XSession (self);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_reply = g_variant_new_string (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (result);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _reply;
#line 5136 "util.c"
}


static GVariant* boxes_fdo_accounts_user_dbus_interface_get_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (strcmp (property_name, "AutomaticLogin") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_AutomaticLogin (object);
#line 5149 "util.c"
	} else if (strcmp (property_name, "Locked") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_Locked (object);
#line 5153 "util.c"
	} else if (strcmp (property_name, "SystemAccount") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_SystemAccount (object);
#line 5157 "util.c"
	} else if (strcmp (property_name, "AccountType") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_AccountType (object);
#line 5161 "util.c"
	} else if (strcmp (property_name, "PasswordMode") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_PasswordMode (object);
#line 5165 "util.c"
	} else if (strcmp (property_name, "Email") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_Email (object);
#line 5169 "util.c"
	} else if (strcmp (property_name, "HomeDirectory") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_HomeDirectory (object);
#line 5173 "util.c"
	} else if (strcmp (property_name, "IconFile") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_IconFile (object);
#line 5177 "util.c"
	} else if (strcmp (property_name, "Language") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_Language (object);
#line 5181 "util.c"
	} else if (strcmp (property_name, "Location") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_Location (object);
#line 5185 "util.c"
	} else if (strcmp (property_name, "RealName") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_RealName (object);
#line 5189 "util.c"
	} else if (strcmp (property_name, "Shell") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_Shell (object);
#line 5193 "util.c"
	} else if (strcmp (property_name, "UserName") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_UserName (object);
#line 5197 "util.c"
	} else if (strcmp (property_name, "XSession") == 0) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return _dbus_boxes_fdo_accounts_user_get_XSession (object);
#line 5201 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return NULL;
#line 5205 "util.c"
}


static gboolean boxes_fdo_accounts_user_dbus_interface_set_property (GDBusConnection* connection, const gchar* sender, const gchar* object_path, const gchar* interface_name, const gchar* property_name, GVariant* value, GError** error, gpointer user_data) {
	gpointer* data;
	gpointer object;
	data = user_data;
	object = data[0];
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 5216 "util.c"
}


guint boxes_fdo_accounts_user_register_object (gpointer object, GDBusConnection* connection, const gchar* path, GError** error) {
	guint result;
	gpointer *data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data = g_new (gpointer, 3);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[0] = g_object_ref (object);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[1] = g_object_ref (connection);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	data[2] = g_strdup (path);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = g_dbus_connection_register_object (connection, path, (GDBusInterfaceInfo *) (&_boxes_fdo_accounts_user_dbus_interface_info), &_boxes_fdo_accounts_user_dbus_interface_vtable, data, _boxes_fdo_accounts_user_unregister_object, error);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (!result) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return 0;
#line 5237 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5241 "util.c"
}


static void _boxes_fdo_accounts_user_unregister_object (gpointer user_data) {
	gpointer* data;
	data = user_data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[0]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (data[1]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (data[2]);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (data);
#line 5256 "util.c"
}


gchar* boxes_yes_no (gboolean value) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	gboolean _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = value;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp1_) {
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = "yes";
#line 5272 "util.c"
	} else {
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = "no";
#line 5276 "util.c"
	}
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _tmp0_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = g_strdup (_tmp2_);
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp3_;
#line 396 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 5286 "util.c"
}


static void boxes_check_cpu_vt_capability_data_free (gpointer _data) {
	BoxesCheckCpuVtCapabilityData* _data_;
	_data_ = _data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckCpuVtCapabilityData, _data_);
#line 5295 "util.c"
}


void boxes_check_cpu_vt_capability (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckCpuVtCapabilityData);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_check_cpu_vt_capability);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_cpu_vt_capability_data_free);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 5309 "util.c"
}


gboolean boxes_check_cpu_vt_capability_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckCpuVtCapabilityData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5322 "util.c"
}


static void boxes_check_cpu_vt_capability_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckCpuVtCapabilityData* _data_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_ = _user_data_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_source_object_ = source_object;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_res_ = _res_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_check_cpu_vt_capability_co (_data_);
#line 5336 "util.c"
}


static inline GRegex* _thread_safe_regex_init (GRegex** re, const gchar * pattern, GRegexMatchFlags match_options) {
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_once_init_enter ((volatile gsize*) re)) {
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		GRegex* val = g_regex_new (pattern, match_options, 0, NULL);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_once_init_leave ((volatile gsize*) re, (gsize) val);
#line 5347 "util.c"
	}
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return *re;
#line 5351 "util.c"
}


static gboolean boxes_check_cpu_vt_capability_co (BoxesCheckCpuVtCapabilityData* _data_) {
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	switch (_data_->_state_) {
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 0:
#line 5360 "util.c"
		goto _state_0;
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 1:
#line 5364 "util.c"
		goto _state_1;
		default:
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_assert_not_reached ();
#line 5369 "util.c"
	}
	_state_0:
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_result_ = FALSE;
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = NULL;
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/cpuinfo");
#line 401 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->file = _data_->_tmp0_;
#line 5380 "util.c"
	{
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp1_ = _data_->file;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp2_ = NULL;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp2_ = g_file_read (_data_->_tmp1_, NULL, &_data_->_inner_error_);
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_data_->_inner_error_ != NULL) {
#line 5392 "util.c"
			goto __catch62_g_error;
		}
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 404 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->stream = _data_->_tmp6_;
#line 405 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->line = NULL;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		while (TRUE) {
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp7_ = _data_->stream;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_state_ = 1;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_data_input_stream_read_line_async (_data_->_tmp7_, G_PRIORITY_DEFAULT, NULL, boxes_check_cpu_vt_capability_ready, _data_);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return FALSE;
#line 5417 "util.c"
			_state_1:
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp8_ = NULL;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp8_ = g_data_input_stream_read_line_finish (_data_->_tmp7_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_data_->_inner_error_ != NULL) {
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_free0 (_data_->line);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_object_unref0 (_data_->stream);
#line 5431 "util.c"
				goto __catch62_g_error;
			}
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_free0 (_data_->line);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->line = _data_->_tmp9_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp10_ = _data_->line;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				break;
#line 5444 "util.c"
			}
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp11_ = _data_->line;
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp12_ = FALSE;
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_0, "^flags.*(vmx|svm)", 0), _data_->_tmp11_, 0, NULL);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 408 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 408 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_data_->_tmp13_) {
#line 409 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				break;
#line 5460 "util.c"
			}
		}
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_data_->line);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->stream);
#line 5467 "util.c"
	}
	goto __finally62;
	__catch62_g_error:
	{
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_inner_error_ = NULL;
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 412 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_error ("util.vala:412: %s", _data_->_tmp14_);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_data_->_error_);
#line 5482 "util.c"
	}
	__finally62:
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_inner_error_ != NULL) {
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->file);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_clear_error (&_data_->_inner_error_);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 5495 "util.c"
	}
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp16_ = NULL;
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp18_ = g_strconcat ("check_cpu_vt_capability: ", _data_->_tmp17_, NULL);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_debug ("util.vala:415: %s", _data_->_tmp19_);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_data_->_tmp19_);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_data_->_tmp17_);
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->result = _data_->_result_;
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (_data_->file);
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5523 "util.c"
	} else {
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5527 "util.c"
	}
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 416 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (_data_->file);
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5539 "util.c"
	} else {
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5543 "util.c"
	}
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 5549 "util.c"
}


static void boxes_check_module_kvm_loaded_data_free (gpointer _data) {
	BoxesCheckModuleKvmLoadedData* _data_;
	_data_ = _data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesCheckModuleKvmLoadedData, _data_);
#line 5558 "util.c"
}


void boxes_check_module_kvm_loaded (GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesCheckModuleKvmLoadedData);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_check_module_kvm_loaded);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_check_module_kvm_loaded_data_free);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 5572 "util.c"
}


gboolean boxes_check_module_kvm_loaded_finish (GAsyncResult* _res_) {
	gboolean result;
	BoxesCheckModuleKvmLoadedData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5585 "util.c"
}


static void boxes_check_module_kvm_loaded_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesCheckModuleKvmLoadedData* _data_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_ = _user_data_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_source_object_ = source_object;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_res_ = _res_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_check_module_kvm_loaded_co (_data_);
#line 5599 "util.c"
}


static gboolean boxes_check_module_kvm_loaded_co (BoxesCheckModuleKvmLoadedData* _data_) {
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	switch (_data_->_state_) {
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 0:
#line 5608 "util.c"
		goto _state_0;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 1:
#line 5612 "util.c"
		goto _state_1;
		default:
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_assert_not_reached ();
#line 5617 "util.c"
	}
	_state_0:
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_result_ = FALSE;
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = NULL;
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = g_file_new_for_path ("/proc/modules");
#line 421 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->file = _data_->_tmp0_;
#line 5628 "util.c"
	{
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp1_ = _data_->file;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp2_ = NULL;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp2_ = g_file_read (_data_->_tmp1_, NULL, &_data_->_inner_error_);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_data_->_inner_error_ != NULL) {
#line 5640 "util.c"
			goto __catch63_g_error;
		}
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp4_ = _data_->_tmp3_;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp5_ = g_data_input_stream_new ((GInputStream*) _data_->_tmp4_);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->_tmp4_);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->stream = _data_->_tmp6_;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->line = NULL;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		while (TRUE) {
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp7_ = _data_->stream;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_state_ = 1;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_data_input_stream_read_line_async (_data_->_tmp7_, G_PRIORITY_DEFAULT, NULL, boxes_check_module_kvm_loaded_ready, _data_);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			return FALSE;
#line 5665 "util.c"
			_state_1:
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp8_ = NULL;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp8_ = g_data_input_stream_read_line_finish (_data_->_tmp7_, _data_->_res_, NULL, &_data_->_inner_error_);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp9_ = _data_->_tmp8_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_data_->_inner_error_ != NULL) {
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_free0 (_data_->line);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_g_object_unref0 (_data_->stream);
#line 5679 "util.c"
				goto __catch63_g_error;
			}
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_g_free0 (_data_->line);
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->line = _data_->_tmp9_;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp10_ = _data_->line;
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (!(_data_->_tmp10_ != NULL)) {
#line 426 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				break;
#line 5692 "util.c"
			}
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp11_ = _data_->line;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp12_ = FALSE;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp12_ = g_regex_match (_thread_safe_regex_init (&_tmp_regex_1, "^(kvm_intel|kvm_amd)", 0), _data_->_tmp11_, 0, NULL);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_result_ = _data_->_tmp12_;
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_data_->_tmp13_ = _data_->_result_;
#line 428 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (_data_->_tmp13_) {
#line 429 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				break;
#line 5708 "util.c"
			}
		}
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_data_->line);
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->stream);
#line 5715 "util.c"
	}
	goto __finally63;
	__catch63_g_error:
	{
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_inner_error_ = NULL;
#line 432 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp14_ = _data_->_error_->message;
#line 432 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_error ("util.vala:432: %s", _data_->_tmp14_);
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_data_->_error_);
#line 5730 "util.c"
	}
	__finally63:
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_inner_error_ != NULL) {
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data_->file);
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_clear_error (&_data_->_inner_error_);
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 5743 "util.c"
	}
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp15_ = _data_->_result_;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp16_ = NULL;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp16_ = boxes_yes_no (_data_->_tmp15_);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp17_ = _data_->_tmp16_;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp18_ = g_strconcat ("check_module_kvm_loaded: ", _data_->_tmp17_, NULL);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp19_ = _data_->_tmp18_;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_debug ("util.vala:435: %s", _data_->_tmp19_);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_data_->_tmp19_);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_free0 (_data_->_tmp17_);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->result = _data_->_result_;
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (_data_->file);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5771 "util.c"
	} else {
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5775 "util.c"
	}
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (_data_->file);
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 5787 "util.c"
	} else {
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 5791 "util.c"
	}
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 5797 "util.c"
}


static void boxes_run_in_thread_data_free (gpointer _data) {
	BoxesRunInThreadData* _data_;
	_data_ = _data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesRunInThreadData, _data_);
#line 5808 "util.c"
}


void boxes_run_in_thread (BoxesRunInThreadFunc func, void* func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesRunInThreadData* _data_;
	BoxesRunInThreadFunc _tmp0_;
	void* _tmp0__target;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesRunInThreadData);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_run_in_thread);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_run_in_thread_data_free);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = func;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0__target = func_target;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->func = _tmp0_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->func_target = _tmp0__target;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = cancellable;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp2_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread_co (_data_);
#line 5840 "util.c"
}


void boxes_run_in_thread_finish (GAsyncResult* _res_, GError** error) {
	BoxesRunInThreadData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5850 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5854 "util.c"
}


static Block30Data* block30_data_ref (Block30Data* _data30_) {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data30_->_ref_count_);
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data30_;
#line 5863 "util.c"
}


static void block30_data_unref (void * _userdata_) {
	Block30Data* _data30_;
	_data30_ = (Block30Data*) _userdata_;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data30_->_ref_count_)) {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_data30_->e);
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block30Data, _data30_);
#line 5876 "util.c"
	}
}


static gpointer _g_error_copy0 (gpointer self) {
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return self ? g_error_copy (self) : NULL;
#line 5884 "util.c"
}


static gboolean __lambda46_ (Block30Data* _data30_) {
	gboolean result = FALSE;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_run_in_thread_co (_data30_->_async_data_);
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = FALSE;
#line 452 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 5896 "util.c"
}


static gboolean ___lambda46__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda46_ (self);
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 5905 "util.c"
}


static gboolean __lambda45_ (Block30Data* _data30_, GIOSchedulerJob* job, GCancellable* cancellable) {
	gboolean result = FALSE;
	GIOSchedulerJob* _tmp3_;
	GError * _inner_error_ = NULL;
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (job != NULL, FALSE);
#line 5915 "util.c"
	{
		BoxesRunInThreadFunc _tmp0_;
		void* _tmp0__target;
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = _data30_->func;
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0__target = _data30_->func_target;
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ (_tmp0__target, &_inner_error_);
#line 444 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 5927 "util.c"
			goto __catch64_g_error;
		}
	}
	goto __finally64;
	__catch64_g_error:
	{
		GError* err = NULL;
		GError* _tmp1_;
		GError* _tmp2_;
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		err = _inner_error_;
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp1_ = err;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = _g_error_copy0 (_tmp1_);
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (_data30_->e);
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data30_->e = _tmp2_;
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (err);
#line 5951 "util.c"
	}
	__finally64:
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_clear_error (&_inner_error_);
#line 443 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 5962 "util.c"
	}
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = job;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_io_scheduler_job_send_to_mainloop (_tmp3_, ___lambda46__gsource_func, block30_data_ref (_data30_), block30_data_unref);
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = FALSE;
#line 455 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 5972 "util.c"
}


static gboolean ___lambda45__gio_scheduler_job_func (GIOSchedulerJob* job, GCancellable* cancellable, gpointer self) {
	gboolean result;
	result = __lambda45_ (self, job, cancellable);
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 5981 "util.c"
}


static gboolean boxes_run_in_thread_co (BoxesRunInThreadData* _data_) {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	switch (_data_->_state_) {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 0:
#line 5990 "util.c"
		goto _state_0;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 1:
#line 5994 "util.c"
		goto _state_1;
		default:
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_assert_not_reached ();
#line 5999 "util.c"
	}
	_state_0:
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_ = g_slice_new0 (Block30Data);
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_->_ref_count_ = 1;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = _data_->func;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0__target = _data_->func_target;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_->func = _data_->_tmp0_;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_->func_target = _data_->_tmp0__target;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_->_async_data_ = _data_;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_->e = NULL;
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp1_ = _data_->cancellable;
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_io_scheduler_push_job (___lambda45__gio_scheduler_job_func, block30_data_ref (_data_->_data30_), block30_data_unref, G_PRIORITY_DEFAULT, _data_->_tmp1_);
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_state_ = 1;
#line 458 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 6026 "util.c"
	_state_1:
	;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp2_ = _data_->_data30_->e;
#line 460 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_tmp2_ != NULL) {
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp3_ = _data_->_data30_->e;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_tmp4_ = _g_error_copy0 (_data_->_tmp3_);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_inner_error_ = _data_->_tmp4_;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_error_free (_data_->_inner_error_);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		block30_data_unref (_data_->_data30_);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_data30_ = NULL;
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_data_->_state_ == 0) {
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6051 "util.c"
		} else {
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6055 "util.c"
		}
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_object_unref (_data_->_async_result);
#line 461 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 6061 "util.c"
	}
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block30_data_unref (_data_->_data30_);
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data30_ = NULL;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6071 "util.c"
	} else {
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6075 "util.c"
	}
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 6081 "util.c"
}


static void boxes_exec_data_free (gpointer _data) {
	BoxesExecData* _data_;
	_data_ = _data;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->cancellable);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesExecData, _data_);
#line 6092 "util.c"
}


void boxes_exec (gchar** argv, int argv_length1, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesExecData* _data_;
	gchar** _tmp0_;
	gint _tmp0__length1;
	GCancellable* _tmp1_;
	GCancellable* _tmp2_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesExecData);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (g_object_newv (G_TYPE_OBJECT, 0, NULL), _callback_, _user_data_, boxes_exec);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_exec_data_free);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = argv;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0__length1 = argv_length1;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->argv = _tmp0_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->argv_length1 = _tmp0__length1;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = cancellable;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->cancellable = _tmp2_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_exec_co (_data_);
#line 6124 "util.c"
}


void boxes_exec_finish (GAsyncResult* _res_, GError** error) {
	BoxesExecData* _data_;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 6134 "util.c"
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 6138 "util.c"
}


static Block31Data* block31_data_ref (Block31Data* _data31_) {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data31_->_ref_count_);
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data31_;
#line 6147 "util.c"
}


static void block31_data_unref (void * _userdata_) {
	Block31Data* _data31_;
	_data31_ = (Block31Data*) _userdata_;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data31_->_ref_count_)) {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block31Data, _data31_);
#line 6158 "util.c"
	}
}


static void __lambda47_ (Block31Data* _data31_, GError** error) {
	gchar** _tmp0_;
	gint _tmp0__length1;
	GError * _inner_error_ = NULL;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = _data31_->argv;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0__length1 = _data31_->argv_length1;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_exec_sync (_tmp0_, _tmp0__length1, &_inner_error_);
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_propagate_error (error, _inner_error_);
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 6179 "util.c"
	}
}


static void ___lambda47__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	__lambda47_ (self, error);
#line 6187 "util.c"
}


static void boxes_exec_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesExecData* _data_;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_ = _user_data_;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_source_object_ = source_object;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_res_ = _res_;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_exec_co (_data_);
#line 6201 "util.c"
}


static gboolean boxes_exec_co (BoxesExecData* _data_) {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	switch (_data_->_state_) {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 0:
#line 6210 "util.c"
		goto _state_0;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		case 1:
#line 6214 "util.c"
		goto _state_1;
		default:
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_assert_not_reached ();
#line 6219 "util.c"
	}
	_state_0:
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_ = g_slice_new0 (Block31Data);
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_->_ref_count_ = 1;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0_ = _data_->argv;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_tmp0__length1 = _data_->argv_length1;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_->argv = _data_->_tmp0_;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_->argv_length1 = _data_->_tmp0__length1;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_->_async_data_ = _data_;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_state_ = 1;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_run_in_thread (___lambda47__boxes_run_in_thread_func, _data_->_data31_, NULL, boxes_exec_ready, _data_);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 6242 "util.c"
	_state_1:
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_inner_error_ != NULL) {
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_error_free (_data_->_inner_error_);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		block31_data_unref (_data_->_data31_);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_data_->_data31_ = NULL;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_data_->_state_ == 0) {
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6260 "util.c"
		} else {
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 6264 "util.c"
		}
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_object_unref (_data_->_async_result);
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return FALSE;
#line 6270 "util.c"
	}
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block31_data_unref (_data_->_data31_);
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data_->_data31_ = NULL;
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_data_->_state_ == 0) {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 6280 "util.c"
	} else {
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 6284 "util.c"
	}
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_object_unref (_data_->_async_result);
#line 464 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return FALSE;
#line 6290 "util.c"
}


void boxes_exec_sync (gchar** argv, int argv_length1, GError** error) {
	gint exit_status;
	gchar** _tmp0_;
	gint _tmp0__length1;
	gint _tmp1_ = 0;
	gint _tmp2_;
	GError * _inner_error_ = NULL;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	exit_status = -1;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = argv;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0__length1 = argv_length1;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_spawn_sync (NULL, _tmp0_, NULL, G_SPAWN_SEARCH_PATH, NULL, NULL, NULL, NULL, &_tmp1_, &_inner_error_);
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	exit_status = _tmp1_;
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_propagate_error (error, _inner_error_);
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 6317 "util.c"
	}
#line 481 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = exit_status;
#line 481 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp2_ != 0) {
#line 6323 "util.c"
		gchar** _tmp3_;
		gint _tmp3__length1;
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_;
		GError* _tmp6_;
		GError* _tmp7_;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = argv;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3__length1 = argv_length1;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = g_strjoinv (" ", _tmp3_);
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = _tmp4_;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = g_error_new (BOXES_ERROR, BOXES_ERROR_COMMAND_FAILED, "Failed to execute: %s", _tmp5_);
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = _tmp6_;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp5_);
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = _tmp7_;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_propagate_error (error, _inner_error_);
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 6350 "util.c"
	}
}


static guint8* _vala_array_dup5 (guint8* self, int length) {
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return g_memdup (self, length * sizeof (guint8));
#line 6358 "util.c"
}


GdkPixbuf* boxes_remove_alpha (GdkPixbuf* pixbuf) {
	GdkPixbuf* result = NULL;
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	static const guint8 ALPHA_TRESHOLD = (guint8) 50;
#line 6366 "util.c"
	gboolean _tmp0_ = FALSE;
	GdkPixbuf* _tmp1_;
	gint _tmp2_ = 0;
	gboolean _tmp5_;
	GdkPixbuf* _tmp6_;
	GdkPixbuf* _tmp7_;
	gint _tmp8_ = 0;
	gint width;
	GdkPixbuf* _tmp9_;
	gint _tmp10_ = 0;
	gint height;
	GdkPixbuf* _tmp11_;
	gint _tmp12_ = 0;
	gint rowstride;
	GdkPixbuf* _tmp13_;
	guint8* _tmp14_ = NULL;
	guint8* orig_pixels;
	gint orig_pixels_length1;
	gint _orig_pixels_size_;
	gint _tmp15_;
	gint _tmp16_;
	guint8* _tmp17_ = NULL;
	guint8* pixels;
	gint pixels_length1;
	gint _pixels_size_;
	guint8* _tmp65_;
	gint _tmp65__length1;
	guint8* _tmp66_;
	gint _tmp66__length1;
	GdkPixbuf* _tmp67_;
	GdkColorspace _tmp68_ = 0;
	gint _tmp69_;
	gint _tmp70_;
	gint _tmp71_;
	GdkPixbuf* _tmp72_;
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (pixbuf != NULL, NULL);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = pixbuf;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = gdk_pixbuf_get_n_channels (_tmp1_);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_tmp2_ == 4) {
#line 6410 "util.c"
		GdkPixbuf* _tmp3_;
		gint _tmp4_ = 0;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = pixbuf;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = gdk_pixbuf_get_bits_per_sample (_tmp3_);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = _tmp4_ == 8;
#line 6419 "util.c"
	} else {
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = FALSE;
#line 6423 "util.c"
	}
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = _tmp0_;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = pixbuf;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (_tmp5_, _tmp6_);
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = pixbuf;
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = gdk_pixbuf_get_width (_tmp7_);
#line 491 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	width = _tmp8_;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = pixbuf;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = gdk_pixbuf_get_height (_tmp9_);
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	height = _tmp10_;
#line 493 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = pixbuf;
#line 493 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_ = gdk_pixbuf_get_rowstride (_tmp11_);
#line 493 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	rowstride = _tmp12_;
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp13_ = pixbuf;
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp14_ = gdk_pixbuf_get_pixels (_tmp13_);
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	orig_pixels = _tmp14_;
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	orig_pixels_length1 = -1;
#line 494 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_orig_pixels_size_ = orig_pixels_length1;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp15_ = rowstride;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp16_ = height;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp17_ = g_new0 (guint8, _tmp15_ * _tmp16_);
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	pixels = _tmp17_;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	pixels_length1 = _tmp15_ * _tmp16_;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_pixels_size_ = pixels_length1;
#line 6471 "util.c"
	{
		gint i;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		i = 0;
#line 6476 "util.c"
		{
			gboolean _tmp18_;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			_tmp18_ = TRUE;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			while (TRUE) {
#line 6483 "util.c"
				gboolean _tmp19_;
				gint _tmp21_;
				gint _tmp22_;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp19_ = _tmp18_;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (!_tmp19_) {
#line 6491 "util.c"
					gint _tmp20_;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					_tmp20_ = i;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					i = _tmp20_ + 1;
#line 6497 "util.c"
				}
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp18_ = FALSE;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp21_ = i;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				_tmp22_ = height;
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
				if (!(_tmp21_ < _tmp22_)) {
#line 497 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					break;
#line 6509 "util.c"
				}
				{
					gint j;
					gint k;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					j = 0;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
					k = 0;
#line 6518 "util.c"
					{
						gboolean _tmp23_;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
						_tmp23_ = TRUE;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
						while (TRUE) {
#line 6525 "util.c"
							gboolean _tmp24_;
							gint _tmp27_;
							gint _tmp28_;
							gint _tmp29_;
							gint _tmp30_;
							gint _tmp31_;
							gint orig_index;
							gint _tmp32_;
							gint _tmp33_;
							gint _tmp34_;
							gint index;
							guint8* _tmp35_;
							gint _tmp35__length1;
							gint _tmp36_;
							guint8 _tmp37_;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp24_ = _tmp23_;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							if (!_tmp24_) {
#line 6545 "util.c"
								gint _tmp25_;
								gint _tmp26_;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp25_ = j;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								j = _tmp25_ + 4;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp26_ = k;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								k = _tmp26_ + 3;
#line 6556 "util.c"
							}
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp23_ = FALSE;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp27_ = j;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp28_ = width;
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							if (!(_tmp27_ < (_tmp28_ * 4))) {
#line 498 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								break;
#line 6568 "util.c"
							}
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp29_ = rowstride;
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp30_ = i;
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp31_ = j;
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							orig_index = (_tmp29_ * _tmp30_) + _tmp31_;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp32_ = rowstride;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp33_ = i;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp34_ = k;
#line 500 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							index = (_tmp32_ * _tmp33_) + _tmp34_;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp35_ = orig_pixels;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp35__length1 = orig_pixels_length1;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp36_ = orig_index;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							_tmp37_ = _tmp35_[_tmp36_ + 3];
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
							if (_tmp37_ < ALPHA_TRESHOLD) {
#line 6596 "util.c"
								guint8* _tmp38_;
								gint _tmp38__length1;
								gint _tmp39_;
								guint8 _tmp40_;
								guint8* _tmp41_;
								gint _tmp41__length1;
								gint _tmp42_;
								guint8 _tmp43_;
								guint8* _tmp44_;
								gint _tmp44__length1;
								gint _tmp45_;
								guint8 _tmp46_;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp38_ = pixels;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp38__length1 = pixels_length1;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp39_ = index;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp38_[_tmp39_] = (guint8) 0xFF;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp40_ = _tmp38_[_tmp39_];
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp41_ = pixels;
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp41__length1 = pixels_length1;
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp42_ = index;
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp41_[_tmp42_ + 1] = (guint8) 0xFF;
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp43_ = _tmp41_[_tmp42_ + 1];
#line 505 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp44_ = pixels;
#line 505 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp44__length1 = pixels_length1;
#line 505 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp45_ = index;
#line 505 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp44_[_tmp45_ + 2] = (guint8) 0xFF;
#line 505 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp46_ = _tmp44_[_tmp45_ + 2];
#line 6639 "util.c"
							} else {
								guint8* _tmp47_;
								gint _tmp47__length1;
								gint _tmp48_;
								guint8* _tmp49_;
								gint _tmp49__length1;
								gint _tmp50_;
								guint8 _tmp51_;
								guint8 _tmp52_;
								guint8* _tmp53_;
								gint _tmp53__length1;
								gint _tmp54_;
								guint8* _tmp55_;
								gint _tmp55__length1;
								gint _tmp56_;
								guint8 _tmp57_;
								guint8 _tmp58_;
								guint8* _tmp59_;
								gint _tmp59__length1;
								gint _tmp60_;
								guint8* _tmp61_;
								gint _tmp61__length1;
								gint _tmp62_;
								guint8 _tmp63_;
								guint8 _tmp64_;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp47_ = pixels;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp47__length1 = pixels_length1;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp48_ = index;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp49_ = orig_pixels;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp49__length1 = orig_pixels_length1;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp50_ = orig_index;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp51_ = _tmp49_[_tmp50_];
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp47_[_tmp48_] = _tmp51_;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp52_ = _tmp47_[_tmp48_];
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp53_ = pixels;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp53__length1 = pixels_length1;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp54_ = index;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp55_ = orig_pixels;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp55__length1 = orig_pixels_length1;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp56_ = orig_index;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp57_ = _tmp55_[_tmp56_ + 1];
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp53_[_tmp54_ + 1] = _tmp57_;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp58_ = _tmp53_[_tmp54_ + 1];
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp59_ = pixels;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp59__length1 = pixels_length1;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp60_ = index;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp61_ = orig_pixels;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp61__length1 = orig_pixels_length1;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp62_ = orig_index;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp63_ = _tmp61_[_tmp62_ + 2];
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp59_[_tmp60_ + 2] = _tmp63_;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
								_tmp64_ = _tmp59_[_tmp60_ + 2];
#line 6719 "util.c"
							}
						}
					}
				}
			}
		}
	}
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp65_ = pixels;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp65__length1 = pixels_length1;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp66_ = (_tmp65_ != NULL) ? _vala_array_dup5 (_tmp65_, _tmp65__length1) : ((gpointer) _tmp65_);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp66__length1 = _tmp65__length1;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp67_ = pixbuf;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp68_ = gdk_pixbuf_get_colorspace (_tmp67_);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp69_ = width;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp70_ = height;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp71_ = rowstride;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp72_ = gdk_pixbuf_new_from_data (_tmp66_, _tmp68_, FALSE, 8, _tmp69_, _tmp70_, _tmp71_, (GdkPixbufDestroyNotify) NULL, NULL);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = _tmp72_;
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	pixels = (g_free (pixels), NULL);
#line 514 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 6753 "util.c"
}


static Block32Data* block32_data_ref (Block32Data* _data32_) {
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_atomic_int_inc (&_data32_->_ref_count_);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return _data32_;
#line 6762 "util.c"
}


static void block32_data_unref (void * _userdata_) {
	Block32Data* _data32_;
	_data32_ = (Block32Data*) _userdata_;
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (g_atomic_int_dec_and_test (&_data32_->_ref_count_)) {
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_object_unref0 (_data32_->widget);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_slice_free (Block32Data, _data32_);
#line 6775 "util.c"
	}
}


static gboolean __lambda96_ (Block32Data* _data32_, cairo_t* cr) {
	gboolean result = FALSE;
	GtkWidget* _tmp0_;
	GtkStyleContext* _tmp1_ = NULL;
	GtkStyleContext* _tmp2_;
	GtkStyleContext* context;
	GtkAllocation allocation = {0};
	GtkWidget* _tmp3_;
	GtkAllocation _tmp4_ = {0};
	cairo_t* _tmp5_;
	GtkAllocation _tmp6_;
	gint _tmp7_;
	GtkAllocation _tmp8_;
	gint _tmp9_;
	cairo_t* _tmp10_;
	GtkAllocation _tmp11_;
	gint _tmp12_;
	GtkAllocation _tmp13_;
	gint _tmp14_;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_val_if_fail (cr != NULL, FALSE);
#line 526 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = _data32_->widget;
#line 526 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = gtk_widget_get_style_context (_tmp0_);
#line 526 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 526 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	context = _tmp2_;
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp3_ = _data32_->widget;
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_widget_get_allocation (_tmp3_, &_tmp4_);
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	allocation = _tmp4_;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp5_ = cr;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp6_ = allocation;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp7_ = _tmp6_.width;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp8_ = allocation;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp9_ = _tmp8_.height;
#line 529 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_render_background (context, _tmp5_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp7_, (gdouble) _tmp9_);
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp10_ = cr;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp11_ = allocation;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp12_ = _tmp11_.width;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp13_ = allocation;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp14_ = _tmp13_.height;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	gtk_render_frame (context, _tmp10_, (gdouble) 0, (gdouble) 0, (gdouble) _tmp12_, (gdouble) _tmp14_);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	result = FALSE;
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_g_object_unref0 (context);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 6845 "util.c"
}


static gboolean ___lambda96__gtk_widget_draw (GtkWidget* _sender, cairo_t* cr, gpointer self) {
	gboolean result;
	result = __lambda96_ (self, cr);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	return result;
#line 6854 "util.c"
}


void boxes_draw_as_css_box (GtkWidget* widget) {
	Block32Data* _data32_;
	GtkWidget* _tmp0_;
	GtkWidget* _tmp1_;
	GtkWidget* _tmp2_;
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (widget != NULL);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data32_ = g_slice_new0 (Block32Data);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data32_->_ref_count_ = 1;
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp0_ = widget;
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data32_->widget = _tmp1_;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_tmp2_ = _data32_->widget;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_signal_connect_data (_tmp2_, "draw", (GCallback) ___lambda96__gtk_widget_draw, block32_data_ref (_data32_), (GClosureNotify) block32_data_unref, 0);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	block32_data_unref (_data32_);
#line 524 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	_data32_ = NULL;
#line 6883 "util.c"
}


void boxes_delete_file (GFile* file, GError** error) {
	GError * _inner_error_ = NULL;
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	g_return_if_fail (file != NULL);
#line 6891 "util.c"
	{
		GFile* _tmp0_;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_;
		GFile* _tmp3_;
		GFile* _tmp4_;
		gchar* _tmp5_ = NULL;
		gchar* _tmp6_;
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp0_ = file;
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp1_ = g_file_get_path (_tmp0_);
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp2_ = _tmp1_;
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_debug ("util.vala:541: Removing '%s'..", _tmp2_);
#line 541 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp2_);
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp3_ = file;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_file_delete (_tmp3_, NULL, &_inner_error_);
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		if (_inner_error_ != NULL) {
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
			if (g_error_matches (_inner_error_, G_IO_ERROR, G_IO_ERROR_NOT_FOUND)) {
#line 6918 "util.c"
				goto __catch65_g_io_error_not_found;
			}
			goto __finally65;
		}
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp4_ = file;
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp5_ = g_file_get_path (_tmp4_);
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp6_ = _tmp5_;
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_debug ("util.vala:543: Removed '%s'.", _tmp6_);
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp6_);
#line 6933 "util.c"
	}
	goto __finally65;
	__catch65_g_io_error_not_found:
	{
		GError* e = NULL;
		GFile* _tmp7_;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_;
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		e = _inner_error_;
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_inner_error_ = NULL;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp7_ = file;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp8_ = g_file_get_path (_tmp7_);
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_tmp9_ = _tmp8_;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_debug ("util.vala:545: File '%s' was already deleted", _tmp9_);
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_free0 (_tmp9_);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		_g_error_free0 (e);
#line 6958 "util.c"
	}
	__finally65:
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
	if (_inner_error_ != NULL) {
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		g_propagate_error (error, _inner_error_);
#line 540 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/util.vala"
		return;
#line 6967 "util.c"
	}
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 6975 "util.c"
		int i;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 6983 "util.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 6995 "util.c"
}


static gint _vala_array_length (gpointer array) {
	int length;
	length = 0;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (array) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		while (((gpointer*) array)[length]) {
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			length++;
#line 7008 "util.c"
		}
	}
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return length;
#line 7013 "util.c"
}



