/* libvirt-machine.c generated by valac 0.17.2.20-113d, the Vala compiler
 * generated from libvirt-machine.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <clutter/clutter.h>
#include <stdlib.h>
#include <string.h>
#include <gtk/gtk.h>
#include <gio/gio.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <libvirt-gobject/libvirt-gobject.h>
#include <libvirt-gconfig/libvirt-gconfig.h>
#include <float.h>
#include <math.h>
#include <glib/gi18n-lib.h>
#include <clutter-gtk/clutter-gtk.h>
#include <osinfo/osinfo.h>


#define BOXES_TYPE_UI (boxes_ui_get_type ())
#define BOXES_UI(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_UI, BoxesUI))
#define BOXES_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_UI, BoxesUIClass))
#define BOXES_IS_UI(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_UI))
#define BOXES_IS_UI_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_UI))
#define BOXES_UI_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_UI, BoxesUIClass))

typedef struct _BoxesUI BoxesUI;
typedef struct _BoxesUIClass BoxesUIClass;
typedef struct _BoxesUIPrivate BoxesUIPrivate;

#define BOXES_TYPE_UI_STATE (boxes_ui_state_get_type ())

#define BOXES_TYPE_COLLECTION_ITEM (boxes_collection_item_get_type ())
#define BOXES_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItem))
#define BOXES_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))
#define BOXES_IS_COLLECTION_ITEM(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_IS_COLLECTION_ITEM_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_ITEM))
#define BOXES_COLLECTION_ITEM_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_ITEM, BoxesCollectionItemClass))

typedef struct _BoxesCollectionItem BoxesCollectionItem;
typedef struct _BoxesCollectionItemClass BoxesCollectionItemClass;
typedef struct _BoxesCollectionItemPrivate BoxesCollectionItemPrivate;

#define BOXES_TYPE_IPROPERTIES_PROVIDER (boxes_iproperties_provider_get_type ())
#define BOXES_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProvider))
#define BOXES_IS_IPROPERTIES_PROVIDER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER))
#define BOXES_IPROPERTIES_PROVIDER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_IPROPERTIES_PROVIDER, BoxesIPropertiesProviderIface))

typedef struct _BoxesIPropertiesProvider BoxesIPropertiesProvider;
typedef struct _BoxesIPropertiesProviderIface BoxesIPropertiesProviderIface;

#define BOXES_TYPE_PROPERTIES_PAGE (boxes_properties_page_get_type ())

#define BOXES_TYPE_PAIR (boxes_pair_get_type ())
#define BOXES_PAIR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PAIR, BoxesPair))
#define BOXES_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PAIR, BoxesPairClass))
#define BOXES_IS_PAIR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PAIR))
#define BOXES_IS_PAIR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PAIR))
#define BOXES_PAIR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PAIR, BoxesPairClass))

typedef struct _BoxesPair BoxesPair;
typedef struct _BoxesPairClass BoxesPairClass;

#define BOXES_TYPE_MACHINE (boxes_machine_get_type ())
#define BOXES_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE, BoxesMachine))
#define BOXES_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE, BoxesMachineClass))
#define BOXES_IS_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE))
#define BOXES_IS_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE))
#define BOXES_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE, BoxesMachineClass))

typedef struct _BoxesMachine BoxesMachine;
typedef struct _BoxesMachineClass BoxesMachineClass;
typedef struct _BoxesMachinePrivate BoxesMachinePrivate;

#define BOXES_TYPE_MACHINE_ACTOR (boxes_machine_actor_get_type ())
#define BOXES_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActor))
#define BOXES_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))
#define BOXES_IS_MACHINE_ACTOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_IS_MACHINE_ACTOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_MACHINE_ACTOR))
#define BOXES_MACHINE_ACTOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_MACHINE_ACTOR, BoxesMachineActorClass))

typedef struct _BoxesMachineActor BoxesMachineActor;
typedef struct _BoxesMachineActorClass BoxesMachineActorClass;

#define BOXES_TYPE_COLLECTION_SOURCE (boxes_collection_source_get_type ())
#define BOXES_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSource))
#define BOXES_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))
#define BOXES_IS_COLLECTION_SOURCE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_IS_COLLECTION_SOURCE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION_SOURCE))
#define BOXES_COLLECTION_SOURCE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION_SOURCE, BoxesCollectionSourceClass))

typedef struct _BoxesCollectionSource BoxesCollectionSource;
typedef struct _BoxesCollectionSourceClass BoxesCollectionSourceClass;

#define BOXES_TYPE_DISPLAY_CONFIG (boxes_display_config_get_type ())
#define BOXES_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfig))
#define BOXES_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))
#define BOXES_IS_DISPLAY_CONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_IS_DISPLAY_CONFIG_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_CONFIG))
#define BOXES_DISPLAY_CONFIG_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_CONFIG, BoxesDisplayConfigClass))

typedef struct _BoxesDisplayConfig BoxesDisplayConfig;
typedef struct _BoxesDisplayConfigClass BoxesDisplayConfigClass;

#define BOXES_TYPE_LIBVIRT_MACHINE (boxes_libvirt_machine_get_type ())
#define BOXES_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine))
#define BOXES_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))
#define BOXES_IS_LIBVIRT_MACHINE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_IS_LIBVIRT_MACHINE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_LIBVIRT_MACHINE))
#define BOXES_LIBVIRT_MACHINE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachineClass))

typedef struct _BoxesLibvirtMachine BoxesLibvirtMachine;
typedef struct _BoxesLibvirtMachineClass BoxesLibvirtMachineClass;
typedef struct _BoxesLibvirtMachinePrivate BoxesLibvirtMachinePrivate;

#define BOXES_TYPE_VM_CREATOR (boxes_vm_creator_get_type ())
#define BOXES_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreator))
#define BOXES_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))
#define BOXES_IS_VM_CREATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VM_CREATOR))
#define BOXES_IS_VM_CREATOR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VM_CREATOR))
#define BOXES_VM_CREATOR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VM_CREATOR, BoxesVMCreatorClass))

typedef struct _BoxesVMCreator BoxesVMCreator;
typedef struct _BoxesVMCreatorClass BoxesVMCreatorClass;

#define BOXES_LIBVIRT_MACHINE_TYPE_MACHINE_STAT (boxes_libvirt_machine_machine_stat_get_type ())
typedef struct _BoxesLibvirtMachineMachineStat BoxesLibvirtMachineMachineStat;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _boxes_vm_creator_unref0(var) ((var == NULL) ? NULL : (var = (boxes_vm_creator_unref (var), NULL)))

#define BOXES_TYPE_DISPLAY (boxes_display_get_type ())
#define BOXES_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY, BoxesDisplay))
#define BOXES_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY, BoxesDisplayClass))
#define BOXES_IS_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY))
#define BOXES_IS_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY))
#define BOXES_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY, BoxesDisplayClass))

typedef struct _BoxesDisplay BoxesDisplay;
typedef struct _BoxesDisplayClass BoxesDisplayClass;

#define BOXES_MACHINE_TYPE_MACHINE_STATE (boxes_machine_machine_state_get_type ())
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
#define __vala_GVirDomainInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInfo_free (var), NULL)))
typedef struct _Block8Data Block8Data;
typedef struct _Block9Data Block9Data;
#define __vala_GVirDomainDiskStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainDiskStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateIoStatData BoxesLibvirtMachineUpdateIoStatData;
typedef struct _Block10Data Block10Data;
typedef struct _Block11Data Block11Data;
#define __vala_GVirDomainInterfaceStats_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirDomainInterfaceStats_free (var), NULL)))
typedef struct _BoxesLibvirtMachineUpdateNetStatData BoxesLibvirtMachineUpdateNetStatData;
typedef struct _BoxesLibvirtMachineUpdateStatsData BoxesLibvirtMachineUpdateStatsData;
typedef struct _Block12Data Block12Data;
#define __g_list_free__boxes_pair_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__boxes_pair_unref0_ (var), NULL)))

#define BOXES_TYPE_SPICE_DISPLAY (boxes_spice_display_get_type ())
#define BOXES_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplay))
#define BOXES_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))
#define BOXES_IS_SPICE_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_IS_SPICE_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SPICE_DISPLAY))
#define BOXES_SPICE_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SPICE_DISPLAY, BoxesSpiceDisplayClass))

typedef struct _BoxesSpiceDisplay BoxesSpiceDisplay;
typedef struct _BoxesSpiceDisplayClass BoxesSpiceDisplayClass;

#define BOXES_TYPE_VNC_DISPLAY (boxes_vnc_display_get_type ())
#define BOXES_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplay))
#define BOXES_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))
#define BOXES_IS_VNC_DISPLAY(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_IS_VNC_DISPLAY_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_VNC_DISPLAY))
#define BOXES_VNC_DISPLAY_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_VNC_DISPLAY, BoxesVncDisplayClass))

typedef struct _BoxesVncDisplay BoxesVncDisplay;
typedef struct _BoxesVncDisplayClass BoxesVncDisplayClass;
typedef struct _Block13Data Block13Data;
typedef struct _BoxesLibvirtMachineTakeScreenshotData BoxesLibvirtMachineTakeScreenshotData;

#define BOXES_TYPE_APP (boxes_app_get_type ())
#define BOXES_APP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_APP, BoxesApp))
#define BOXES_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_APP, BoxesAppClass))
#define BOXES_IS_APP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_APP))
#define BOXES_IS_APP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_APP))
#define BOXES_APP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_APP, BoxesAppClass))

typedef struct _BoxesApp BoxesApp;
typedef struct _BoxesAppClass BoxesAppClass;
typedef struct _BoxesLibvirtMachineSuspendData BoxesLibvirtMachineSuspendData;
typedef struct _BoxesAppPrivate BoxesAppPrivate;

#define BOXES_TYPE_TOPBAR (boxes_topbar_get_type ())
#define BOXES_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_TOPBAR, BoxesTopbar))
#define BOXES_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_TOPBAR, BoxesTopbarClass))
#define BOXES_IS_TOPBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_TOPBAR))
#define BOXES_IS_TOPBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_TOPBAR))
#define BOXES_TOPBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_TOPBAR, BoxesTopbarClass))

typedef struct _BoxesTopbar BoxesTopbar;
typedef struct _BoxesTopbarClass BoxesTopbarClass;

#define BOXES_TYPE_NOTIFICATIONBAR (boxes_notificationbar_get_type ())
#define BOXES_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbar))
#define BOXES_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))
#define BOXES_IS_NOTIFICATIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_IS_NOTIFICATIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_NOTIFICATIONBAR))
#define BOXES_NOTIFICATIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_NOTIFICATIONBAR, BoxesNotificationbarClass))

typedef struct _BoxesNotificationbar BoxesNotificationbar;
typedef struct _BoxesNotificationbarClass BoxesNotificationbarClass;

#define BOXES_TYPE_REVEALER (boxes_revealer_get_type ())
#define BOXES_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_REVEALER, BoxesRevealer))
#define BOXES_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_REVEALER, BoxesRevealerClass))
#define BOXES_IS_REVEALER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_REVEALER))
#define BOXES_IS_REVEALER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_REVEALER))
#define BOXES_REVEALER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_REVEALER, BoxesRevealerClass))

typedef struct _BoxesRevealer BoxesRevealer;
typedef struct _BoxesRevealerClass BoxesRevealerClass;

#define BOXES_TYPE_SIDEBAR (boxes_sidebar_get_type ())
#define BOXES_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebar))
#define BOXES_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))
#define BOXES_IS_SIDEBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SIDEBAR))
#define BOXES_IS_SIDEBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SIDEBAR))
#define BOXES_SIDEBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SIDEBAR, BoxesSidebarClass))

typedef struct _BoxesSidebar BoxesSidebar;
typedef struct _BoxesSidebarClass BoxesSidebarClass;

#define BOXES_TYPE_SELECTIONBAR (boxes_selectionbar_get_type ())
#define BOXES_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbar))
#define BOXES_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))
#define BOXES_IS_SELECTIONBAR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_SELECTIONBAR))
#define BOXES_IS_SELECTIONBAR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_SELECTIONBAR))
#define BOXES_SELECTIONBAR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_SELECTIONBAR, BoxesSelectionbarClass))

typedef struct _BoxesSelectionbar BoxesSelectionbar;
typedef struct _BoxesSelectionbarClass BoxesSelectionbarClass;

#define BOXES_TYPE_WIZARD (boxes_wizard_get_type ())
#define BOXES_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_WIZARD, BoxesWizard))
#define BOXES_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_WIZARD, BoxesWizardClass))
#define BOXES_IS_WIZARD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_WIZARD))
#define BOXES_IS_WIZARD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_WIZARD))
#define BOXES_WIZARD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_WIZARD, BoxesWizardClass))

typedef struct _BoxesWizard BoxesWizard;
typedef struct _BoxesWizardClass BoxesWizardClass;

#define BOXES_TYPE_PROPERTIES (boxes_properties_get_type ())
#define BOXES_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_PROPERTIES, BoxesProperties))
#define BOXES_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))
#define BOXES_IS_PROPERTIES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_PROPERTIES))
#define BOXES_IS_PROPERTIES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_PROPERTIES))
#define BOXES_PROPERTIES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_PROPERTIES, BoxesPropertiesClass))

typedef struct _BoxesProperties BoxesProperties;
typedef struct _BoxesPropertiesClass BoxesPropertiesClass;

#define BOXES_TYPE_DISPLAY_PAGE (boxes_display_page_get_type ())
#define BOXES_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPage))
#define BOXES_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))
#define BOXES_IS_DISPLAY_PAGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_IS_DISPLAY_PAGE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DISPLAY_PAGE))
#define BOXES_DISPLAY_PAGE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DISPLAY_PAGE, BoxesDisplayPageClass))

typedef struct _BoxesDisplayPage BoxesDisplayPage;
typedef struct _BoxesDisplayPageClass BoxesDisplayPageClass;

#define BOXES_TYPE_COLLECTION (boxes_collection_get_type ())
#define BOXES_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_COLLECTION, BoxesCollection))
#define BOXES_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_COLLECTION, BoxesCollectionClass))
#define BOXES_IS_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_COLLECTION))
#define BOXES_IS_COLLECTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_COLLECTION))
#define BOXES_COLLECTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_COLLECTION, BoxesCollectionClass))

typedef struct _BoxesCollection BoxesCollection;
typedef struct _BoxesCollectionClass BoxesCollectionClass;
#define __g_list_free__g_object_unref0_0(var) ((var == NULL) ? NULL : (var = (_g_list_free__g_object_unref0_ (var), NULL)))
#define __vala_GVirNodeInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirNodeInfo_free (var), NULL)))
typedef struct _Block14Data Block14Data;
#define __vala_GVirStorageVolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStorageVolInfo_free (var), NULL)))
#define __vala_GVirStoragePoolInfo_free0(var) ((var == NULL) ? NULL : (var = (_vala_GVirStoragePoolInfo_free (var), NULL)))
typedef struct _Block15Data Block15Data;

#define BOXES_TYPE_ICONFIG (boxes_iconfig_get_type ())
#define BOXES_ICONFIG(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_ICONFIG, BoxesIConfig))
#define BOXES_IS_ICONFIG(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_ICONFIG))
#define BOXES_ICONFIG_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), BOXES_TYPE_ICONFIG, BoxesIConfigIface))

typedef struct _BoxesIConfig BoxesIConfig;
typedef struct _BoxesIConfigIface BoxesIConfigIface;

typedef enum  {
	BOXES_UI_STATE_NONE,
	BOXES_UI_STATE_COLLECTION,
	BOXES_UI_STATE_CREDS,
	BOXES_UI_STATE_DISPLAY,
	BOXES_UI_STATE_SETTINGS,
	BOXES_UI_STATE_WIZARD,
	BOXES_UI_STATE_PROPERTIES
} BoxesUIState;

struct _BoxesUI {
	GObject parent_instance;
	BoxesUIPrivate * priv;
	BoxesUIState previous_ui_state;
};

struct _BoxesUIClass {
	GObjectClass parent_class;
	void (*ui_state_changed) (BoxesUI* self);
	ClutterActor* (*get_actor) (BoxesUI* self);
};

struct _BoxesCollectionItem {
	BoxesUI parent_instance;
	BoxesCollectionItemPrivate * priv;
};

struct _BoxesCollectionItemClass {
	BoxesUIClass parent_class;
};

typedef enum  {
	BOXES_PROPERTIES_PAGE_LOGIN,
	BOXES_PROPERTIES_PAGE_SYSTEM,
	BOXES_PROPERTIES_PAGE_DISPLAY,
	BOXES_PROPERTIES_PAGE_DEVICES,
	BOXES_PROPERTIES_PAGE_LAST
} BoxesPropertiesPage;

struct _BoxesIPropertiesProviderIface {
	GTypeInterface parent_iface;
	GList* (*get_properties) (BoxesIPropertiesProvider* self, BoxesPropertiesPage page);
};

struct _BoxesMachine {
	BoxesCollectionItem parent_instance;
	BoxesMachinePrivate * priv;
	BoxesMachineActor* machine_actor;
	BoxesCollectionSource* source;
	BoxesDisplayConfig* config;
	gboolean deleted;
};

struct _BoxesMachineClass {
	BoxesCollectionItemClass parent_class;
	void (*take_screenshot) (BoxesMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
	GdkPixbuf* (*take_screenshot_finish) (BoxesMachine* self, GAsyncResult* _res_, GError** error);
	GList* (*get_properties) (BoxesMachine* self, BoxesPropertiesPage page);
	gchar* (*get_screenshot_prefix) (BoxesMachine* self);
	void (*connect_display) (BoxesMachine* self);
	void (*disconnect_display) (BoxesMachine* self);
	void (*delete) (BoxesMachine* self, gboolean by_user);
};

struct _BoxesLibvirtMachine {
	BoxesMachine parent_instance;
	BoxesLibvirtMachinePrivate * priv;
	GVirDomain* domain;
	GVirConfigDomain* domain_config;
	GVirConnection* connection;
	BoxesVMCreator* vm_creator;
	gdouble* cpu_stats;
	gint cpu_stats_length1;
	gint _cpu_stats_size_;
	gdouble* io_stats;
	gint io_stats_length1;
	gint _io_stats_size_;
	gdouble* net_stats;
	gint net_stats_length1;
	gint _net_stats_size_;
};

struct _BoxesLibvirtMachineClass {
	BoxesMachineClass parent_class;
};

struct _BoxesLibvirtMachineMachineStat {
	gint64 timestamp;
	gdouble cpu_time;
	gdouble cpu_time_abs;
	gdouble cpu_guest_percent;
	gdouble memory_percent;
	GVirDomainDiskStats* disk;
	gdouble disk_read;
	gdouble disk_write;
	GVirDomainInterfaceStats* net;
	gdouble net_read;
	gdouble net_write;
};

struct _BoxesLibvirtMachinePrivate {
	gchar* storage_volume_path;
	gulong started_id;
	guint ram_update_timeout;
	guint storage_update_timeout;
	guint stats_update_timeout;
	GCancellable* stats_cancellable;
	BoxesLibvirtMachineMachineStat* stats;
	gint stats_length1;
	gint _stats_size_;
};

typedef enum  {
	BOXES_MACHINE_MACHINE_STATE_UNKNOWN,
	BOXES_MACHINE_MACHINE_STATE_STOPPED,
	BOXES_MACHINE_MACHINE_STATE_RUNNING,
	BOXES_MACHINE_MACHINE_STATE_PAUSED
} BoxesMachineMachineState;

struct _Block8Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block9Data {
	int _ref_count_;
	Block8Data * _data8_;
	GVirDomainDisk* disk;
};

typedef void (*BoxesRunInThreadFunc) (void* user_data, GError** error);
struct _BoxesLibvirtMachineUpdateIoStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block8Data* _data8_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block9Data* _data9_;
	GVirDomainDisk* _tmp3_;
	GVirDomainDisk* _tmp4_;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainDiskStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	BoxesLibvirtMachineMachineStat* _tmp11_;
	GVirDomainDiskStats* _tmp12_;
	gint64 _tmp13_;
	BoxesLibvirtMachineMachineStat _tmp14_;
	GVirDomainDiskStats* _tmp15_;
	gint64 _tmp16_;
	BoxesLibvirtMachineMachineStat* _tmp17_;
	BoxesLibvirtMachineMachineStat* _tmp18_;
	GVirDomainDiskStats* _tmp19_;
	gint64 _tmp20_;
	BoxesLibvirtMachineMachineStat _tmp21_;
	GVirDomainDiskStats* _tmp22_;
	gint64 _tmp23_;
	GError* err;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	GError* _tmp26_;
	const gchar* _tmp27_;
	GError * _inner_error_;
};

struct _Block10Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineMachineStat* stat;
	gpointer _async_data_;
};

struct _Block11Data {
	int _ref_count_;
	Block10Data * _data10_;
	GVirDomainInterface* net;
};

struct _BoxesLibvirtMachineUpdateNetStatData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GVirDomainInfo* info;
	BoxesLibvirtMachineMachineStat* stat;
	Block10Data* _data10_;
	BoxesLibvirtMachineMachineStat* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainState _tmp2_;
	Block11Data* _data11_;
	GVirDomainInterface* _tmp3_;
	GVirDomainInterface* _tmp4_;
	BoxesLibvirtMachineMachineStat* _tmp5_;
	gint _tmp5__length1;
	BoxesLibvirtMachineMachineStat _tmp6_;
	BoxesLibvirtMachineMachineStat _tmp7_;
	BoxesLibvirtMachineMachineStat prev;
	BoxesLibvirtMachineMachineStat _tmp8_;
	GVirDomainInterfaceStats* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	BoxesLibvirtMachineMachineStat* _tmp11_;
	GVirDomainInterfaceStats* _tmp12_;
	gint64 _tmp13_;
	BoxesLibvirtMachineMachineStat _tmp14_;
	GVirDomainInterfaceStats* _tmp15_;
	gint64 _tmp16_;
	BoxesLibvirtMachineMachineStat* _tmp17_;
	BoxesLibvirtMachineMachineStat* _tmp18_;
	GVirDomainInterfaceStats* _tmp19_;
	gint64 _tmp20_;
	BoxesLibvirtMachineMachineStat _tmp21_;
	GVirDomainInterfaceStats* _tmp22_;
	gint64 _tmp23_;
	GError* err;
	const gchar* _tmp24_;
	const gchar* _tmp25_;
	GError* _tmp26_;
	const gchar* _tmp27_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineUpdateStatsData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gint64 _tmp0_;
	gint64 now;
	gint64 _tmp1_;
	BoxesLibvirtMachineMachineStat _tmp2_;
	BoxesLibvirtMachineMachineStat stat;
	GVirDomain* _tmp3_;
	GCancellable* _tmp4_;
	GVirDomainInfo* _tmp5_;
	GVirDomainInfo* info;
	GVirDomainInfo* _tmp6_;
	GVirDomainInfo* _tmp7_;
	GVirDomainInfo* _tmp8_;
	GVirDomainInfo* _tmp9_;
	BoxesLibvirtMachineMachineStat* _tmp10_;
	gint _tmp10__length1;
	BoxesLibvirtMachineMachineStat* _tmp11_;
	gint _tmp11__length1;
	BoxesLibvirtMachineMachineStat* _tmp12_;
	gint _tmp12__length1;
	BoxesLibvirtMachineMachineStat _tmp13_;
	BoxesLibvirtMachineMachineStat _tmp14_;
	GError* err;
	GError* _vala1_err;
	GError* _tmp15_;
	const gchar* _tmp16_;
	gdouble* _tmp17_;
	gdouble* _tmp18_;
	gdouble* _tmp19_;
	BoxesLibvirtMachineMachineStat* _tmp20_;
	gint _tmp20__length1;
	BoxesLibvirtMachineMachineStat* stat_collection;
	gint stat_collection_length1;
	gint _stat_collection_size_;
	gint stat_it;
	BoxesLibvirtMachineMachineStat _tmp21_;
	BoxesLibvirtMachineMachineStat _vala1_stat;
	gdouble* _tmp22_;
	gint _tmp22__length1;
	BoxesLibvirtMachineMachineStat _tmp23_;
	gdouble _tmp24_;
	gdouble* _tmp25_;
	gint _tmp25__length1;
	BoxesLibvirtMachineMachineStat _tmp26_;
	gdouble _tmp27_;
	BoxesLibvirtMachineMachineStat _tmp28_;
	gdouble _tmp29_;
	gdouble* _tmp30_;
	gint _tmp30__length1;
	BoxesLibvirtMachineMachineStat _tmp31_;
	gdouble _tmp32_;
	BoxesLibvirtMachineMachineStat _tmp33_;
	gdouble _tmp34_;
	GError * _inner_error_;
};

struct _Block12Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	gboolean stats_updating;
};

typedef void (*PropertyStringChanged) (const gchar* value, void* user_data, GError** error);
typedef enum  {
	BOXES_ERROR_INVALID,
	BOXES_ERROR_COMMAND_FAILED
} BoxesError;
#define BOXES_ERROR boxes_error_quark ()
struct _Block13Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	GVirStream* stream;
	gpointer _async_data_;
};

struct _BoxesLibvirtMachineTakeScreenshotData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	GdkPixbuf* result;
	Block13Data* _data13_;
	GVirDomainState state;
	GVirDomain* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainInfo* _tmp2_;
	GVirDomainInfo* _tmp3_;
	GVirDomainState _tmp4_;
	GError* _error_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	gboolean _tmp7_;
	GVirDomainState _tmp8_;
	GVirDomainState _tmp9_;
	gboolean _tmp10_;
	GVirConnection* _tmp11_;
	GVirStream* _tmp12_;
	GdkPixbufLoader* _tmp13_;
	GdkPixbufLoader* loader;
	GVirStream* _tmp14_;
	GInputStream* _tmp15_;
	GInputStream* _tmp16_;
	GInputStream* input_stream;
	guint8* _tmp17_;
	guint8* buffer;
	gint buffer_length1;
	gint _buffer_size_;
	gssize length;
	gboolean _tmp18_;
	gboolean _tmp19_;
	gssize _tmp20_;
	GInputStream* _tmp21_;
	guint8* _tmp22_;
	gint _tmp22__length1;
	gssize _tmp23_;
	gssize _tmp24_;
	GdkPixbufLoader* _tmp25_;
	guint8* _tmp26_;
	gint _tmp26__length1;
	gssize _tmp27_;
	GdkPixbufLoader* _tmp28_;
	GdkPixbufLoader* _tmp29_;
	GdkPixbuf* _tmp30_;
	GdkPixbuf* _tmp31_;
	GError * _inner_error_;
};

struct _BoxesLibvirtMachineSuspendData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesLibvirtMachine* self;
	gboolean _tmp0_;
	gboolean _tmp1_;
	gboolean _tmp2_;
	GVirDomain* _tmp3_;
	gboolean _tmp4_;
	GVirDomain* _tmp5_;
	gboolean _tmp6_;
	gboolean _tmp7_;
	GError * _inner_error_;
};

struct _BoxesApp {
	BoxesUI parent_instance;
	BoxesAppPrivate * priv;
	GtkApplicationWindow* window;
	GtkNotebook* notebook;
	GtkClutterEmbed* embed;
	ClutterStage* stage;
	ClutterBinLayout* stage_bin;
	ClutterActor* overlay_bin_actor;
	ClutterBinLayout* overlay_bin;
	BoxesCollectionItem* current_item;
	BoxesTopbar* topbar;
	BoxesNotificationbar* notificationbar;
	BoxesRevealer* sidebar_revealer;
	BoxesRevealer* topbar_revealer;
	BoxesSidebar* sidebar;
	BoxesSelectionbar* selectionbar;
	guint duration;
	GSettings* settings;
	BoxesWizard* wizard;
	BoxesProperties* properties;
	BoxesDisplayPage* display_page;
	BoxesCollection* collection;
	GSimpleAction* action_properties;
	GSimpleAction* action_fullscreen;
	GSimpleAction* action_shutdown;
};

struct _BoxesAppClass {
	BoxesUIClass parent_class;
};

typedef void (*PropertySizeChanged) (guint64 value, void* user_data, GError** error);
struct _Block14Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	guint64 value;
};

typedef void (*BoxesNotificationbarOKFunc) (void* user_data);
typedef void (*BoxesNotificationbarCancelFunc) (void* user_data);
struct _Block15Data {
	int _ref_count_;
	BoxesLibvirtMachine * self;
	guint64 value;
};

struct _BoxesIConfigIface {
	GTypeInterface parent_iface;
	GKeyFile* (*get_keyfile) (BoxesIConfig* self);
	const gchar* (*get_filename) (BoxesIConfig* self);
	void (*set_filename) (BoxesIConfig* self, const gchar* value);
	gboolean (*get_has_file) (BoxesIConfig* self);
	void (*set_has_file) (BoxesIConfig* self, gboolean value);
};


static gpointer boxes_libvirt_machine_parent_class = NULL;
extern BoxesApp* boxes_app_app;

GType boxes_ui_get_type (void) G_GNUC_CONST;
GType boxes_ui_state_get_type (void) G_GNUC_CONST;
GType boxes_collection_item_get_type (void) G_GNUC_CONST;
GType boxes_properties_page_get_type (void) G_GNUC_CONST;
gpointer boxes_pair_ref (gpointer instance);
void boxes_pair_unref (gpointer instance);
GParamSpec* boxes_param_spec_pair (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_pair (GValue* value, gpointer v_object);
void boxes_value_take_pair (GValue* value, gpointer v_object);
gpointer boxes_value_get_pair (const GValue* value);
GType boxes_pair_get_type (void) G_GNUC_CONST;
GType boxes_iproperties_provider_get_type (void) G_GNUC_CONST;
GType boxes_machine_get_type (void) G_GNUC_CONST;
GType boxes_machine_actor_get_type (void) G_GNUC_CONST;
GType boxes_collection_source_get_type (void) G_GNUC_CONST;
GType boxes_display_config_get_type (void) G_GNUC_CONST;
GType boxes_libvirt_machine_get_type (void) G_GNUC_CONST;
gpointer boxes_vm_creator_ref (gpointer instance);
void boxes_vm_creator_unref (gpointer instance);
GParamSpec* boxes_param_spec_vm_creator (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_vm_creator (GValue* value, gpointer v_object);
void boxes_value_take_vm_creator (GValue* value, gpointer v_object);
gpointer boxes_value_get_vm_creator (const GValue* value);
GType boxes_vm_creator_get_type (void) G_GNUC_CONST;
static GType boxes_libvirt_machine_machine_stat_get_type (void) G_GNUC_CONST G_GNUC_UNUSED;
static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self);
static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest);
static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self);
#define BOXES_LIBVIRT_MACHINE_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachinePrivate))
enum  {
	BOXES_LIBVIRT_MACHINE_DUMMY_PROPERTY,
	BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT
};
static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length);
#define BOXES_LIBVIRT_MACHINE_STATS_SIZE 20
static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base);
GType boxes_display_get_type (void) G_GNUC_CONST;
BoxesDisplay* boxes_machine_get_display (BoxesMachine* self);
GType boxes_machine_machine_state_get_type (void) G_GNUC_CONST;
BoxesMachineMachineState boxes_machine_get_state (BoxesMachine* self);
static void ____lambda53_ (BoxesLibvirtMachine* self);
void boxes_machine_connect_display (BoxesMachine* self);
static void _____lambda53__gvir_domain_resumed (GVirDomain* _sender, gpointer self);
static void ____lambda54_ (BoxesLibvirtMachine* self);
static void _____lambda54__gvir_domain_started (GVirDomain* _sender, gpointer self);
static void boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self);
void boxes_display_connect_it (BoxesDisplay* self);
void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self);
GVirStorageVol* boxes_get_storage_volume (GVirConnection* connection, GVirDomain* domain, GVirStoragePool** pool);
BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error);
BoxesMachine* boxes_machine_construct (GType object_type, BoxesCollectionSource* source, const gchar* name);
const gchar* boxes_collection_item_get_name (BoxesCollectionItem* self);
BoxesDisplayConfig* boxes_display_config_new (BoxesCollectionSource* source, const gchar* subgroup);
BoxesDisplayConfig* boxes_display_config_construct (GType object_type, BoxesCollectionSource* source, const gchar* subgroup);
static void _vala_GVirDomainInfo_free (GVirDomainInfo* self);
void boxes_machine_set_state (BoxesMachine* self, BoxesMachineMachineState value);
static void __lambda66_ (BoxesLibvirtMachine* self);
static void ___lambda66__gvir_domain_started (GVirDomain* _sender, gpointer self);
static void __lambda67_ (BoxesLibvirtMachine* self);
static void ___lambda67__gvir_domain_suspended (GVirDomain* _sender, gpointer self);
static void __lambda68_ (BoxesLibvirtMachine* self);
static void ___lambda68__gvir_domain_resumed (GVirDomain* _sender, gpointer self);
static void __lambda69_ (BoxesLibvirtMachine* self);
static void ___lambda69__gvir_domain_stopped (GVirDomain* _sender, gpointer self);
void boxes_collection_item_set_title (BoxesCollectionItem* self, const gchar* value);
static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self);
void boxes_machine_load_screenshot (BoxesMachine* self);
void boxes_machine_set_screenshot_enable (BoxesMachine* self, gboolean enable);
static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable);
static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat);
static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data);
static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self);
static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_);
static Block8Data* block8_data_ref (Block8Data* _data8_);
static void block8_data_unref (void * _userdata_);
static Block9Data* block9_data_ref (Block9Data* _data9_);
static void block9_data_unref (void * _userdata_);
static GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error);
void boxes_run_in_thread (BoxesRunInThreadFunc func, void* func_target, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_run_in_thread_finish (GAsyncResult* _res_, GError** error);
static void ___lambda71_ (Block9Data* _data9_, GError** error);
static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self);
static void ____lambda71__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data);
static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_);
static Block10Data* block10_data_ref (Block10Data* _data10_);
static void block10_data_unref (void * _userdata_);
static Block11Data* block11_data_ref (Block11Data* _data11_);
static void block11_data_unref (void * _userdata_);
static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error);
static void ___lambda72_ (Block11Data* _data11_, GError** error);
static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self);
static void ____lambda72__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_data_free (gpointer _data);
static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_);
static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_);
static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length);
static void _vala_array_add2 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value);
static void _vala_array_add3 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add4 (gdouble** array, int* length, int* size, gdouble value);
static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value);
static Block12Data* block12_data_ref (Block12Data* _data12_);
static void block12_data_unref (void * _userdata_);
static gboolean ___lambda70_ (Block12Data* _data12_);
static void __lambda73_ (Block12Data* _data12_);
static void ___lambda73__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self);
static gboolean ____lambda70__gsource_func (gpointer self);
static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page);
void boxes_iproperties_provider_add_string_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, const gchar* value, PropertyStringChanged changed, void* changed_target);
gchar* boxes_collection_source_get_uri (BoxesCollectionSource* self);
gchar* boxes_display_get_uri (BoxesDisplay* self);
static void boxes_libvirt_machine_add_ram_property (BoxesLibvirtMachine* self, GList** list);
static void boxes_libvirt_machine_add_storage_property (BoxesLibvirtMachine* self, GList** list);
const gchar* boxes_display_get_protocol (BoxesDisplay* self);
GList* boxes_display_get_properties (BoxesDisplay* self, BoxesPropertiesPage page);
static void _boxes_pair_unref0_ (gpointer var);
static void _g_list_free__boxes_pair_unref0_ (GList* self);
GQuark boxes_error_quark (void);
gchar* boxes_extract_xpath (const gchar* xmldoc, const gchar* xpath, gboolean required, GError** error);
BoxesSpiceDisplay* boxes_spice_display_new (BoxesDisplayConfig* config, const gchar* host, gint port);
BoxesSpiceDisplay* boxes_spice_display_construct (GType object_type, BoxesDisplayConfig* config, const gchar* host, gint port);
GType boxes_spice_display_get_type (void) G_GNUC_CONST;
void boxes_machine_set_display (BoxesMachine* self, BoxesDisplay* value);
BoxesVncDisplay* boxes_vnc_display_new (BoxesDisplayConfig* config, const gchar* host, gint port);
BoxesVncDisplay* boxes_vnc_display_construct (GType object_type, BoxesDisplayConfig* config, const gchar* host, gint port);
GType boxes_vnc_display_get_type (void) G_GNUC_CONST;
static gchar* boxes_libvirt_machine_real_get_screenshot_prefix (BoxesMachine* base);
static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data);
static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_);
static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_);
static Block13Data* block13_data_ref (Block13Data* _data13_);
static void block13_data_unref (void * _userdata_);
static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void __lambda80_ (Block13Data* _data13_, GError** error);
static void ___lambda80__boxes_run_in_thread_func (gpointer self, GError** error);
static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user);
void boxes_machine_delete (BoxesMachine* self, gboolean by_user);
void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm);
GType boxes_app_get_type (void) G_GNUC_CONST;
GVirConnection* boxes_app_get_default_connection (BoxesApp* self);
static void boxes_libvirt_machine_suspend_data_free (gpointer _data);
void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_);
gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self);
static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
GType boxes_topbar_get_type (void) G_GNUC_CONST;
GType boxes_notificationbar_get_type (void) G_GNUC_CONST;
GType boxes_revealer_get_type (void) G_GNUC_CONST;
GType boxes_sidebar_get_type (void) G_GNUC_CONST;
GType boxes_selectionbar_get_type (void) G_GNUC_CONST;
GType boxes_wizard_get_type (void) G_GNUC_CONST;
GType boxes_properties_get_type (void) G_GNUC_CONST;
GType boxes_display_page_get_type (void) G_GNUC_CONST;
GType boxes_collection_get_type (void) G_GNUC_CONST;
static void _g_object_unref0_ (gpointer var);
static void _g_list_free__g_object_unref0_ (GList* self);
static void _vala_GVirNodeInfo_free (GVirNodeInfo* self);
void boxes_iproperties_provider_add_size_property (BoxesIPropertiesProvider* self, GList** list, const gchar* name, guint64 size, guint64 min, guint64 max, guint64 step, PropertySizeChanged changed, void* changed_target);
static void boxes_libvirt_machine_on_ram_changed (BoxesLibvirtMachine* self, guint64 value);
static void _boxes_libvirt_machine_on_ram_changed_property_size_changed (guint64 value, gpointer self);
static Block14Data* block14_data_ref (Block14Data* _data14_);
static void block14_data_unref (void * _userdata_);
static gboolean __lambda74_ (Block14Data* _data14_);
static void boxes_libvirt_machine_notify_reboot_required (BoxesLibvirtMachine* self);
static gboolean ___lambda74__gsource_func (gpointer self);
static void __lambda75_ (BoxesLibvirtMachine* self);
static void ___lambda75__boxes_notificationbar_ok_func (gpointer self);
void boxes_notificationbar_display_for_action (BoxesNotificationbar* self, const gchar* message, const gchar* action_label, BoxesNotificationbarOKFunc action_func, void* action_func_target, GDestroyNotify action_func_target_destroy_notify, BoxesNotificationbarCancelFunc ignore_func, void* ignore_func_target, GDestroyNotify ignore_func_target_destroy_notify);
static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self);
static void boxes_libvirt_machine_on_storage_changed (BoxesLibvirtMachine* self, guint64 value);
static void _boxes_libvirt_machine_on_storage_changed_property_size_changed (guint64 value, gpointer self);
static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self);
static Block15Data* block15_data_ref (Block15Data* _data15_);
static void block15_data_unref (void * _userdata_);
static gboolean __lambda79_ (Block15Data* _data15_);
gboolean boxes_machine_is_running (BoxesMachine* self);
static gboolean ___lambda79__gsource_func (gpointer self);
GType boxes_iconfig_get_type (void) G_GNUC_CONST;
gboolean boxes_iconfig_get_boolean (BoxesIConfig* self, const gchar* group, const gchar* key, gboolean default_value);
void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value);
void boxes_iconfig_set_boolean (BoxesIConfig* self, const gchar* group, const gchar* key, gboolean value);
static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self);
static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self);
static void boxes_libvirt_machine_finalize (GObject* obj);
static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


static void _vala_BoxesLibvirtMachineMachineStat_array_free (BoxesLibvirtMachineMachineStat* array, gint array_length) {
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (array != NULL) {
#line 947 "libvirt-machine.c"
		int i;
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&array[i]);
#line 953 "libvirt-machine.c"
		}
	}
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 958 "libvirt-machine.c"
}


static void ____lambda53_ (BoxesLibvirtMachine* self) {
	GVirDomain* _tmp0_;
	gulong _tmp1_;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->domain;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->priv->started_id;
#line 29 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 30 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->started_id = (gulong) 0;
#line 31 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_connect_display ((BoxesMachine*) self);
#line 975 "libvirt-machine.c"
}


static void _____lambda53__gvir_domain_resumed (GVirDomain* _sender, gpointer self) {
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	____lambda53_ (self);
#line 982 "libvirt-machine.c"
}


static void ____lambda54_ (BoxesLibvirtMachine* self) {
	GVirDomain* _tmp0_;
	gulong _tmp1_;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->domain;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->priv->started_id;
#line 40 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_handler_disconnect ((GObject*) _tmp0_, _tmp1_);
#line 41 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->started_id = (gulong) 0;
#line 42 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_connect_display ((BoxesMachine*) self);
#line 999 "libvirt-machine.c"
}


static void _____lambda54__gvir_domain_started (GVirDomain* _sender, gpointer self) {
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	____lambda54_ (self);
#line 1006 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_connect_display (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
	BoxesDisplay* _tmp0_;
	BoxesDisplay* _tmp1_;
	BoxesMachineMachineState _tmp2_;
	BoxesMachineMachineState _tmp3_;
	BoxesDisplay* _tmp17_;
	BoxesDisplay* _tmp18_;
	GError * _inner_error_ = NULL;
#line 19 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 20 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != NULL) {
#line 21 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1029 "libvirt-machine.c"
	}
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 23 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_ != BOXES_MACHINE_MACHINE_STATE_RUNNING) {
#line 1037 "libvirt-machine.c"
		gulong _tmp4_;
		BoxesMachineMachineState _tmp5_;
		BoxesMachineMachineState _tmp6_;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->priv->started_id;
#line 24 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp4_ != ((gulong) 0)) {
#line 25 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 1047 "libvirt-machine.c"
		}
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_machine_get_state ((BoxesMachine*) self);
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_;
#line 27 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp6_ == BOXES_MACHINE_MACHINE_STATE_PAUSED) {
#line 1055 "libvirt-machine.c"
			GVirDomain* _tmp7_;
			gulong _tmp8_ = 0UL;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = self->domain;
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = g_signal_connect_object (_tmp7_, "resumed", (GCallback) _____lambda53__gvir_domain_resumed, self, 0);
#line 28 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			self->priv->started_id = _tmp8_;
#line 1064 "libvirt-machine.c"
			{
				GVirDomain* _tmp9_;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp9_ = self->domain;
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_resume (_tmp9_, &_inner_error_);
#line 34 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_inner_error_ != NULL) {
#line 1073 "libvirt-machine.c"
					goto __catch16_g_error;
				}
			}
			goto __finally16;
			__catch16_g_error:
			{
				GError* _error_ = NULL;
				GError* _tmp10_;
				const gchar* _tmp11_;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_error_ = _inner_error_;
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_inner_error_ = NULL;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp10_ = _error_;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp11_ = _tmp10_->message;
#line 36 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_warning ("libvirt-machine.vala:36: %s", _tmp11_);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_error_);
#line 1095 "libvirt-machine.c"
			}
			__finally16:
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_clear_error (&_inner_error_);
#line 33 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				return;
#line 1106 "libvirt-machine.c"
			}
		} else {
			GVirDomain* _tmp12_;
			gulong _tmp13_ = 0UL;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp12_ = self->domain;
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp13_ = g_signal_connect_object (_tmp12_, "started", (GCallback) _____lambda54__gvir_domain_started, self, 0);
#line 39 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			self->priv->started_id = _tmp13_;
#line 1117 "libvirt-machine.c"
			{
				GVirDomain* _tmp14_;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp14_ = self->domain;
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_start (_tmp14_, (guint) 0, &_inner_error_);
#line 45 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_inner_error_ != NULL) {
#line 1126 "libvirt-machine.c"
					goto __catch17_g_error;
				}
			}
			goto __finally17;
			__catch17_g_error:
			{
				GError* _error_ = NULL;
				GError* _tmp15_;
				const gchar* _tmp16_;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_error_ = _inner_error_;
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_inner_error_ = NULL;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp15_ = _error_;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp16_ = _tmp15_->message;
#line 47 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_warning ("libvirt-machine.vala:47: %s", _tmp16_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_error_free0 (_error_);
#line 1148 "libvirt-machine.c"
			}
			__finally17:
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_clear_error (&_inner_error_);
#line 44 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				return;
#line 1159 "libvirt-machine.c"
			}
		}
	}
#line 52 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_display (self);
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = _tmp17_;
#line 53 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_display_connect_it (_tmp18_);
#line 1171 "libvirt-machine.c"
}


void boxes_libvirt_machine_update_domain_config (BoxesLibvirtMachine* self) {
	GError * _inner_error_ = NULL;
#line 82 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 1179 "libvirt-machine.c"
	{
		GVirDomain* _tmp0_;
		GVirConfigDomain* _tmp1_ = NULL;
		GVirConfigDomain* _tmp2_;
		GVirConnection* _tmp3_;
		GVirDomain* _tmp4_;
		GVirStorageVol* _tmp5_ = NULL;
		GVirStorageVol* volume;
		const gchar* _tmp6_ = NULL;
		GVirStorageVol* _tmp7_;
		const gchar* _tmp10_;
		gchar* _tmp11_;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = self->domain;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = gvir_domain_get_config (_tmp0_, (guint) 0, &_inner_error_);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 1200 "libvirt-machine.c"
			goto __catch18_g_error;
		}
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self->domain_config);
#line 84 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self->domain_config = _tmp2_;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->connection;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = self->domain;
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = boxes_get_storage_volume (_tmp3_, _tmp4_, NULL);
#line 85 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		volume = _tmp5_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = volume;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp7_ != NULL) {
#line 1219 "libvirt-machine.c"
			GVirStorageVol* _tmp8_;
			const gchar* _tmp9_ = NULL;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = volume;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = gvir_storage_vol_get_path (_tmp8_, &_inner_error_);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = _tmp9_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (volume);
#line 1232 "libvirt-machine.c"
				goto __catch18_g_error;
			}
		} else {
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = NULL;
#line 1238 "libvirt-machine.c"
		}
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _tmp6_;
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = g_strdup (_tmp10_);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (self->priv->storage_volume_path);
#line 86 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self->priv->storage_volume_path = _tmp11_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (volume);
#line 1250 "libvirt-machine.c"
	}
	goto __finally18;
	__catch18_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp12_;
		const gchar* _tmp13_ = NULL;
		GError* _tmp14_;
		const gchar* _tmp15_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = self->domain;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = gvir_domain_get_name (_tmp12_);
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = _error_;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = _tmp14_->message;
#line 88 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("libvirt-machine.vala:88: Failed to fetch configuration for domain '%s'" \
": %s", _tmp13_, _tmp15_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 1276 "libvirt-machine.c"
	}
	__finally18:
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 83 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1287 "libvirt-machine.c"
	}
}


static gpointer _g_object_ref0 (gpointer self) {
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return self ? g_object_ref (self) : NULL;
#line 1295 "libvirt-machine.c"
}


static void _vala_GVirDomainInfo_free (GVirDomainInfo* self) {
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_info_get_type (), self);
#line 1302 "libvirt-machine.c"
}


static void __lambda66_ (BoxesLibvirtMachine* self) {
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1309 "libvirt-machine.c"
}


static void ___lambda66__gvir_domain_started (GVirDomain* _sender, gpointer self) {
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda66_ (self);
#line 1316 "libvirt-machine.c"
}


static void __lambda67_ (BoxesLibvirtMachine* self) {
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 1323 "libvirt-machine.c"
}


static void ___lambda67__gvir_domain_suspended (GVirDomain* _sender, gpointer self) {
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda67_ (self);
#line 1330 "libvirt-machine.c"
}


static void __lambda68_ (BoxesLibvirtMachine* self) {
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 1337 "libvirt-machine.c"
}


static void ___lambda68__gvir_domain_resumed (GVirDomain* _sender, gpointer self) {
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda68_ (self);
#line 1344 "libvirt-machine.c"
}


static void __lambda69_ (BoxesLibvirtMachine* self) {
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 1351 "libvirt-machine.c"
}


static void ___lambda69__gvir_domain_stopped (GVirDomain* _sender, gpointer self) {
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda69_ (self);
#line 1358 "libvirt-machine.c"
}


static void _boxes_libvirt_machine_update_domain_config_gvir_domain_updated (GVirDomain* _sender, gpointer self) {
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 1365 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_construct (GType object_type, BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
	BoxesLibvirtMachine * self = NULL;
	BoxesCollectionSource* _tmp0_;
	GVirDomain* _tmp1_;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_;
	const gchar* _tmp4_;
	gchar* _tmp5_;
	gchar* _tmp6_;
	BoxesCollectionSource* _tmp7_;
	GVirDomain* _tmp8_;
	const gchar* _tmp9_ = NULL;
	BoxesDisplayConfig* _tmp10_;
	GVirConnection* _tmp11_;
	GVirConnection* _tmp12_;
	GVirDomain* _tmp13_;
	GVirDomain* _tmp14_;
	GVirDomain* _tmp22_;
	GVirDomain* _tmp23_;
	GVirDomain* _tmp24_;
	GVirDomain* _tmp25_;
	GVirConfigDomain* _tmp26_;
	const gchar* _tmp27_ = NULL;
	gchar* _tmp28_;
	gchar* _tmp29_;
	const gchar* _tmp30_;
	const gchar* _tmp34_;
	GVirDomain* _tmp35_;
	GError * _inner_error_ = NULL;
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (source != NULL, NULL);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (connection != NULL, NULL);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (domain != NULL, NULL);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = source;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = domain;
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_get_name (_tmp1_);
#line 95 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) boxes_machine_construct (object_type, _tmp0_, _tmp2_);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = _tmp3_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = g_strconcat ("new libvirt machine: ", _tmp4_, NULL);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = _tmp5_;
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:97: %s", _tmp6_);
#line 97 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp6_);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = source;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = domain;
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = gvir_domain_get_uuid (_tmp8_);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = boxes_display_config_new (_tmp7_, _tmp9_);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (((BoxesMachine*) self)->config);
#line 98 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	((BoxesMachine*) self)->config = _tmp10_;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = connection;
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = _g_object_ref0 (_tmp11_);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->connection);
#line 99 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->connection = _tmp12_;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = domain;
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = _g_object_ref0 (_tmp13_);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->domain);
#line 100 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->domain = _tmp14_;
#line 1452 "libvirt-machine.c"
	{
		GVirDomain* _tmp15_;
		GVirDomainInfo* _tmp16_ = NULL;
		GVirDomainInfo* _tmp17_;
		GVirDomainInfo* _tmp18_;
		GVirDomainState _tmp19_;
		GVirDomainState _tmp20_;
		GVirDomainState s;
		GVirDomainState _tmp21_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = domain;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp16_ = gvir_domain_get_info (_tmp15_, &_inner_error_);
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp17_ = _tmp16_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 1470 "libvirt-machine.c"
			goto __catch19_g_error;
		}
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp18_ = _tmp17_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = _tmp18_->state;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp20_ = _tmp19_;
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_tmp18_);
#line 103 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		s = _tmp20_;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp21_ = s;
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		switch (_tmp21_) {
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_RUNNING:
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_BLOCKED:
#line 1491 "libvirt-machine.c"
			{
#line 107 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_RUNNING);
#line 108 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1497 "libvirt-machine.c"
			}
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_PAUSED:
#line 1501 "libvirt-machine.c"
			{
#line 110 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_PAUSED);
#line 111 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1507 "libvirt-machine.c"
			}
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTDOWN:
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_SHUTOFF:
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_CRASHED:
#line 1515 "libvirt-machine.c"
			{
#line 115 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_STOPPED);
#line 116 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1521 "libvirt-machine.c"
			}
			default:
#line 104 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			case GVIR_DOMAIN_STATE_NONE:
#line 1526 "libvirt-machine.c"
			{
#line 119 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 120 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 1532 "libvirt-machine.c"
			}
		}
	}
	goto __finally19;
	__catch19_g_error:
	{
		GError* _error_ = NULL;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 123 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_machine_set_state ((BoxesMachine*) self, BOXES_MACHINE_MACHINE_STATE_UNKNOWN);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 1548 "libvirt-machine.c"
	}
	__finally19:
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 102 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 1559 "libvirt-machine.c"
	}
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = domain;
#line 126 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp22_, "started", (GCallback) ___lambda66__gvir_domain_started, self, 0);
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = domain;
#line 127 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp23_, "suspended", (GCallback) ___lambda67__gvir_domain_suspended, self, 0);
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = domain;
#line 128 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp24_, "resumed", (GCallback) ___lambda68__gvir_domain_resumed, self, 0);
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = domain;
#line 129 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp25_, "stopped", (GCallback) ___lambda69__gvir_domain_stopped, self, 0);
#line 131 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp26_ = self->domain_config;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp27_ = gvir_config_domain_get_title (_tmp26_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp28_ = g_strdup (_tmp27_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp29_ = _tmp28_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp30_ = _tmp29_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp30_ == NULL) {
#line 1591 "libvirt-machine.c"
		const gchar* _tmp31_;
		const gchar* _tmp32_;
		gchar* _tmp33_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp31_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp32_ = _tmp31_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = g_strdup (_tmp32_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp29_);
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp29_ = _tmp33_;
#line 1605 "libvirt-machine.c"
	}
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = _tmp29_;
#line 132 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_collection_item_set_title ((BoxesCollectionItem*) self, _tmp34_);
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp35_ = domain;
#line 133 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_connect_object (_tmp35_, "updated", (GCallback) _boxes_libvirt_machine_update_domain_config_gvir_domain_updated, self, 0);
#line 135 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_load_screenshot ((BoxesMachine*) self);
#line 136 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_machine_set_screenshot_enable ((BoxesMachine*) self, TRUE);
#line 137 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_stats_enable (self, TRUE);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp29_);
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return self;
#line 1625 "libvirt-machine.c"
}


BoxesLibvirtMachine* boxes_libvirt_machine_new (BoxesCollectionSource* source, GVirConnection* connection, GVirDomain* domain, GError** error) {
#line 92 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return boxes_libvirt_machine_construct (BOXES_TYPE_LIBVIRT_MACHINE, source, connection, domain, error);
#line 1632 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_cpu_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	BoxesLibvirtMachineMachineStat* _tmp0_;
	gint _tmp0__length1;
	BoxesLibvirtMachineMachineStat _tmp1_;
	BoxesLibvirtMachineMachineStat _tmp2_ = {0};
	BoxesLibvirtMachineMachineStat prev;
	gboolean _tmp3_ = FALSE;
	GVirDomainInfo* _tmp4_;
	GVirDomainState _tmp5_;
	gboolean _tmp8_;
	GVirDomainInfo* _tmp9_;
	guint64 _tmp10_;
	BoxesLibvirtMachineMachineStat _tmp11_;
	gdouble _tmp12_;
	GVirDomainInfo* _tmp13_;
	guint64 _tmp14_;
	BoxesLibvirtMachineMachineStat _tmp15_;
	gint64 _tmp16_;
	BoxesLibvirtMachineMachineStat _tmp17_;
	gint64 _tmp18_;
	gint64 dt;
	BoxesLibvirtMachineMachineStat _tmp19_;
	gdouble _tmp20_;
	gint64 _tmp21_;
	gdouble percent;
	gdouble _tmp22_;
	GVirDomainInfo* _tmp23_;
	guint16 _tmp24_;
	gdouble _tmp25_;
	gdouble _tmp26_ = 0.0;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->priv->stats;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0__length1 = self->priv->stats_length1;
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (&_tmp1_, &_tmp2_);
#line 141 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	prev = _tmp2_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->state;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_ == GVIR_DOMAIN_STATE_CRASHED) {
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = TRUE;
#line 1690 "libvirt-machine.c"
	} else {
		GVirDomainInfo* _tmp6_;
		GVirDomainState _tmp7_;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = info;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _tmp6_->state;
#line 144 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp7_ == GVIR_DOMAIN_STATE_SHUTOFF;
#line 1700 "libvirt-machine.c"
	}
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = _tmp3_;
#line 143 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp8_) {
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 145 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1710 "libvirt-machine.c"
	}
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = info;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = _tmp9_->cpuTime;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = prev;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = _tmp11_.cpu_time_abs;
#line 147 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time = _tmp10_ - _tmp12_;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp13_ = info;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp14_ = _tmp13_->cpuTime;
#line 148 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_time_abs = (gdouble) _tmp14_;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp15_ = *stat;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp16_ = _tmp15_.timestamp;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = prev;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = _tmp17_.timestamp;
#line 150 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	dt = (_tmp16_ - _tmp18_) * 10;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = *stat;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = _tmp19_.cpu_time;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp21_ = dt;
#line 151 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp20_ / _tmp21_;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp22_ = percent;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp23_ = info;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp24_ = _tmp23_->nrVirtCpu;
#line 152 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	percent = _tmp22_ / _tmp24_;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp25_ = percent;
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp26_ = CLAMP (_tmp25_, (gdouble) 0, (gdouble) 100);
#line 153 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*stat).cpu_guest_percent = _tmp26_;
#line 140 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (&prev);
#line 1762 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_mem_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat) {
	GVirDomainInfo* _tmp0_;
	GVirDomainState _tmp1_;
	GVirDomainInfo* _tmp2_;
	guint64 _tmp3_;
	GVirDomainInfo* _tmp4_;
	guint64 _tmp5_;
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (info != NULL);
#line 156 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (stat != NULL);
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = info;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_->state;
#line 157 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 158 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1787 "libvirt-machine.c"
	}
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = info;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_->memory;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = info;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->maxMem;
#line 160 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*stat).memory_percent = (_tmp3_ * 100.0) / _tmp5_;
#line 1799 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	_data_ = _data;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateIoStatData, _data_);
#line 1812 "libvirt-machine.c"
}


static GVirDomainInfo* _vala_GVirDomainInfo_copy (GVirDomainInfo* self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_info_get_type (), self);
#line 1819 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInfo_copy0 (gpointer self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInfo_copy (self) : NULL;
#line 1826 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainInfo* _tmp2_;
	BoxesLibvirtMachineMachineStat* _tmp3_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateIoStatData);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_io_stat);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_io_stat_data_free);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 1858 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1866 "libvirt-machine.c"
}


static Block8Data* block8_data_ref (Block8Data* _data8_) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data8_->_ref_count_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data8_;
#line 1875 "libvirt-machine.c"
}


static void block8_data_unref (void * _userdata_) {
	Block8Data* _data8_;
	_data8_ = (Block8Data*) _userdata_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data8_->_ref_count_)) {
#line 1884 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data8_->self;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block8Data, _data8_);
#line 1892 "libvirt-machine.c"
	}
}


static Block9Data* block9_data_ref (Block9Data* _data9_) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data9_->_ref_count_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data9_;
#line 1902 "libvirt-machine.c"
}


static void block9_data_unref (void * _userdata_) {
	Block9Data* _data9_;
	_data9_ = (Block9Data*) _userdata_;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data9_->_ref_count_)) {
#line 1911 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data9_->_data8_->self;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data9_->disk);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block8_data_unref (_data9_->_data8_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data9_->_data8_ = NULL;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block9Data, _data9_);
#line 1923 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainDiskStats_free (GVirDomainDiskStats* self) {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_disk_stats_get_type (), self);
#line 1931 "libvirt-machine.c"
}


static void ___lambda71_ (Block9Data* _data9_, GError** error) {
	Block8Data* _data8_;
	BoxesLibvirtMachine * self;
	GVirDomainDisk* _tmp0_;
	GVirDomainDiskStats* _tmp1_ = NULL;
	GVirDomainDiskStats* _tmp2_;
	BoxesLibvirtMachineMachineStat* _tmp3_;
	GError * _inner_error_ = NULL;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data8_ = _data9_->_data8_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data8_->self;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _data9_->disk;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_domain_disk_get_stats (_tmp0_, &_inner_error_);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 1959 "libvirt-machine.c"
	}
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _data8_->stat;
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*_tmp3_).disk);
#line 173 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*_tmp3_).disk = _tmp2_;
#line 1967 "libvirt-machine.c"
}


static void ____lambda71__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	___lambda71_ (self, error);
#line 1974 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_io_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateIoStatData* _data_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_io_stat_co (_data_);
#line 1988 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_io_stat_co (BoxesLibvirtMachineUpdateIoStatData* _data_) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 1997 "libvirt-machine.c"
		goto _state_0;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2001 "libvirt-machine.c"
		goto _state_1;
		default:
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2006 "libvirt-machine.c"
	}
	_state_0:
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_ = g_slice_new0 (Block8Data);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_->_ref_count_ = 1;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_->self = g_object_ref (_data_->self);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_->stat = _data_->_tmp0_;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_->_async_data_ = _data_;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 164 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block8_data_unref (_data_->_data8_);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data8_ = NULL;
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2035 "libvirt-machine.c"
		} else {
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2039 "libvirt-machine.c"
		}
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 165 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2045 "libvirt-machine.c"
	}
	{
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data9_ = g_slice_new0 (Block9Data);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data9_->_ref_count_ = 1;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data9_->_data8_ = block8_data_ref (_data_->_data8_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_disk (_data_->self, &_data_->_inner_error_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data9_->disk = _data_->_tmp3_;
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block9_data_unref (_data_->_data9_);
#line 168 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data9_ = NULL;
#line 2066 "libvirt-machine.c"
			goto __catch20_g_error;
		}
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data9_->disk;
#line 169 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block9_data_unref (_data_->_data9_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data9_ = NULL;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block8_data_unref (_data_->_data8_);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data8_ = NULL;
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2085 "libvirt-machine.c"
			} else {
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2089 "libvirt-machine.c"
			}
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 170 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 2095 "libvirt-machine.c"
		}
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda71__boxes_run_in_thread_func, _data_->_data9_, NULL, boxes_libvirt_machine_update_io_stat_ready, _data_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2103 "libvirt-machine.c"
		_state_1:
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block9_data_unref (_data_->_data9_);
#line 172 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data9_ = NULL;
#line 2113 "libvirt-machine.c"
			goto __catch20_g_error;
		}
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 175 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.disk;
#line 176 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data8_->stat;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = _data_->_data8_->stat;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = (*_data_->_tmp11_).disk;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->_tmp12_->rd_bytes;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->prev;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_.disk;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_tmp15_->rd_bytes;
#line 177 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_tmp10_).disk_read = (gdouble) (_data_->_tmp13_ - _data_->_tmp16_);
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = _data_->_data8_->stat;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_data8_->stat;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = (*_data_->_tmp18_).disk;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_->wr_bytes;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->prev;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22_ = _data_->_tmp21_.disk;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = _data_->_tmp22_->wr_bytes;
#line 178 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_tmp17_).disk_write = (gdouble) (_data_->_tmp20_ - _data_->_tmp23_);
#line 2166 "libvirt-machine.c"
		}
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block9_data_unref (_data_->_data9_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data9_ = NULL;
#line 2174 "libvirt-machine.c"
	}
	goto __finally20;
	__catch20_g_error:
	{
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp26_ = _data_->err;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp27_ = _data_->_tmp26_->message;
#line 181 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:181: Failed to fetch I/O statistics for %s: %s", _data_->_tmp25_, _data_->_tmp27_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 2195 "libvirt-machine.c"
	}
	__finally20:
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block8_data_unref (_data_->_data8_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data8_ = NULL;
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 167 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2210 "libvirt-machine.c"
	}
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block8_data_unref (_data_->_data8_);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data8_ = NULL;
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2220 "libvirt-machine.c"
	} else {
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2224 "libvirt-machine.c"
	}
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 163 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 2230 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	_data_ = _data;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInfo_free0 (_data_->info);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateNetStatData, _data_);
#line 2243 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat (BoxesLibvirtMachine* self, GVirDomainInfo* info, BoxesLibvirtMachineMachineStat* stat, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
	BoxesLibvirtMachine* _tmp0_;
	GVirDomainInfo* _tmp1_;
	GVirDomainInfo* _tmp2_;
	BoxesLibvirtMachineMachineStat* _tmp3_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateNetStatData);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_net_stat);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_net_stat_data_free);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = info;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = __vala_GVirDomainInfo_copy0 (_tmp1_);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->info = _tmp2_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = stat;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->stat = _tmp3_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2275 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2283 "libvirt-machine.c"
}


static Block10Data* block10_data_ref (Block10Data* _data10_) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data10_->_ref_count_);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data10_;
#line 2292 "libvirt-machine.c"
}


static void block10_data_unref (void * _userdata_) {
	Block10Data* _data10_;
	_data10_ = (Block10Data*) _userdata_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data10_->_ref_count_)) {
#line 2301 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data10_->self;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block10Data, _data10_);
#line 2309 "libvirt-machine.c"
	}
}


static Block11Data* block11_data_ref (Block11Data* _data11_) {
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data11_->_ref_count_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data11_;
#line 2319 "libvirt-machine.c"
}


static void block11_data_unref (void * _userdata_) {
	Block11Data* _data11_;
	_data11_ = (Block11Data*) _userdata_;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data11_->_ref_count_)) {
#line 2328 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data11_->_data10_->self;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data11_->net);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block10_data_unref (_data11_->_data10_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data11_->_data10_ = NULL;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block11Data, _data11_);
#line 2340 "libvirt-machine.c"
	}
}


static void _vala_GVirDomainInterfaceStats_free (GVirDomainInterfaceStats* self) {
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_domain_interface_stats_get_type (), self);
#line 2348 "libvirt-machine.c"
}


static void ___lambda72_ (Block11Data* _data11_, GError** error) {
	Block10Data* _data10_;
	BoxesLibvirtMachine * self;
	GVirDomainInterface* _tmp0_;
	GVirDomainInterfaceStats* _tmp1_ = NULL;
	GVirDomainInterfaceStats* _tmp2_;
	BoxesLibvirtMachineMachineStat* _tmp3_;
	GError * _inner_error_ = NULL;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data10_ = _data11_->_data10_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data10_->self;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _data11_->net;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_domain_interface_get_stats (_tmp0_, &_inner_error_);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 2376 "libvirt-machine.c"
	}
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _data10_->stat;
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*_tmp3_).net);
#line 195 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*_tmp3_).net = _tmp2_;
#line 2384 "libvirt-machine.c"
}


static void ____lambda72__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	___lambda72_ (self, error);
#line 2391 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_net_stat_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateNetStatData* _data_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_net_stat_co (_data_);
#line 2405 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_net_stat_co (BoxesLibvirtMachineUpdateNetStatData* _data_) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2414 "libvirt-machine.c"
		goto _state_0;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2418 "libvirt-machine.c"
		goto _state_1;
		default:
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2423 "libvirt-machine.c"
	}
	_state_0:
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_ = g_slice_new0 (Block10Data);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_->_ref_count_ = 1;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_->self = g_object_ref (_data_->self);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp0_ = _data_->stat;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_->stat = _data_->_tmp0_;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_->_async_data_ = _data_;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = _data_->info;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_->state;
#line 186 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block10_data_unref (_data_->_data10_);
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data10_ = NULL;
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2452 "libvirt-machine.c"
		} else {
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2456 "libvirt-machine.c"
		}
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 187 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2462 "libvirt-machine.c"
	}
	{
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data11_ = g_slice_new0 (Block11Data);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data11_->_ref_count_ = 1;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data11_->_data10_ = block10_data_ref (_data_->_data10_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = NULL;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = boxes_libvirt_machine_get_domain_network_interface (_data_->self, &_data_->_inner_error_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data11_->net = _data_->_tmp3_;
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block11_data_unref (_data_->_data11_);
#line 190 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data11_ = NULL;
#line 2483 "libvirt-machine.c"
			goto __catch21_g_error;
		}
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_data11_->net;
#line 191 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp4_ == NULL) {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block11_data_unref (_data_->_data11_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data11_ = NULL;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block10_data_unref (_data_->_data10_);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data10_ = NULL;
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2502 "libvirt-machine.c"
			} else {
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2506 "libvirt-machine.c"
			}
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 192 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 2512 "libvirt-machine.c"
		}
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread (____lambda72__boxes_run_in_thread_func, _data_->_data11_, NULL, boxes_libvirt_machine_update_net_stat_ready, _data_);
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2520 "libvirt-machine.c"
		_state_1:
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block11_data_unref (_data_->_data11_);
#line 194 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_data11_ = NULL;
#line 2530 "libvirt-machine.c"
			goto __catch21_g_error;
		}
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->priv->stats;
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5__length1 = _data_->self->priv->stats_length1;
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_[BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1];
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp7_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp6_, &_data_->_tmp7_);
#line 197 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->prev = _data_->_tmp7_;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->prev;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->_tmp8_.net;
#line 198 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_tmp9_ != NULL) {
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp10_ = _data_->_data10_->stat;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp11_ = _data_->_data10_->stat;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp12_ = (*_data_->_tmp11_).net;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp13_ = _data_->_tmp12_->rx_bytes;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp14_ = _data_->prev;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp15_ = _data_->_tmp14_.net;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp16_ = _data_->_tmp15_->rx_bytes;
#line 199 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_tmp10_).net_read = (gdouble) (_data_->_tmp13_ - _data_->_tmp16_);
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp17_ = _data_->_data10_->stat;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = _data_->_data10_->stat;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = (*_data_->_tmp18_).net;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp20_ = _data_->_tmp19_->tx_bytes;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->prev;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22_ = _data_->_tmp21_.net;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = _data_->_tmp22_->tx_bytes;
#line 200 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			(*_data_->_tmp17_).net_write = (gdouble) (_data_->_tmp20_ - _data_->_tmp23_);
#line 2583 "libvirt-machine.c"
		}
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->prev);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block11_data_unref (_data_->_data11_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data11_ = NULL;
#line 2591 "libvirt-machine.c"
	}
	goto __finally21;
	__catch21_g_error:
	{
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp24_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp25_ = _data_->_tmp24_;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp26_ = _data_->err;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp27_ = _data_->_tmp26_->message;
#line 203 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:203: Failed to fetch network statistics for %s: %" \
"s", _data_->_tmp25_, _data_->_tmp27_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 2612 "libvirt-machine.c"
	}
	__finally21:
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block10_data_unref (_data_->_data10_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data10_ = NULL;
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 189 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2627 "libvirt-machine.c"
	}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block10_data_unref (_data_->_data10_);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data10_ = NULL;
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2637 "libvirt-machine.c"
	} else {
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2641 "libvirt-machine.c"
	}
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 185 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 2647 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_data_free (gpointer _data) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	_data_ = _data;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineUpdateStatsData, _data_);
#line 2658 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
	BoxesLibvirtMachine* _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineUpdateStatsData);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_update_stats);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_update_stats_data_free);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 2677 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2685 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_stats_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineUpdateStatsData* _data_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats_co (_data_);
#line 2699 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* _vala_array_dup1 (BoxesLibvirtMachineMachineStat* self, int length) {
	BoxesLibvirtMachineMachineStat* result;
	int i;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = g_new0 (BoxesLibvirtMachineMachineStat, length);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	for (i = 0; i < length; i++) {
#line 2710 "libvirt-machine.c"
		BoxesLibvirtMachineMachineStat _tmp0_ = {0};
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&self[i], &_tmp0_);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		result[i] = _tmp0_;
#line 2716 "libvirt-machine.c"
	}
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 2720 "libvirt-machine.c"
}


static void _vala_array_add2 (BoxesLibvirtMachineMachineStat** array, int* length, int* size, const BoxesLibvirtMachineMachineStat* value) {
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (BoxesLibvirtMachineMachineStat, *array, *size);
#line 2731 "libvirt-machine.c"
	}
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = *value;
#line 2735 "libvirt-machine.c"
}


static void _vala_array_add3 (gdouble** array, int* length, int* size, gdouble value) {
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 2746 "libvirt-machine.c"
	}
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 2750 "libvirt-machine.c"
}


static void _vala_array_add4 (gdouble** array, int* length, int* size, gdouble value) {
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 2761 "libvirt-machine.c"
	}
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 2765 "libvirt-machine.c"
}


static void _vala_array_add5 (gdouble** array, int* length, int* size, gdouble value) {
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if ((*length) == (*size)) {
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		*array = g_renew (gdouble, *array, *size);
#line 2776 "libvirt-machine.c"
	}
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*array)[(*length)++] = value;
#line 2780 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_update_stats_co (BoxesLibvirtMachineUpdateStatsData* _data_) {
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 2789 "libvirt-machine.c"
		goto _state_0;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 2793 "libvirt-machine.c"
		goto _state_1;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 2797 "libvirt-machine.c"
		goto _state_2;
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 2801 "libvirt-machine.c"
		goto _state_3;
		default:
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 2806 "libvirt-machine.c"
	}
	_state_0:
	{
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = 0LL;
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = g_get_monotonic_time ();
#line 214 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->now = _data_->_tmp0_;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = _data_->now;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp2_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_.timestamp = _data_->_tmp1_;
#line 215 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat = _data_->_tmp2_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->self->domain;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->self->priv->stats_cancellable;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp3_, _data_->_tmp4_, boxes_libvirt_machine_update_stats_ready, _data_);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2836 "libvirt-machine.c"
		_state_1:
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = NULL;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = gvir_domain_get_info_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->info = _data_->_tmp5_;
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 216 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (g_error_matches (_data_->_inner_error_, G_IO_ERROR, G_IO_ERROR_CANCELLED)) {
#line 2850 "libvirt-machine.c"
				goto __catch22_g_io_error_cancelled;
			}
			goto __catch22_g_error;
		}
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->info;
#line 218 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_cpu_stat (_data_->self, _data_->_tmp6_, &_data_->stat);
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->info;
#line 219 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_mem_stat (_data_->self, _data_->_tmp7_, &_data_->stat);
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp8_ = _data_->info;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 2;
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat (_data_->self, _data_->_tmp8_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2871 "libvirt-machine.c"
		_state_2:
#line 220 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_io_stat_finish (_data_->self, _data_->_res_);
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->info;
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 3;
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat (_data_->self, _data_->_tmp9_, &_data_->stat, boxes_libvirt_machine_update_stats_ready, _data_);
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2883 "libvirt-machine.c"
		_state_3:
#line 221 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_update_net_stat_finish (_data_->self, _data_->_res_);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10_ = _data_->self->priv->stats;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp10__length1 = _data_->self->priv->stats_length1;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11_ = ((_data_->_tmp10_ + 1) != NULL) ? _vala_array_dup1 (_data_->_tmp10_ + 1, BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1) : ((gpointer) (_data_->_tmp10_ + 1));
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp11__length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE - 1;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (_data_->self->priv->stats, _data_->self->priv->stats_length1), NULL);
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats = _data_->_tmp11_;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->stats_length1 = _data_->_tmp11__length1;
#line 223 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->self->priv->_stats_size_ = _data_->self->priv->stats_length1;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12_ = _data_->self->priv->stats;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp12__length1 = _data_->self->priv->stats_length1;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp13_ = _data_->stat;
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		memset (&_data_->_tmp14_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_copy (&_data_->_tmp13_, &_data_->_tmp14_);
#line 224 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_vala_array_add2 (&_data_->self->priv->stats, &_data_->self->priv->stats_length1, &_data_->self->priv->_stats_size_, &_data_->_tmp14_);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->info);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_machine_stat_destroy (&_data_->stat);
#line 2919 "libvirt-machine.c"
	}
	goto __finally22;
	__catch22_g_io_error_cancelled:
	{
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->err = _data_->_inner_error_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->err);
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2934 "libvirt-machine.c"
		} else {
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2938 "libvirt-machine.c"
		}
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 227 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2944 "libvirt-machine.c"
	}
	goto __finally22;
	__catch22_g_error:
	{
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_vala1_err = _data_->_inner_error_;
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp15_ = _data_->_vala1_err;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp16_ = _data_->_tmp15_->message;
#line 229 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:229: %s", _data_->_tmp16_);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_vala1_err);
#line 2961 "libvirt-machine.c"
	}
	__finally22:
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_data_->_inner_error_);
#line 213 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 2972 "libvirt-machine.c"
	}
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_new0 (gdouble, 0);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = (g_free (_data_->self->cpu_stats), NULL);
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats = _data_->_tmp17_;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->cpu_stats_length1 = 0;
#line 232 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_cpu_stats_size_ = _data_->self->cpu_stats_length1;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = NULL;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp18_ = g_new0 (gdouble, 0);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = (g_free (_data_->self->io_stats), NULL);
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats = _data_->_tmp18_;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->io_stats_length1 = 0;
#line 233 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_io_stats_size_ = _data_->self->io_stats_length1;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = NULL;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp19_ = g_new0 (gdouble, 0);
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = (g_free (_data_->self->net_stats), NULL);
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats = _data_->_tmp19_;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->net_stats_length1 = 0;
#line 234 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self->_net_stats_size_ = _data_->self->net_stats_length1;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20_ = _data_->self->priv->stats;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp20__length1 = _data_->self->priv->stats_length1;
#line 3014 "libvirt-machine.c"
	{
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = 0;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_stat_collection_size_ = 0;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection = _data_->_tmp20_;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->stat_collection_length1 = _data_->_tmp20__length1;
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (_data_->stat_it = 0; _data_->stat_it < _data_->_tmp20__length1; _data_->stat_it = _data_->stat_it + 1) {
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			memset (&_data_->_tmp21_, 0, sizeof (BoxesLibvirtMachineMachineStat));
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_machine_stat_copy (&_data_->stat_collection[_data_->stat_it], &_data_->_tmp21_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_vala1_stat = _data_->_tmp21_;
#line 3032 "libvirt-machine.c"
			{
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22_ = _data_->self->cpu_stats;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp22__length1 = _data_->self->cpu_stats_length1;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp23_ = _data_->_vala1_stat;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp24_ = _data_->_tmp23_.cpu_guest_percent;
#line 237 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add3 (&_data_->self->cpu_stats, &_data_->self->cpu_stats_length1, &_data_->self->_cpu_stats_size_, _data_->_tmp24_);
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25_ = _data_->self->net_stats;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp25__length1 = _data_->self->net_stats_length1;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp26_ = _data_->_vala1_stat;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp27_ = _data_->_tmp26_.net_read;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp28_ = _data_->_vala1_stat;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp29_ = _data_->_tmp28_.net_write;
#line 238 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add4 (&_data_->self->net_stats, &_data_->self->net_stats_length1, &_data_->self->_net_stats_size_, _data_->_tmp27_ + _data_->_tmp29_);
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30_ = _data_->self->io_stats;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp30__length1 = _data_->self->io_stats_length1;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp31_ = _data_->_vala1_stat;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp32_ = _data_->_tmp31_.disk_read;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp33_ = _data_->_vala1_stat;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp34_ = _data_->_tmp33_.disk_write;
#line 239 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_vala_array_add5 (&_data_->self->io_stats, &_data_->self->io_stats_length1, &_data_->self->_io_stats_size_, _data_->_tmp32_ + _data_->_tmp34_);
#line 236 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_libvirt_machine_machine_stat_destroy (&_data_->_vala1_stat);
#line 3074 "libvirt-machine.c"
			}
		}
	}
#line 242 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_emit_by_name (_data_->self, "stats-updated");
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3084 "libvirt-machine.c"
	} else {
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3088 "libvirt-machine.c"
	}
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 212 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 3094 "libvirt-machine.c"
}


static Block12Data* block12_data_ref (Block12Data* _data12_) {
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data12_->_ref_count_);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data12_;
#line 3103 "libvirt-machine.c"
}


static void block12_data_unref (void * _userdata_) {
	Block12Data* _data12_;
	_data12_ = (Block12Data*) _userdata_;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data12_->_ref_count_)) {
#line 3112 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data12_->self;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block12Data, _data12_);
#line 3120 "libvirt-machine.c"
	}
}


static void __lambda73_ (Block12Data* _data12_) {
	BoxesLibvirtMachine * self;
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data12_->self;
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data12_->stats_updating = FALSE;
#line 3131 "libvirt-machine.c"
}


static void ___lambda73__gasync_ready_callback (GObject* source_object, GAsyncResult* res, gpointer self) {
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda73_ (self);
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block12_data_unref (self);
#line 3140 "libvirt-machine.c"
}


static gboolean ___lambda70_ (Block12Data* _data12_) {
	BoxesLibvirtMachine * self;
	gboolean result = FALSE;
	gboolean _tmp0_;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data12_->self;
#line 254 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _data12_->stats_updating;
#line 254 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3154 "libvirt-machine.c"
		const gchar* _tmp1_;
		const gchar* _tmp2_;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 255 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:255: Fetching of stats for '%s' is taking too lon" \
"g. Probably a libvirt bug.", _tmp2_);
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		result = TRUE;
#line 257 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 3167 "libvirt-machine.c"
	}
#line 260 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data12_->stats_updating = TRUE;
#line 261 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_stats (self, ___lambda73__gasync_ready_callback, block12_data_ref (_data12_));
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = TRUE;
#line 263 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3177 "libvirt-machine.c"
}


static gboolean ____lambda70__gsource_func (gpointer self) {
	gboolean result;
	result = ___lambda70_ (self);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3186 "libvirt-machine.c"
}


static void boxes_libvirt_machine_set_stats_enable (BoxesLibvirtMachine* self, gboolean enable) {
	gboolean _tmp0_;
#line 245 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = enable;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 3198 "libvirt-machine.c"
		Block12Data* _data12_;
		const gchar* _tmp1_;
		const gchar* _tmp2_;
		gchar* _tmp3_;
		gchar* _tmp4_;
		guint _tmp5_;
		GCancellable* _tmp6_;
		guint _tmp7_ = 0U;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data12_ = g_slice_new0 (Block12Data);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data12_->_ref_count_ = 1;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data12_->self = g_object_ref (self);
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = g_strconcat ("enable statistics for ", _tmp2_, NULL);
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:247: %s", _tmp4_);
#line 247 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp4_);
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = self->priv->stats_update_timeout;
#line 248 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp5_ != ((guint) 0)) {
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			block12_data_unref (_data12_);
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data12_ = NULL;
#line 249 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 3235 "libvirt-machine.c"
		}
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = self->priv->stats_cancellable;
#line 251 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_cancellable_reset (_tmp6_);
#line 252 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data12_->stats_updating = FALSE;
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ____lambda70__gsource_func, block12_data_ref (_data12_), block12_data_unref);
#line 253 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = _tmp7_;
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block12_data_unref (_data12_);
#line 246 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data12_ = NULL;
#line 3251 "libvirt-machine.c"
	} else {
		const gchar* _tmp8_;
		const gchar* _tmp9_;
		gchar* _tmp10_;
		gchar* _tmp11_;
		guint _tmp12_;
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_;
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = g_strconcat ("disable statistics for ", _tmp9_, NULL);
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = _tmp10_;
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:266: %s", _tmp11_);
#line 266 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp11_);
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = self->priv->stats_update_timeout;
#line 267 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp12_ != ((guint) 0)) {
#line 3274 "libvirt-machine.c"
			GCancellable* _tmp13_;
			guint _tmp14_;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp13_ = self->priv->stats_cancellable;
#line 268 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_cancellable_cancel (_tmp13_);
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp14_ = self->priv->stats_update_timeout;
#line 269 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_source_remove (_tmp14_);
#line 3285 "libvirt-machine.c"
		}
#line 271 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self->priv->stats_update_timeout = (guint) 0;
#line 3289 "libvirt-machine.c"
	}
}


static void _boxes_pair_unref0_ (gpointer var) {
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(var == NULL) ? NULL : (var = (boxes_pair_unref (var), NULL));
#line 3297 "libvirt-machine.c"
}


static void _g_list_free__boxes_pair_unref0_ (GList* self) {
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_list_foreach (self, (GFunc) _boxes_pair_unref0_, NULL);
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_list_free (self);
#line 3306 "libvirt-machine.c"
}


static GList* boxes_libvirt_machine_real_get_properties (BoxesMachine* base, BoxesPropertiesPage page) {
	BoxesLibvirtMachine * self;
	GList* result = NULL;
	GList* list;
	BoxesPropertiesPage _tmp0_;
	BoxesDisplay* _tmp17_;
	BoxesDisplay* _tmp18_;
	BoxesPropertiesPage _tmp19_;
	GList* _tmp20_ = NULL;
#line 275 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 276 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	list = NULL;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = page;
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_tmp0_) {
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_PROPERTIES_PAGE_LOGIN:
#line 3329 "libvirt-machine.c"
		{
			const gchar* _tmp1_ = NULL;
			BoxesCollectionSource* _tmp2_;
			gchar* _tmp3_;
			gchar* _tmp4_;
			gchar* _tmp5_;
			const gchar* _tmp6_ = NULL;
			BoxesDisplay* _tmp7_;
			BoxesDisplay* _tmp8_;
			gchar* _tmp9_;
			gchar* _tmp10_;
			gchar* _tmp11_;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp1_ = _ ("Virtualizer");
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp2_ = ((BoxesMachine*) self)->source;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp3_ = boxes_collection_source_get_uri (_tmp2_);
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp4_ = _tmp3_;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp5_ = _tmp4_;
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp1_, _tmp5_, NULL, NULL);
#line 280 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp5_);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = _ ("URI");
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = _tmp7_;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = boxes_display_get_uri (_tmp8_);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp10_ = _tmp9_;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp11_ = _tmp10_;
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp6_, _tmp11_, NULL, NULL);
#line 281 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (_tmp11_);
#line 282 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			break;
#line 3374 "libvirt-machine.c"
		}
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_PROPERTIES_PAGE_SYSTEM:
#line 3378 "libvirt-machine.c"
		{
#line 285 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_add_ram_property (self, &list);
#line 286 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_libvirt_machine_add_storage_property (self, &list);
#line 287 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			break;
#line 3386 "libvirt-machine.c"
		}
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_PROPERTIES_PAGE_DISPLAY:
#line 3390 "libvirt-machine.c"
		{
			const gchar* _tmp12_ = NULL;
			BoxesDisplay* _tmp13_;
			BoxesDisplay* _tmp14_;
			const gchar* _tmp15_;
			const gchar* _tmp16_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp12_ = _ ("Protocol");
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp13_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp14_ = _tmp13_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp15_ = boxes_display_get_protocol (_tmp14_);
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp16_ = _tmp15_;
#line 290 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			boxes_iproperties_provider_add_string_property ((BoxesIPropertiesProvider*) self, &list, _tmp12_, _tmp16_, NULL, NULL);
#line 291 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			break;
#line 3411 "libvirt-machine.c"
		}
		default:
#line 278 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 3416 "libvirt-machine.c"
	}
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp17_ = boxes_machine_get_display ((BoxesMachine*) self);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp18_ = _tmp17_;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp19_ = page;
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp20_ = boxes_display_get_properties (_tmp18_, _tmp19_);
#line 294 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	list = g_list_concat (list, _tmp20_);
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = list;
#line 296 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3432 "libvirt-machine.c"
}


static const gchar* string_to_string (const gchar* self) {
	const gchar* result = NULL;
#line 1418 "../vapi/upstream/glib-2.0.vapi"
	g_return_val_if_fail (self != NULL, NULL);
#line 1419 "../vapi/upstream/glib-2.0.vapi"
	result = self;
#line 1419 "../vapi/upstream/glib-2.0.vapi"
	return result;
#line 3444 "libvirt-machine.c"
}


static void boxes_libvirt_machine_update_display (BoxesLibvirtMachine* self) {
	gchar* type = NULL;
	gchar* port = NULL;
	gchar* socket = NULL;
	gchar* host = NULL;
	gboolean _tmp31_ = FALSE;
	const gchar* _tmp32_;
	gboolean _tmp34_;
	const gchar* _tmp36_;
	const gchar* _tmp37_;
	GQuark _tmp39_ = 0U;
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp38_label0 = 0;
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	static GQuark _tmp38_label1 = 0;
#line 3463 "libvirt-machine.c"
	GError * _inner_error_ = NULL;
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 302 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_update_domain_config (self);
#line 3469 "libvirt-machine.c"
	{
		GVirConfigDomain* _tmp0_;
		gchar* _tmp1_ = NULL;
		gchar* xmldoc;
		const gchar* _tmp2_;
		gchar* _tmp3_ = NULL;
		gchar* _tmp4_;
		const gchar* _tmp5_;
		const gchar* _tmp6_;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_;
		gchar* _tmp10_ = NULL;
		gchar* _tmp11_;
		gchar* _tmp12_;
		const gchar* _tmp13_;
		const gchar* _tmp14_;
		const gchar* _tmp15_ = NULL;
		gchar* _tmp16_ = NULL;
		gchar* _tmp17_;
		gchar* _tmp18_ = NULL;
		gchar* _tmp19_;
		gchar* _tmp20_;
		const gchar* _tmp21_;
		const gchar* _tmp22_;
		const gchar* _tmp23_ = NULL;
		gchar* _tmp24_ = NULL;
		gchar* _tmp25_;
		gchar* _tmp26_ = NULL;
		gchar* _tmp27_;
		gchar* _tmp28_;
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = self->domain_config;
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = gvir_config_object_to_xml ((GVirConfigObject*) _tmp0_);
#line 305 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		xmldoc = _tmp1_;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = xmldoc;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = boxes_extract_xpath (_tmp2_, "string(/domain/devices/graphics/@type)", TRUE, &_inner_error_);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_;
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 3517 "libvirt-machine.c"
			goto __catch23_g_error;
		}
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (type);
#line 306 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		type = _tmp4_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = xmldoc;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = type;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = string_to_string (_tmp6_);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp7_, "']/@port)", NULL);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = boxes_extract_xpath (_tmp5_, _tmp9_, FALSE, &_inner_error_);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = _tmp10_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp9_);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = _tmp11_;
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 3546 "libvirt-machine.c"
			goto __catch23_g_error;
		}
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (port);
#line 307 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		port = _tmp12_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = xmldoc;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = type;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = string_to_string (_tmp14_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp16_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp15_, "']/@socket)", NULL);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp17_ = _tmp16_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp18_ = boxes_extract_xpath (_tmp13_, _tmp17_, FALSE, &_inner_error_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = _tmp18_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp17_);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp20_ = _tmp19_;
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 3575 "libvirt-machine.c"
			goto __catch23_g_error;
		}
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (socket);
#line 308 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		socket = _tmp20_;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp21_ = xmldoc;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp22_ = type;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp23_ = string_to_string (_tmp22_);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp24_ = g_strconcat ("string(/domain/devices/graphics[@type='", _tmp23_, "']/@listen)", NULL);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp25_ = _tmp24_;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp26_ = boxes_extract_xpath (_tmp21_, _tmp25_, FALSE, &_inner_error_);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp27_ = _tmp26_;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (_tmp25_);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp28_ = _tmp27_;
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_free0 (xmldoc);
#line 3604 "libvirt-machine.c"
			goto __catch23_g_error;
		}
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 309 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		host = _tmp28_;
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (xmldoc);
#line 3613 "libvirt-machine.c"
	}
	goto __finally23;
	__catch23_g_error:
	{
		GError* _error_ = NULL;
		GError* _tmp29_;
		const gchar* _tmp30_;
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp29_ = _error_;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp30_ = _tmp29_->message;
#line 311 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:311: %s", _tmp30_);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (socket);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (port);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (type);
#line 312 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 3643 "libvirt-machine.c"
	}
	__finally23:
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (socket);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (port);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (type);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 304 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 3662 "libvirt-machine.c"
	}
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp32_ = host;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp32_ == NULL) {
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp31_ = TRUE;
#line 3670 "libvirt-machine.c"
	} else {
		const gchar* _tmp33_;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp33_ = host;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp31_ = g_strcmp0 (_tmp33_, "") == 0;
#line 3677 "libvirt-machine.c"
	}
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp34_ = _tmp31_;
#line 315 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp34_) {
#line 3683 "libvirt-machine.c"
		gchar* _tmp35_;
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp35_ = g_strdup ("localhost");
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_free0 (host);
#line 316 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		host = _tmp35_;
#line 3691 "libvirt-machine.c"
	}
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp36_ = type;
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp37_ = _tmp36_;
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp39_ = (NULL == _tmp37_) ? 0 : g_quark_from_string (_tmp37_);
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp39_ == ((0 != _tmp38_label0) ? _tmp38_label0 : (_tmp38_label0 = g_quark_from_static_string ("spice")))) {
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 3703 "libvirt-machine.c"
			default:
			{
				BoxesDisplayConfig* _tmp40_;
				const gchar* _tmp41_;
				const gchar* _tmp42_;
				gint _tmp43_ = 0;
				BoxesSpiceDisplay* _tmp44_;
				BoxesSpiceDisplay* _tmp45_;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp40_ = ((BoxesMachine*) self)->config;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp41_ = host;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp42_ = port;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp43_ = atoi (_tmp42_);
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp44_ = boxes_spice_display_new (_tmp40_, _tmp41_, _tmp43_);
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp45_ = _tmp44_;
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_display ((BoxesMachine*) self, (BoxesDisplay*) _tmp45_);
#line 320 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_tmp45_);
#line 321 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 3730 "libvirt-machine.c"
			}
		}
	} else if (_tmp39_ == ((0 != _tmp38_label1) ? _tmp38_label1 : (_tmp38_label1 = g_quark_from_static_string ("vnc")))) {
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 3736 "libvirt-machine.c"
			default:
			{
				BoxesDisplayConfig* _tmp46_;
				const gchar* _tmp47_;
				const gchar* _tmp48_;
				gint _tmp49_ = 0;
				BoxesVncDisplay* _tmp50_;
				BoxesVncDisplay* _tmp51_;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp46_ = ((BoxesMachine*) self)->config;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp47_ = host;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp48_ = port;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp49_ = atoi (_tmp48_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp50_ = boxes_vnc_display_new (_tmp46_, _tmp47_, _tmp49_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp51_ = _tmp50_;
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				boxes_machine_set_display ((BoxesMachine*) self, (BoxesDisplay*) _tmp51_);
#line 324 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_tmp51_);
#line 325 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 3763 "libvirt-machine.c"
			}
		}
	} else {
#line 318 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		switch (0) {
#line 3769 "libvirt-machine.c"
			default:
			{
				const gchar* _tmp52_;
				gchar* _tmp53_;
				gchar* _tmp54_;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp52_ = type;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp53_ = g_strconcat ("unsupported display of type ", _tmp52_, NULL);
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp54_ = _tmp53_;
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_warning ("libvirt-machine.vala:328: %s", _tmp54_);
#line 328 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_free0 (_tmp54_);
#line 329 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				break;
#line 3787 "libvirt-machine.c"
			}
		}
	}
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (host);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (socket);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (port);
#line 299 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (type);
#line 3799 "libvirt-machine.c"
}


static gchar* boxes_libvirt_machine_real_get_screenshot_prefix (BoxesMachine* base) {
	BoxesLibvirtMachine * self;
	gchar* result = NULL;
	GVirDomain* _tmp0_;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_;
#line 333 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 334 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->domain;
#line 334 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = gvir_domain_get_uuid (_tmp0_);
#line 334 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = g_strdup (_tmp1_);
#line 334 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp2_;
#line 334 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3821 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot_data_free (gpointer _data) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	_data_ = _data;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->result);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineTakeScreenshotData, _data_);
#line 3834 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_take_screenshot (BoxesMachine* base, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
	BoxesLibvirtMachine* _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineTakeScreenshotData);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_real_take_screenshot);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_real_take_screenshot_data_free);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 3856 "libvirt-machine.c"
}


static GdkPixbuf* boxes_libvirt_machine_real_take_screenshot_finish (BoxesMachine* base, GAsyncResult* _res_, GError** error) {
	GdkPixbuf* result;
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return NULL;
#line 3867 "libvirt-machine.c"
	}
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = _data_->result;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = NULL;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 3877 "libvirt-machine.c"
}


static Block13Data* block13_data_ref (Block13Data* _data13_) {
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data13_->_ref_count_);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data13_;
#line 3886 "libvirt-machine.c"
}


static void block13_data_unref (void * _userdata_) {
	Block13Data* _data13_;
	_data13_ = (Block13Data*) _userdata_;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data13_->_ref_count_)) {
#line 3895 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data13_->self;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data13_->stream);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block13Data, _data13_);
#line 3905 "libvirt-machine.c"
	}
}


static void boxes_libvirt_machine_take_screenshot_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineTakeScreenshotData* _data_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_real_take_screenshot_co (_data_);
#line 3920 "libvirt-machine.c"
}


static void __lambda80_ (Block13Data* _data13_, GError** error) {
	BoxesLibvirtMachine * self;
	GVirDomain* _tmp0_;
	GVirStream* _tmp1_;
	gchar* _tmp2_ = NULL;
	gchar* _tmp3_;
	GError * _inner_error_ = NULL;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data13_->self;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->domain;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data13_->stream;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_domain_screenshot (_tmp0_, _tmp1_, (guint) 0, (guint) 0, &_inner_error_);
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_propagate_error (error, _inner_error_);
#line 350 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 3949 "libvirt-machine.c"
	}
}


static void ___lambda80__boxes_run_in_thread_func (gpointer self, GError** error) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda80_ (self, error);
#line 3957 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_real_take_screenshot_co (BoxesLibvirtMachineTakeScreenshotData* _data_) {
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 3966 "libvirt-machine.c"
		goto _state_0;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 3970 "libvirt-machine.c"
		goto _state_1;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 2:
#line 3974 "libvirt-machine.c"
		goto _state_2;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 3:
#line 3978 "libvirt-machine.c"
		goto _state_3;
		default:
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 3983 "libvirt-machine.c"
	}
	_state_0:
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_ = g_slice_new0 (Block13Data);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_->_ref_count_ = 1;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_->self = g_object_ref (_data_->self);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_->_async_data_ = _data_;
#line 338 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->state = GVIR_DOMAIN_STATE_NONE;
#line 3996 "libvirt-machine.c"
	{
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = _data_->self->domain;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_get_info_async (_data_->_tmp0_, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4006 "libvirt-machine.c"
		_state_1:
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = NULL;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp1_ = gvir_domain_get_info_finish (_data_->_tmp0_, _data_->_res_, &_data_->_inner_error_);
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp2_ = _data_->_tmp1_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 4016 "libvirt-machine.c"
			goto __catch24_g_error;
		}
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->_tmp2_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = _data_->_tmp3_->state;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->state = _data_->_tmp4_;
#line 340 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirDomainInfo_free0 (_data_->_tmp3_);
#line 4027 "libvirt-machine.c"
	}
	goto __finally24;
	__catch24_g_error:
	{
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_inner_error_ = NULL;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = boxes_collection_item_get_name ((BoxesCollectionItem*) _data_->self);
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = _data_->_tmp5_;
#line 342 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:342: Failed to get information on '%s'", _data_->_tmp6_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_data_->_error_);
#line 4044 "libvirt-machine.c"
	}
	__finally24:
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block13_data_unref (_data_->_data13_);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data13_ = NULL;
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4061 "libvirt-machine.c"
		} else {
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4065 "libvirt-machine.c"
		}
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 339 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4071 "libvirt-machine.c"
	}
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp8_ = _data_->state;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp8_ != GVIR_DOMAIN_STATE_RUNNING) {
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp9_ = _data_->state;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = _data_->_tmp9_ != GVIR_DOMAIN_STATE_PAUSED;
#line 4081 "libvirt-machine.c"
	} else {
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp7_ = FALSE;
#line 4085 "libvirt-machine.c"
	}
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp10_ = _data_->_tmp7_;
#line 345 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp10_) {
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->result = NULL;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block13_data_unref (_data_->_data13_);
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data13_ = NULL;
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4101 "libvirt-machine.c"
		} else {
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4105 "libvirt-machine.c"
		}
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 346 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4111 "libvirt-machine.c"
	}
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp11_ = _data_->self->connection;
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp12_ = NULL;
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp12_ = gvir_connection_get_stream (_data_->_tmp11_, (guint) 0);
#line 348 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_->stream = _data_->_tmp12_;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_state_ = 2;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread (___lambda80__boxes_run_in_thread_func, _data_->_data13_, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4127 "libvirt-machine.c"
	_state_2:
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_run_in_thread_finish (_data_->_res_, &_data_->_inner_error_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block13_data_unref (_data_->_data13_);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data13_ = NULL;
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4145 "libvirt-machine.c"
		} else {
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4149 "libvirt-machine.c"
		}
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 349 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4155 "libvirt-machine.c"
	}
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp13_ = gdk_pixbuf_loader_new ();
#line 353 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->loader = _data_->_tmp13_;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp14_ = _data_->_data13_->stream;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = NULL;
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp15_ = g_io_stream_get_input_stream ((GIOStream*) _data_->_tmp14_);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp16_ = _g_object_ref0 (_data_->_tmp15_);
#line 354 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->input_stream = _data_->_tmp16_;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = NULL;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp17_ = g_new0 (guint8, 65535);
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = _data_->_tmp17_;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer_length1 = 65535;
#line 355 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_buffer_size_ = _data_->buffer_length1;
#line 356 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->length = (gssize) 0;
#line 4183 "libvirt-machine.c"
	{
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp18_ = TRUE;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		while (TRUE) {
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp19_ = _data_->_tmp18_;
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (!_data_->_tmp19_) {
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_tmp20_ = _data_->length;
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (!(_data_->_tmp20_ > ((gssize) 0))) {
#line 360 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 4199 "libvirt-machine.c"
				}
			}
#line 357 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp18_ = FALSE;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp21_ = _data_->input_stream;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22_ = _data_->buffer;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp22__length1 = _data_->buffer_length1;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_state_ = 3;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_input_stream_read_async (_data_->_tmp21_, _data_->_tmp22_, (gsize) _data_->_tmp22__length1, G_PRIORITY_DEFAULT, NULL, boxes_libvirt_machine_take_screenshot_ready, _data_);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4216 "libvirt-machine.c"
			_state_3:
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = 0L;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp23_ = g_input_stream_read_finish (_data_->_tmp21_, _data_->_res_, &_data_->_inner_error_);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp24_ = _data_->_tmp23_;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_inner_error_ != NULL) {
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				block13_data_unref (_data_->_data13_);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data13_ = NULL;
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4244 "libvirt-machine.c"
				} else {
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 4248 "libvirt-machine.c"
				}
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 4254 "libvirt-machine.c"
			}
#line 358 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->length = _data_->_tmp24_;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp25_ = _data_->loader;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26_ = _data_->buffer;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp26__length1 = _data_->buffer_length1;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_data_->_tmp27_ = _data_->length;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			gdk_pixbuf_loader_write (_data_->_tmp25_, _data_->_tmp26_ + 0, (gsize) (_data_->_tmp27_ - 0), &_data_->_inner_error_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_inner_error_ != NULL) {
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_error_free (_data_->_inner_error_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->buffer = (g_free (_data_->buffer), NULL);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->input_stream);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (_data_->loader);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				block13_data_unref (_data_->_data13_);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_data_->_data13_ = NULL;
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_data_->_state_ == 0) {
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4288 "libvirt-machine.c"
				} else {
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					g_simple_async_result_complete (_data_->_async_result);
#line 4292 "libvirt-machine.c"
				}
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_object_unref (_data_->_async_result);
#line 359 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				return FALSE;
#line 4298 "libvirt-machine.c"
			}
		}
	}
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp28_ = _data_->loader;
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	gdk_pixbuf_loader_close (_data_->_tmp28_, &_data_->_inner_error_);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_inner_error_ != NULL) {
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_error_free (_data_->_inner_error_);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->buffer = (g_free (_data_->buffer), NULL);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->input_stream);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (_data_->loader);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		block13_data_unref (_data_->_data13_);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_data13_ = NULL;
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_state_ == 0) {
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4326 "libvirt-machine.c"
		} else {
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 4330 "libvirt-machine.c"
		}
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_unref (_data_->_async_result);
#line 361 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4336 "libvirt-machine.c"
	}
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp29_ = _data_->loader;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = NULL;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp30_ = gdk_pixbuf_loader_get_pixbuf (_data_->_tmp29_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp31_ = _g_object_ref0 (_data_->_tmp30_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->result = _data_->_tmp31_;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block13_data_unref (_data_->_data13_);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_ = NULL;
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4362 "libvirt-machine.c"
	} else {
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4366 "libvirt-machine.c"
	}
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 363 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->buffer = (g_free (_data_->buffer), NULL);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->input_stream);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->loader);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block13_data_unref (_data_->_data13_);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_data13_ = NULL;
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4386 "libvirt-machine.c"
	} else {
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4390 "libvirt-machine.c"
	}
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 337 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4396 "libvirt-machine.c"
}


static void boxes_libvirt_machine_real_delete (BoxesMachine* base, gboolean by_user) {
	BoxesLibvirtMachine * self;
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	gchar* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	GError * _inner_error_ = NULL;
#line 366 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = (BoxesLibvirtMachine*) base;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = g_strconcat ("delete libvirt machine: ", _tmp1_, NULL);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = _tmp2_;
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:367: %s", _tmp3_);
#line 367 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (_tmp3_);
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = by_user;
#line 368 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (boxes_libvirt_machine_parent_class)->delete (G_TYPE_CHECK_INSTANCE_CAST (self, BOXES_TYPE_MACHINE, BoxesMachine), _tmp4_);
#line 370 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_set_stats_enable (self, FALSE);
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = by_user;
#line 372 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp5_) {
#line 373 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_force_shutdown (self, FALSE);
#line 4435 "libvirt-machine.c"
		{
			GVirConnection* _tmp6_;
			BoxesApp* _tmp7_;
			GVirConnection* _tmp8_;
			GVirConnection* _tmp9_;
			GVirDomain* _tmp15_;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = self->connection;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp7_ = boxes_app_app;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp8_ = boxes_app_get_default_connection (_tmp7_);
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = _tmp8_;
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_tmp6_ == _tmp9_) {
#line 4452 "libvirt-machine.c"
				GVirConnection* _tmp10_;
				GVirDomain* _tmp11_;
				GVirStorageVol* _tmp12_ = NULL;
				GVirStorageVol* volume;
				GVirStorageVol* _tmp13_;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp10_ = self->connection;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp11_ = self->domain;
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp12_ = boxes_get_storage_volume (_tmp10_, _tmp11_, NULL);
#line 377 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				volume = _tmp12_;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp13_ = volume;
#line 378 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_tmp13_ != NULL) {
#line 4470 "libvirt-machine.c"
					GVirStorageVol* _tmp14_;
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp14_ = volume;
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					gvir_storage_vol_delete (_tmp14_, (guint) 0, &_inner_error_);
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					if (_inner_error_ != NULL) {
#line 379 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (volume);
#line 4480 "libvirt-machine.c"
						goto __catch25_g_error;
					}
				}
#line 376 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (volume);
#line 4486 "libvirt-machine.c"
			}
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp15_ = self->domain;
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			gvir_domain_delete (_tmp15_, (guint) GVIR_DOMAIN_DELETE_SAVED_STATE, &_inner_error_);
#line 381 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 4494 "libvirt-machine.c"
				goto __catch25_g_error;
			}
		}
		goto __finally25;
		__catch25_g_error:
		{
			GError* err = NULL;
			GError* _tmp16_;
			const gchar* _tmp17_;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			err = _inner_error_;
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_inner_error_ = NULL;
#line 383 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp16_ = err;
#line 383 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp17_ = _tmp16_->message;
#line 383 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_warning ("libvirt-machine.vala:383: %s", _tmp17_);
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_error_free0 (err);
#line 4516 "libvirt-machine.c"
		}
		__finally25:
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_clear_error (&_inner_error_);
#line 375 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 4527 "libvirt-machine.c"
		}
	}
}


static void boxes_libvirt_machine_suspend_data_free (gpointer _data) {
	BoxesLibvirtMachineSuspendData* _data_;
	_data_ = _data;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (_data_->self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_slice_free (BoxesLibvirtMachineSuspendData, _data_);
#line 4540 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend (BoxesLibvirtMachine* self, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
	BoxesLibvirtMachine* _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_slice_new0 (BoxesLibvirtMachineSuspendData);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_libvirt_machine_suspend);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_libvirt_machine_suspend_data_free);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->self = _tmp0_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 4559 "libvirt-machine.c"
}


void boxes_libvirt_machine_suspend_finish (BoxesLibvirtMachine* self, GAsyncResult* _res_, GError** error) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4569 "libvirt-machine.c"
	}
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 4573 "libvirt-machine.c"
}


static void boxes_libvirt_machine_suspend_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesLibvirtMachineSuspendData* _data_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_ = _user_data_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_source_object_ = source_object;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_res_ = _res_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_suspend_co (_data_);
#line 4587 "libvirt-machine.c"
}


static gboolean boxes_libvirt_machine_suspend_co (BoxesLibvirtMachineSuspendData* _data_) {
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (_data_->_state_) {
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 0:
#line 4596 "libvirt-machine.c"
		goto _state_0;
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case 1:
#line 4600 "libvirt-machine.c"
		goto _state_1;
		default:
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_assert_not_reached ();
#line 4605 "libvirt-machine.c"
	}
	_state_0:
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp1_ = boxes_libvirt_machine_get_save_on_quit (_data_->self);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp2_ = _data_->_tmp1_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_tmp2_) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp3_ = _data_->self->domain;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_state_ = 1;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_save_async (_data_->_tmp3_, (guint) 0, NULL, boxes_libvirt_machine_suspend_ready, _data_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 4622 "libvirt-machine.c"
		_state_1:
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = FALSE;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp4_ = gvir_domain_save_finish (_data_->_tmp3_, _data_->_res_, &_data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = _data_->_tmp4_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4640 "libvirt-machine.c"
			} else {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4644 "libvirt-machine.c"
			}
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4650 "libvirt-machine.c"
		}
	} else {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp5_ = _data_->self->domain;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = FALSE;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp6_ = gvir_domain_suspend (_data_->_tmp5_, &_data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_data_->_tmp0_ = _data_->_tmp6_;
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_data_->_inner_error_ != NULL) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_error_free (_data_->_inner_error_);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_data_->_state_ == 0) {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4671 "libvirt-machine.c"
			} else {
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 4675 "libvirt-machine.c"
			}
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			g_object_unref (_data_->_async_result);
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return FALSE;
#line 4681 "libvirt-machine.c"
		}
	}
#line 389 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data_->_tmp7_ = _data_->_tmp0_;
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_data_->_state_ == 0) {
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 4690 "libvirt-machine.c"
	} else {
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 4694 "libvirt-machine.c"
	}
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_unref (_data_->_async_result);
#line 388 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return FALSE;
#line 4700 "libvirt-machine.c"
}


void boxes_libvirt_machine_force_shutdown (BoxesLibvirtMachine* self, gboolean confirm) {
	gboolean _tmp0_;
	const gchar* _tmp9_;
	const gchar* _tmp10_;
	GError * _inner_error_ = NULL;
#line 392 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 393 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = confirm;
#line 393 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp0_) {
#line 4715 "libvirt-machine.c"
		BoxesApp* _tmp1_;
		GtkApplicationWindow* _tmp2_;
		const gchar* _tmp3_ = NULL;
		GtkMessageDialog* _tmp4_;
		GtkMessageDialog* dialog;
		GtkMessageDialog* _tmp5_;
		gint _tmp6_ = 0;
		gint response;
		GtkMessageDialog* _tmp7_;
		gint _tmp8_;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = boxes_app_app;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_->window;
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _ ("When you force shutdown, the box may lose data.");
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = (GtkMessageDialog*) gtk_message_dialog_new ((GtkWindow*) _tmp2_, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_OK_CANCEL, _tmp3_);
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_object_ref_sink (_tmp4_);
#line 394 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		dialog = _tmp4_;
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = dialog;
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = gtk_dialog_run ((GtkDialog*) _tmp5_);
#line 399 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		response = _tmp6_;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = dialog;
#line 400 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gtk_widget_destroy ((GtkWidget*) _tmp7_);
#line 402 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = response;
#line 402 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp8_ != ((gint) GTK_RESPONSE_OK)) {
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_object_unref0 (dialog);
#line 403 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			return;
#line 4756 "libvirt-machine.c"
		}
#line 393 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (dialog);
#line 4760 "libvirt-machine.c"
	}
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = _tmp9_;
#line 406 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:406: Force shutdown '%s'..", _tmp10_);
#line 4768 "libvirt-machine.c"
	{
		GVirDomain* _tmp11_;
#line 408 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = self->domain;
#line 408 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_stop (_tmp11_, (guint) 0, &_inner_error_);
#line 408 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 4777 "libvirt-machine.c"
			goto __catch26_g_error;
		}
	}
	goto __finally26;
	__catch26_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp12_;
		const gchar* _tmp13_ = NULL;
		GError* _tmp14_;
		const gchar* _tmp15_;
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 410 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = self->domain;
#line 410 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = gvir_domain_get_name (_tmp12_);
#line 410 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = _error_;
#line 410 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = _tmp14_->message;
#line 410 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:410: Failed to shutdown '%s': %s", _tmp13_, _tmp15_);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 4805 "libvirt-machine.c"
	}
	__finally26:
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 407 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 4816 "libvirt-machine.c"
	}
}


static void _g_object_unref0_ (gpointer var) {
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(var == NULL) ? NULL : (var = (g_object_unref (var), NULL));
#line 4824 "libvirt-machine.c"
}


static void _g_list_free__g_object_unref0_ (GList* self) {
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_list_foreach (self, (GFunc) _g_object_unref0_, NULL);
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_list_free (self);
#line 4833 "libvirt-machine.c"
}


static GVirDomainDisk* boxes_libvirt_machine_get_domain_disk (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainDisk* result = NULL;
	GVirDomainDisk* _tmp0_;
	GVirDomainDisk* disk;
	GVirConfigDomain* _tmp1_;
	GList* _tmp2_ = NULL;
#line 414 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (NULL, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) NULL) : NULL);
#line 415 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	disk = _tmp0_;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->domain_config;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_config_domain_get_devices (_tmp1_);
#line 4853 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp2_;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 4861 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp3_;
			GVirConfigDomainDevice* device_config = NULL;
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp3_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 417 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp3_;
#line 4868 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp4_;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp4_ = device_config;
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gvir_config_domain_disk_get_type ())) {
#line 4875 "libvirt-machine.c"
					GVirConfigDomainDevice* _tmp5_;
					GVirConfigDomainDisk* _tmp6_;
					GVirConfigDomainDisk* disk_config;
					GVirConfigDomainDisk* _tmp7_;
					GVirConfigDomainDiskGuestDeviceType _tmp8_ = 0;
					GVirConfigDomainDiskGuestDeviceType disk_type;
					gboolean _tmp9_ = FALSE;
					GVirConfigDomainDiskGuestDeviceType _tmp10_;
					gboolean _tmp14_;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp5_ = device_config;
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, gvir_config_domain_disk_get_type ()) ? ((GVirConfigDomainDisk*) _tmp5_) : NULL);
#line 419 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					disk_config = _tmp6_;
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = disk_config;
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = gvir_config_domain_disk_get_guest_device_type (_tmp7_);
#line 420 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					disk_type = _tmp8_;
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp10_ = disk_type;
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp10_ == GVIR_CONFIG_DOMAIN_DISK_GUEST_DEVICE_DISK) {
#line 4901 "libvirt-machine.c"
						GVirConfigDomainDisk* _tmp11_;
						const gchar* _tmp12_ = NULL;
						const gchar* _tmp13_;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp11_ = disk_config;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp12_ = gvir_config_domain_disk_get_source (_tmp11_);
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp13_ = self->priv->storage_volume_path;
#line 424 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp9_ = g_strcmp0 (_tmp12_, _tmp13_) == 0;
#line 4913 "libvirt-machine.c"
					} else {
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp9_ = FALSE;
#line 4917 "libvirt-machine.c"
					}
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp14_ = _tmp9_;
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					if (_tmp14_) {
#line 4923 "libvirt-machine.c"
						GVirDomain* _tmp15_;
						GVirConfigDomainDevice* _tmp16_;
						GObject* _tmp17_ = NULL;
						GObject* _tmp18_;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp15_ = self->domain;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp16_ = device_config;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp17_ = g_object_new (gvir_domain_disk_get_type (), "domain", _tmp15_, "config", _tmp16_, NULL);
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_tmp18_ = G_IS_INITIALLY_UNOWNED (_tmp17_) ? g_object_ref_sink (_tmp17_) : _tmp17_;
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk);
#line 425 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						disk = G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, gvir_domain_disk_get_type ()) ? ((GVirDomainDisk*) _tmp18_) : NULL;
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (disk_config);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						_g_object_unref0 (device_config);
#line 427 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
						break;
#line 4946 "libvirt-machine.c"
					}
#line 423 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (disk_config);
#line 4950 "libvirt-machine.c"
				}
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 4954 "libvirt-machine.c"
			}
		}
#line 418 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 4959 "libvirt-machine.c"
	}
#line 432 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = disk;
#line 432 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 4965 "libvirt-machine.c"
}


static GVirDomainInterface* boxes_libvirt_machine_get_domain_network_interface (BoxesLibvirtMachine* self, GError** error) {
	GVirDomainInterface* result = NULL;
	GVirDomainInterface* _tmp0_;
	GVirDomainInterface* net;
	GVirConfigDomain* _tmp1_;
	GList* _tmp2_ = NULL;
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, NULL);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (NULL, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) NULL) : NULL);
#line 436 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	net = _tmp0_;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->domain_config;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = gvir_config_domain_get_devices (_tmp1_);
#line 4985 "libvirt-machine.c"
	{
		GList* device_config_collection = NULL;
		GList* device_config_it = NULL;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		device_config_collection = _tmp2_;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		for (device_config_it = device_config_collection; device_config_it != NULL; device_config_it = device_config_it->next) {
#line 4993 "libvirt-machine.c"
			GVirConfigDomainDevice* _tmp3_;
			GVirConfigDomainDevice* device_config = NULL;
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp3_ = _g_object_ref0 ((GVirConfigDomainDevice*) device_config_it->data);
#line 439 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			device_config = _tmp3_;
#line 5000 "libvirt-machine.c"
			{
				GVirConfigDomainDevice* _tmp4_;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp4_ = device_config;
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, gvir_config_domain_interface_get_type ())) {
#line 5007 "libvirt-machine.c"
					GVirDomain* _tmp5_;
					GVirConfigDomainDevice* _tmp6_;
					GObject* _tmp7_ = NULL;
					GObject* _tmp8_;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp5_ = self->domain;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp6_ = device_config;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp7_ = g_object_new (gvir_domain_interface_get_type (), "domain", _tmp5_, "config", _tmp6_, NULL);
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_tmp8_ = G_IS_INITIALLY_UNOWNED (_tmp7_) ? g_object_ref_sink (_tmp7_) : _tmp7_;
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (net);
#line 441 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					net = G_TYPE_CHECK_INSTANCE_TYPE (_tmp8_, gvir_domain_interface_get_type ()) ? ((GVirDomainInterface*) _tmp8_) : NULL;
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (device_config);
#line 442 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					break;
#line 5028 "libvirt-machine.c"
				}
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_g_object_unref0 (device_config);
#line 5032 "libvirt-machine.c"
			}
		}
#line 440 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__g_list_free__g_object_unref0_0 (device_config_collection);
#line 5037 "libvirt-machine.c"
	}
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = net;
#line 446 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5043 "libvirt-machine.c"
}


static void _vala_GVirNodeInfo_free (GVirNodeInfo* self) {
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_node_info_get_type (), self);
#line 5050 "libvirt-machine.c"
}


static void _boxes_libvirt_machine_on_ram_changed_property_size_changed (guint64 value, gpointer self) {
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_on_ram_changed (self, value);
#line 5057 "libvirt-machine.c"
}


static void boxes_libvirt_machine_add_ram_property (BoxesLibvirtMachine* self, GList** list) {
	GError * _inner_error_ = NULL;
#line 449 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 5065 "libvirt-machine.c"
	{
		GVirConnection* _tmp0_;
		GVirNodeInfo* _tmp1_ = NULL;
		GVirNodeInfo* _tmp2_;
		GVirNodeInfo* _tmp3_;
		gulong _tmp4_;
		gulong _tmp5_;
		gulong max_ram;
		const gchar* _tmp6_ = NULL;
		GVirConfigDomain* _tmp7_;
		guint64 _tmp8_;
		guint64 _tmp9_;
		gulong _tmp10_;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp0_ = self->connection;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp1_ = gvir_connection_get_node_info (_tmp0_, &_inner_error_);
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = _tmp1_;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 5087 "libvirt-machine.c"
			goto __catch27_g_error;
		}
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = _tmp2_;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _tmp3_->memory;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _tmp4_;
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirNodeInfo_free0 (_tmp3_);
#line 451 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		max_ram = _tmp5_;
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _ ("RAM");
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = self->domain_config;
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = gvir_config_domain_get_memory (_tmp7_);
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_;
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = max_ram;
#line 453 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp6_, _tmp9_, (guint64) (OSINFO_MEBIBYTES / OSINFO_KIBIBYTES), (guint64) _tmp10_, (guint64) (OSINFO_MEBIBYTES / OSINFO_KIBIBYTES), _boxes_libvirt_machine_on_ram_changed_property_size_changed, self);
#line 5112 "libvirt-machine.c"
	}
	goto __finally27;
	__catch27_g_error:
	{
		GError* _error_ = NULL;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5124 "libvirt-machine.c"
	}
	__finally27:
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 450 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5135 "libvirt-machine.c"
	}
}


static Block14Data* block14_data_ref (Block14Data* _data14_) {
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data14_->_ref_count_);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data14_;
#line 5145 "libvirt-machine.c"
}


static void block14_data_unref (void * _userdata_) {
	Block14Data* _data14_;
	_data14_ = (Block14Data*) _userdata_;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data14_->_ref_count_)) {
#line 5154 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data14_->self;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block14Data, _data14_);
#line 5162 "libvirt-machine.c"
	}
}


static gboolean __lambda74_ (Block14Data* _data14_) {
	BoxesLibvirtMachine * self;
	gboolean result = FALSE;
	GVirConfigDomain* _tmp0_;
	guint64 _tmp1_;
	GError * _inner_error_ = NULL;
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data14_->self;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->domain_config;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _data14_->value;
#line 469 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	gvir_config_domain_set_memory (_tmp0_, _tmp1_);
#line 5181 "libvirt-machine.c"
	{
		GVirDomain* _tmp2_;
		GVirConfigDomain* _tmp3_;
		guint64 _tmp4_;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = self->domain;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->domain_config;
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_set_config (_tmp2_, _tmp3_, &_inner_error_);
#line 471 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 5194 "libvirt-machine.c"
			goto __catch28_g_error;
		}
#line 472 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = _data14_->value;
#line 472 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:472: RAM changed to %llu", _tmp4_);
#line 473 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_notify_reboot_required (self);
#line 5203 "libvirt-machine.c"
	}
	goto __finally28;
	__catch28_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp5_;
		const gchar* _tmp6_ = NULL;
		guint64 _tmp7_;
		GError* _tmp8_;
		const gchar* _tmp9_;
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = self->domain;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = gvir_domain_get_name (_tmp5_);
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = _data14_->value;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = _error_;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = _tmp8_->message;
#line 475 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:475: Failed to change RAM of box '%s' to %llu: %s", _tmp6_, _tmp7_, _tmp9_);
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5232 "libvirt-machine.c"
	}
	__finally28:
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 470 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5243 "libvirt-machine.c"
	}
#line 480 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->ram_update_timeout = (guint) 0;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = FALSE;
#line 482 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5251 "libvirt-machine.c"
}


static gboolean ___lambda74__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda74_ (self);
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5260 "libvirt-machine.c"
}


static void boxes_libvirt_machine_on_ram_changed (BoxesLibvirtMachine* self, guint64 value) {
	Block14Data* _data14_;
	guint64 _tmp0_;
	guint _tmp1_;
	guint _tmp3_ = 0U;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data14_ = g_slice_new0 (Block14Data);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data14_->_ref_count_ = 1;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data14_->self = g_object_ref (self);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data14_->value = _tmp0_;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->priv->ram_update_timeout;
#line 465 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != ((guint) 0)) {
#line 5285 "libvirt-machine.c"
		guint _tmp2_;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = self->priv->ram_update_timeout;
#line 466 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_source_remove (_tmp2_);
#line 5291 "libvirt-machine.c"
	}
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ___lambda74__gsource_func, block14_data_ref (_data14_), block14_data_unref);
#line 468 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->ram_update_timeout = _tmp3_;
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block14_data_unref (_data14_);
#line 463 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data14_ = NULL;
#line 5301 "libvirt-machine.c"
}


static void __lambda75_ (BoxesLibvirtMachine* self) {
	const gchar* _tmp0_;
	const gchar* _tmp1_;
	GError * _inner_error_ = NULL;
#line 488 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 488 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = _tmp0_;
#line 488 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_debug ("libvirt-machine.vala:488: Rebooting '%s'..", _tmp1_);
#line 5315 "libvirt-machine.c"
	{
		GVirDomain* _tmp2_;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = self->domain;
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		gvir_domain_reboot (_tmp2_, (guint) 0, &_inner_error_);
#line 490 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 5324 "libvirt-machine.c"
			goto __catch29_g_error;
		}
	}
	goto __finally29;
	__catch29_g_error:
	{
		GError* _error_ = NULL;
		GVirDomain* _tmp3_;
		const gchar* _tmp4_ = NULL;
		GError* _tmp5_;
		const gchar* _tmp6_;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp3_ = self->domain;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = gvir_domain_get_name (_tmp3_);
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = _error_;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = _tmp5_->message;
#line 492 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:492: Failed to reboot '%s': %s", _tmp4_, _tmp6_);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5352 "libvirt-machine.c"
	}
	__finally29:
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 489 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5363 "libvirt-machine.c"
	}
}


static void ___lambda75__boxes_notificationbar_ok_func (gpointer self) {
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__lambda75_ (self);
#line 5371 "libvirt-machine.c"
}


static void boxes_libvirt_machine_notify_reboot_required (BoxesLibvirtMachine* self) {
	BoxesNotificationbarOKFunc reboot;
	void* reboot_target;
	GDestroyNotify reboot_target_destroy_notify;
	const gchar* _tmp0_ = NULL;
	const gchar* _tmp1_;
	const gchar* _tmp2_;
	gchar* _tmp3_ = NULL;
	gchar* message;
	BoxesApp* _tmp4_;
	BoxesNotificationbar* _tmp5_;
	BoxesNotificationbarOKFunc _tmp6_;
	void* _tmp6__target;
	GDestroyNotify _tmp6__target_destroy_notify;
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot = ___lambda75__boxes_notificationbar_ok_func;
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot_target = g_object_ref (self);
#line 487 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot_target_destroy_notify = g_object_unref;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = _ ("Changes require restart of '%s'. Attempt restart?");
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_collection_item_get_name ((BoxesCollectionItem*) self);
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = _tmp1_;
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_strdup_printf (_tmp0_, _tmp2_);
#line 495 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	message = _tmp3_;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = boxes_app_app;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = _tmp4_->notificationbar;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = reboot;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp6__target = reboot_target;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp6__target_destroy_notify = reboot_target_destroy_notify;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot_target_destroy_notify = NULL;
#line 496 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_notificationbar_display_for_action (_tmp5_, message, GTK_STOCK_YES, _tmp6_, _tmp6__target, _tmp6__target_destroy_notify, NULL, NULL, NULL);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (message);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(reboot_target_destroy_notify == NULL) ? NULL : (reboot_target_destroy_notify (reboot_target), NULL);
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot = NULL;
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot_target = NULL;
#line 486 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	reboot_target_destroy_notify = NULL;
#line 5431 "libvirt-machine.c"
}


static void _vala_GVirStorageVolInfo_free (GVirStorageVolInfo* self) {
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_storage_vol_info_get_type (), self);
#line 5438 "libvirt-machine.c"
}


static void _boxes_libvirt_machine_on_storage_changed_property_size_changed (guint64 value, gpointer self) {
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_on_storage_changed (self, value);
#line 5445 "libvirt-machine.c"
}


static void _vala_GVirStoragePoolInfo_free (GVirStoragePoolInfo* self) {
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_boxed_free (gvir_storage_pool_info_get_type (), self);
#line 5452 "libvirt-machine.c"
}


static void boxes_libvirt_machine_add_storage_property (BoxesLibvirtMachine* self, GList** list) {
	GVirStoragePool* pool = NULL;
	GVirConnection* _tmp0_;
	GVirDomain* _tmp1_;
	GVirStoragePool* _tmp2_ = NULL;
	GVirStorageVol* _tmp3_ = NULL;
	GVirStorageVol* volume;
	GVirStorageVol* _tmp4_;
	GError * _inner_error_ = NULL;
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->connection;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->domain;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = boxes_get_storage_volume (_tmp0_, _tmp1_, &_tmp2_);
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (pool);
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	pool = _tmp2_;
#line 502 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	volume = _tmp3_;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = volume;
#line 503 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp4_ == NULL) {
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (volume);
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (pool);
#line 504 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5489 "libvirt-machine.c"
	}
	{
		GVirStorageVol* _tmp5_;
		GVirStorageVolInfo* _tmp6_ = NULL;
		GVirStorageVolInfo* volume_info;
		GVirStoragePool* _tmp7_;
		GVirStoragePoolInfo* _tmp8_ = NULL;
		GVirStoragePoolInfo* pool_info;
		GVirStorageVolInfo* _tmp9_;
		guint64 _tmp10_;
		GVirStoragePoolInfo* _tmp11_;
		guint64 _tmp12_;
		guint64 max_storage;
		const gchar* _tmp13_ = NULL;
		GVirStorageVolInfo* _tmp14_;
		guint64 _tmp15_;
		GVirStorageVolInfo* _tmp16_;
		guint64 _tmp17_;
		guint64 _tmp18_;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp5_ = volume;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp6_ = gvir_storage_vol_get_info (_tmp5_, &_inner_error_);
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		volume_info = _tmp6_;
#line 507 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 5517 "libvirt-machine.c"
			goto __catch30_g_error;
		}
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp7_ = pool;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp8_ = gvir_storage_pool_get_info (_tmp7_, &_inner_error_);
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		pool_info = _tmp8_;
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_inner_error_ != NULL) {
#line 508 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5530 "libvirt-machine.c"
			goto __catch30_g_error;
		}
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp9_ = volume_info;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp10_ = _tmp9_->capacity;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = pool_info;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = _tmp11_->available;
#line 509 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		max_storage = (_tmp10_ + _tmp12_) / OSINFO_KIBIBYTES;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = _ ("Storage");
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = volume_info;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = _tmp14_->capacity;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp16_ = volume_info;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp17_ = _tmp16_->capacity;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp18_ = max_storage;
#line 511 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_iproperties_provider_add_size_property ((BoxesIPropertiesProvider*) self, list, _tmp13_, _tmp15_ / OSINFO_KIBIBYTES, _tmp17_ / OSINFO_KIBIBYTES, _tmp18_, (guint64) (OSINFO_GIBIBYTES / OSINFO_KIBIBYTES), _boxes_libvirt_machine_on_storage_changed_property_size_changed, self);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirStoragePoolInfo_free0 (pool_info);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		__vala_GVirStorageVolInfo_free0 (volume_info);
#line 5561 "libvirt-machine.c"
	}
	goto __finally30;
	__catch30_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp19_;
		const gchar* _tmp20_ = NULL;
		GError* _tmp21_;
		const gchar* _tmp22_;
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp19_ = volume;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp20_ = gvir_storage_vol_get_name (_tmp19_);
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp21_ = _error_;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp22_ = _tmp21_->message;
#line 519 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:519: Failed to get information on volume '%s' or " \
"it's parent pool: %s", _tmp20_, _tmp22_);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5587 "libvirt-machine.c"
	}
	__finally30:
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (volume);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (pool);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 506 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return;
#line 5602 "libvirt-machine.c"
	}
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (volume);
#line 499 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (pool);
#line 5608 "libvirt-machine.c"
}


static Block15Data* block15_data_ref (Block15Data* _data15_) {
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_atomic_int_inc (&_data15_->_ref_count_);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return _data15_;
#line 5617 "libvirt-machine.c"
}


static void block15_data_unref (void * _userdata_) {
	Block15Data* _data15_;
	_data15_ = (Block15Data*) _userdata_;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (g_atomic_int_dec_and_test (&_data15_->_ref_count_)) {
#line 5626 "libvirt-machine.c"
		BoxesLibvirtMachine * self;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		self = _data15_->self;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (self);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_slice_free (Block15Data, _data15_);
#line 5634 "libvirt-machine.c"
	}
}


static gboolean __lambda79_ (Block15Data* _data15_) {
	BoxesLibvirtMachine * self;
	gboolean result = FALSE;
	GVirConnection* _tmp0_;
	GVirDomain* _tmp1_;
	GVirStorageVol* _tmp2_ = NULL;
	GVirStorageVol* volume;
	GVirStorageVol* _tmp3_;
	GError * _inner_error_ = NULL;
#line 530 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = _data15_->self;
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = self->connection;
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->domain;
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = boxes_get_storage_volume (_tmp0_, _tmp1_, NULL);
#line 531 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	volume = _tmp2_;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = volume;
#line 532 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp3_ == NULL) {
#line 533 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		result = FALSE;
#line 533 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (volume);
#line 533 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return result;
#line 5668 "libvirt-machine.c"
	}
	{
		gboolean _tmp4_ = FALSE;
		guint64 _tmp11_;
#line 536 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp4_ = boxes_machine_is_running ((BoxesMachine*) self);
#line 536 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		if (_tmp4_) {
#line 5677 "libvirt-machine.c"
			GVirDomainDisk* _tmp5_ = NULL;
			GVirDomainDisk* disk;
			GVirDomainDisk* _tmp6_;
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp5_ = boxes_libvirt_machine_get_domain_disk (self, &_inner_error_);
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			disk = _tmp5_;
#line 537 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 5687 "libvirt-machine.c"
				goto __catch31_g_error;
			}
#line 538 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp6_ = disk;
#line 538 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_tmp6_ != NULL) {
#line 5694 "libvirt-machine.c"
				GVirDomainDisk* _tmp7_;
				guint64 _tmp8_;
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp7_ = disk;
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				_tmp8_ = _data15_->value;
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				gvir_domain_disk_resize (_tmp7_, _tmp8_, (guint) 0, &_inner_error_);
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
				if (_inner_error_ != NULL) {
#line 539 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
					_g_object_unref0 (disk);
#line 5707 "libvirt-machine.c"
					goto __catch31_g_error;
				}
			}
#line 536 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_g_object_unref0 (disk);
#line 5713 "libvirt-machine.c"
		} else {
			GVirStorageVol* _tmp9_;
			guint64 _tmp10_;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp9_ = volume;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			_tmp10_ = _data15_->value;
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			gvir_storage_vol_resize (_tmp9_, _tmp10_ * OSINFO_KIBIBYTES, GVIR_STORAGE_VOL_RESIZE_NONE, &_inner_error_);
#line 542 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
			if (_inner_error_ != NULL) {
#line 5725 "libvirt-machine.c"
				goto __catch31_g_error;
			}
		}
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp11_ = _data15_->value;
#line 543 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_debug ("libvirt-machine.vala:543: Storage changed to %llu", _tmp11_);
#line 5733 "libvirt-machine.c"
	}
	goto __finally31;
	__catch31_g_error:
	{
		GError* _error_ = NULL;
		GVirStorageVol* _tmp12_;
		const gchar* _tmp13_ = NULL;
		guint64 _tmp14_;
		GError* _tmp15_;
		const gchar* _tmp16_;
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_error_ = _inner_error_;
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_inner_error_ = NULL;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp12_ = volume;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp13_ = gvir_storage_vol_get_name (_tmp12_);
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp14_ = _data15_->value;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp15_ = _error_;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp16_ = _tmp15_->message;
#line 545 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_warning ("libvirt-machine.vala:545: Failed to change storage capacity of volume " \
"'%s' to %llu: %s", _tmp13_, _tmp14_, _tmp16_);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_error_free0 (_error_);
#line 5762 "libvirt-machine.c"
	}
	__finally31:
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_inner_error_ != NULL) {
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_g_object_unref0 (volume);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_clear_error (&_inner_error_);
#line 535 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		return FALSE;
#line 5775 "libvirt-machine.c"
	}
#line 550 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->storage_update_timeout = (guint) 0;
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = FALSE;
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (volume);
#line 552 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5785 "libvirt-machine.c"
}


static gboolean ___lambda79__gsource_func (gpointer self) {
	gboolean result;
	result = __lambda79_ (self);
#line 530 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5794 "libvirt-machine.c"
}


static void boxes_libvirt_machine_on_storage_changed (BoxesLibvirtMachine* self, guint64 value) {
	Block15Data* _data15_;
	guint64 _tmp0_;
	guint _tmp1_;
	guint _tmp3_ = 0U;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data15_ = g_slice_new0 (Block15Data);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data15_->_ref_count_ = 1;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data15_->self = g_object_ref (self);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = value;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data15_->value = _tmp0_;
#line 527 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = self->priv->storage_update_timeout;
#line 527 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	if (_tmp1_ != ((guint) 0)) {
#line 5819 "libvirt-machine.c"
		guint _tmp2_;
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		_tmp2_ = self->priv->storage_update_timeout;
#line 528 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_source_remove (_tmp2_);
#line 5825 "libvirt-machine.c"
	}
#line 530 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = g_timeout_add_seconds_full (G_PRIORITY_DEFAULT, (guint) 1, ___lambda79__gsource_func, block15_data_ref (_data15_), block15_data_unref);
#line 530 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->storage_update_timeout = _tmp3_;
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	block15_data_unref (_data15_);
#line 525 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_data15_ = NULL;
#line 5835 "libvirt-machine.c"
}


gboolean boxes_libvirt_machine_get_save_on_quit (BoxesLibvirtMachine* self) {
	gboolean result;
	BoxesCollectionSource* _tmp0_;
	gboolean _tmp1_ = FALSE;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_val_if_fail (self != NULL, FALSE);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = boxes_iconfig_get_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", FALSE);
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	result = _tmp1_;
#line 14 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return result;
#line 5853 "libvirt-machine.c"
}


void boxes_libvirt_machine_set_save_on_quit (BoxesLibvirtMachine* self, gboolean value) {
	BoxesCollectionSource* _tmp0_;
	gboolean _tmp1_;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_return_if_fail (self != NULL);
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = ((BoxesMachine*) self)->source;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = value;
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_iconfig_set_boolean ((BoxesIConfig*) _tmp0_, "source", "save-on-quit", _tmp1_);
#line 15 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_notify ((GObject *) self, "save-on-quit");
#line 5870 "libvirt-machine.c"
}


static GObject * boxes_libvirt_machine_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	BoxesLibvirtMachine * self;
	BoxesLibvirtMachineMachineStat* _tmp0_ = NULL;
	GCancellable* _tmp1_;
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	parent_class = G_OBJECT_CLASS (boxes_libvirt_machine_parent_class);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = g_new0 (BoxesLibvirtMachineMachineStat, BOXES_LIBVIRT_MACHINE_STATS_SIZE);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = _tmp0_;
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_length1 = BOXES_LIBVIRT_MACHINE_STATS_SIZE;
#line 78 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->_stats_size_ = self->priv->stats_length1;
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = g_cancellable_new ();
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 79 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats_cancellable = _tmp1_;
#line 77 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return obj;
#line 5904 "libvirt-machine.c"
}


static GVirDomainDiskStats* _vala_GVirDomainDiskStats_copy (GVirDomainDiskStats* self) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_disk_stats_get_type (), self);
#line 5911 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainDiskStats_copy0 (gpointer self) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainDiskStats_copy (self) : NULL;
#line 5918 "libvirt-machine.c"
}


static GVirDomainInterfaceStats* _vala_GVirDomainInterfaceStats_copy (GVirDomainInterfaceStats* self) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return g_boxed_copy (gvir_domain_interface_stats_get_type (), self);
#line 5925 "libvirt-machine.c"
}


static gpointer __vala_GVirDomainInterfaceStats_copy0 (gpointer self) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return self ? _vala_GVirDomainInterfaceStats_copy (self) : NULL;
#line 5932 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_copy (const BoxesLibvirtMachineMachineStat* self, BoxesLibvirtMachineMachineStat* dest) {
	gint64 _tmp0_;
	gdouble _tmp1_;
	gdouble _tmp2_;
	gdouble _tmp3_;
	gdouble _tmp4_;
	GVirDomainDiskStats* _tmp5_;
	GVirDomainDiskStats* _tmp6_;
	gdouble _tmp7_;
	gdouble _tmp8_;
	GVirDomainInterfaceStats* _tmp9_;
	GVirDomainInterfaceStats* _tmp10_;
	gdouble _tmp11_;
	gdouble _tmp12_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp0_ = (*self).timestamp;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).timestamp = _tmp0_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp1_ = (*self).cpu_time;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time = _tmp1_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp2_ = (*self).cpu_time_abs;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_time_abs = _tmp2_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp3_ = (*self).cpu_guest_percent;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).cpu_guest_percent = _tmp3_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp4_ = (*self).memory_percent;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).memory_percent = _tmp4_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp5_ = (*self).disk;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp6_ = __vala_GVirDomainDiskStats_copy0 (_tmp5_);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*dest).disk);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk = _tmp6_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp7_ = (*self).disk_read;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_read = _tmp7_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp8_ = (*self).disk_write;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).disk_write = _tmp8_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp9_ = (*self).net;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp10_ = __vala_GVirDomainInterfaceStats_copy0 (_tmp9_);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*dest).net);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net = _tmp10_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp11_ = (*self).net_read;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_read = _tmp11_;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_tmp12_ = (*self).net_write;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	(*dest).net_write = _tmp12_;
#line 6002 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_destroy (BoxesLibvirtMachineMachineStat* self) {
#line 62 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainDiskStats_free0 ((*self).disk);
#line 65 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	__vala_GVirDomainInterfaceStats_free0 ((*self).net);
#line 6011 "libvirt-machine.c"
}


static BoxesLibvirtMachineMachineStat* boxes_libvirt_machine_machine_stat_dup (const BoxesLibvirtMachineMachineStat* self) {
	BoxesLibvirtMachineMachineStat* dup;
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	dup = g_new0 (BoxesLibvirtMachineMachineStat, 1);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_copy (self, dup);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	return dup;
#line 6023 "libvirt-machine.c"
}


static void boxes_libvirt_machine_machine_stat_free (BoxesLibvirtMachineMachineStat* self) {
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_machine_stat_destroy (self);
#line 56 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_free (self);
#line 6032 "libvirt-machine.c"
}


static GType boxes_libvirt_machine_machine_stat_get_type (void) {
	static volatile gsize boxes_libvirt_machine_machine_stat_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_machine_stat_type_id__volatile)) {
		GType boxes_libvirt_machine_machine_stat_type_id;
		boxes_libvirt_machine_machine_stat_type_id = g_boxed_type_register_static ("BoxesLibvirtMachineMachineStat", (GBoxedCopyFunc) boxes_libvirt_machine_machine_stat_dup, (GBoxedFreeFunc) boxes_libvirt_machine_machine_stat_free);
		g_once_init_leave (&boxes_libvirt_machine_machine_stat_type_id__volatile, boxes_libvirt_machine_machine_stat_type_id);
	}
	return boxes_libvirt_machine_machine_stat_type_id__volatile;
}


static void boxes_libvirt_machine_class_init (BoxesLibvirtMachineClass * klass) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	boxes_libvirt_machine_parent_class = g_type_class_peek_parent (klass);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_type_class_add_private (klass, sizeof (BoxesLibvirtMachinePrivate));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->connect_display = boxes_libvirt_machine_real_connect_display;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_properties = boxes_libvirt_machine_real_get_properties;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->get_screenshot_prefix = boxes_libvirt_machine_real_get_screenshot_prefix;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot = boxes_libvirt_machine_real_take_screenshot;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->take_screenshot_finish = boxes_libvirt_machine_real_take_screenshot_finish;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	BOXES_MACHINE_CLASS (klass)->delete = boxes_libvirt_machine_real_delete;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->get_property = _vala_boxes_libvirt_machine_get_property;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->set_property = _vala_boxes_libvirt_machine_set_property;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->constructor = boxes_libvirt_machine_constructor;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_libvirt_machine_finalize;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_object_class_install_property (G_OBJECT_CLASS (klass), BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT, g_param_spec_boolean ("save-on-quit", "save-on-quit", "save-on-quit", FALSE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	g_signal_new ("stats_updated", BOXES_TYPE_LIBVIRT_MACHINE, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_marshal_VOID__VOID, G_TYPE_NONE, 0);
#line 6076 "libvirt-machine.c"
}


static void boxes_libvirt_machine_instance_init (BoxesLibvirtMachine * self) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv = BOXES_LIBVIRT_MACHINE_GET_PRIVATE (self);
#line 70 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->ram_update_timeout = (guint) 0;
#line 71 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->storage_update_timeout = (guint) 0;
#line 6087 "libvirt-machine.c"
}


static void boxes_libvirt_machine_finalize (GObject* obj) {
	BoxesLibvirtMachine * self;
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 6 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->domain);
#line 7 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->domain_config);
#line 8 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->connection);
#line 9 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_free0 (self->priv->storage_volume_path);
#line 11 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_boxes_vm_creator_unref0 (self->vm_creator);
#line 73 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	_g_object_unref0 (self->priv->stats_cancellable);
#line 76 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->priv->stats = (_vala_BoxesLibvirtMachineMachineStat_array_free (self->priv->stats, self->priv->stats_length1), NULL);
#line 209 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->cpu_stats = (g_free (self->cpu_stats), NULL);
#line 210 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->io_stats = (g_free (self->io_stats), NULL);
#line 211 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	self->net_stats = (g_free (self->net_stats), NULL);
#line 435 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	G_OBJECT_CLASS (boxes_libvirt_machine_parent_class)->finalize (obj);
#line 6117 "libvirt-machine.c"
}


GType boxes_libvirt_machine_get_type (void) {
	static volatile gsize boxes_libvirt_machine_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_libvirt_machine_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesLibvirtMachineClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_libvirt_machine_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesLibvirtMachine), 0, (GInstanceInitFunc) boxes_libvirt_machine_instance_init, NULL };
		GType boxes_libvirt_machine_type_id;
		boxes_libvirt_machine_type_id = g_type_register_static (BOXES_TYPE_MACHINE, "BoxesLibvirtMachine", &g_define_type_info, 0);
		g_once_init_leave (&boxes_libvirt_machine_type_id__volatile, boxes_libvirt_machine_type_id);
	}
	return boxes_libvirt_machine_type_id__volatile;
}


static void _vala_boxes_libvirt_machine_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		g_value_set_boolean (value, boxes_libvirt_machine_get_save_on_quit (self));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 6144 "libvirt-machine.c"
		default:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 6150 "libvirt-machine.c"
	}
}


static void _vala_boxes_libvirt_machine_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	BoxesLibvirtMachine * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, BOXES_TYPE_LIBVIRT_MACHINE, BoxesLibvirtMachine);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
	switch (property_id) {
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		case BOXES_LIBVIRT_MACHINE_SAVE_ON_QUIT:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		boxes_libvirt_machine_set_save_on_quit (self, g_value_get_boolean (value));
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 6166 "libvirt-machine.c"
		default:
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
#line 5 "/home/teuf/jhbuild-boxes/sources/gnome-boxes/src/libvirt-machine.vala"
		break;
#line 6172 "libvirt-machine.c"
	}
}



